OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den givne operator er invalid",
    "The given regular expression is invalid" : "Det givne regulære udtryk er invalidt",
    "The given file size is invalid" : "Den givne filstørrelse er invalid",
    "The given tag id is invalid" : "Det givne tag id er invalidt",
    "The given IP range is invalid" : "Det givne IP interval er invalidt",
    "The given IP range is not valid for IPv4" : "Det givne IP interval er invalidt for IPv4",
    "The given IP range is not valid for IPv6" : "Det givne IP interval er invalidt for IPv6",
    "The given time span is invalid" : "Det givne tid interval er invalidt",
    "The given start time is invalid" : "Den givne starttid er invalid",
    "The given end time is invalid" : "Den givne sluttid er invalid",
    "The given group does not exist" : "Den givne gruppe eksisterer ikke",
    "File" : "Fil",
    "Operation #%s does not exist" : "Operation #%s eksisterer ikke",
    "Operation %s does not exist" : "Operation %s eksisterer ikke",
    "Operation %s is invalid" : "Operation %s er invalid",
    "Check %s does not exist" : "Tjek %s eksisterer ikke",
    "Check %s is invalid" : "Tjek %s er invalid",
    "Check #%s does not exist" : "Tjek #%s eksisterer",
    "Check %s is invalid or does not exist" : "Tjek %s er invalid eller eksisterer ikke",
    "Flow" : "Flow",
    "Folder" : "Mappe",
    "Images" : "Billeder",
    "Predefined URLs" : "Foruddefineret URLer",
    "Files WebDAV" : "Fil WebDAV",
    "Others" : "Andre",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Dekstop klient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook tilføjelser",
    "and" : "og",
    "Cancel" : "Annullér",
    "Delete" : "Slet",
    "Save" : "Gem",
    "Browse the App Store" : "Gennemse App Store",
    "matches" : "er lig med",
    "does not match" : "er ikke lig med",
    "is" : "er",
    "is not" : "er ikke",
    "File name" : "Filnavn",
    "File MIME type" : "Fil MIME type",
    "File size (upload)" : "Filstørrelse (upload)",
    "less" : "mindre",
    "less or equals" : "mindre eller lig med",
    "greater or equals" : "større eller lig med",
    "greater" : "større",
    "Request remote address" : "Forespørg bruger adresse",
    "matches IPv4" : "er lig med IPv4",
    "does not match IPv4" : "er ikke lig med IPv4",
    "matches IPv6" : "er lig med IPv6",
    "does not match IPv6" : "er ikke lig med IPv6",
    "File system tag" : "Filsystem markering",
    "is tagged with" : "er markeret med",
    "is not tagged with" : "er ikke markeret med",
    "Request URL" : "Forespurgt URL",
    "Request time" : "Kald tid",
    "between" : "mellem",
    "not between" : "ikke mellem",
    "Request user agent" : "Bruger \"user agent\"",
    "User group membership" : "Brugers gruppemedlemsskab",
    "is member of" : "er medlem af",
    "is not member of" : "er ikke medlem af",
    "No results" : "Ingen resultater",
    "%s (invisible)" : "%s (usynlig)",
    "%s (restricted)" : "%s (begrænset)"
},
"nplurals=2; plural=(n != 1);");
