OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "text document" : "teksdokument",
    "Readme" : "Leesmy",
    "Text" : "Teks",
    "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
    "Use current version" : "Gebruik huidige weergawe",
    "Use the saved version" : "Gebruik die bewaarde weergawe",
    "Reconnect" : "Herverbind",
    "Guest" : "Gas",
    "guest" : "gas",
    "Show author colors" : "Toon outeurkleure",
    "Author colors are only shown until everyone has closed the document." : "Outeurkleure word slegs getoon tot almal die dokument toegemaak het.",
    "Offline" : "Vanlyn",
    "Saving …" : "Bewaar tans…",
    "Saved" : "Bewaar",
    "Unsaved changes" : "Onbewaarde veranderinge",
    "Keyboard shortcuts" : "Sneltoetse",
    "Bold" : "Vet",
    "Italic" : "Skuins",
    "Strikethrough" : "Deurstreep",
    "Heading 1" : "Kop 1",
    "Heading 6" : "Kop 6",
    "Unordered list" : "Ongesorteerde lys",
    "Ordered list" : "Gesorteerde lys",
    "Blockquote" : "Blokaanhaling",
    "Unsupported image type" : "Onondersteunde beeldtipe",
    "Headings" : "Koppe",
    "Heading 2" : "Kop 2",
    "Heading 3" : "Kop 3",
    "Heading 4" : "Kop 4",
    "Heading 5" : "Kop 5",
    "Info" : "Inligting",
    "Success" : "Sukses",
    "Warning" : "Waarskuwing",
    "Edit" : "Wysig",
    "Last saved {lastSaved}" : "Laas bewaar {lastSaved}",
    "Enter your name so other users can see who is editing" : "Voer u naam in sodat andere kan weet wie hieraan werk",
    "Insert an image" : "Voer ’n beeld in",
    "Link file" : "Koppel lêer",
    "Select file to link to" : "Kies lêer om na te koppel",
    "ToDo list" : "Moet-doen-lys",
    "Insert image" : "Voer beeld in"
},
"nplurals=2; plural=(n != 1);");
