OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Compartióse con %1$s",
    "Shared with {email}" : "Compartióse con {email}",
    "Shared with %1$s by %2$s" : "Compartióse con %1$s por %2$s",
    "Shared with {email} by {actor}" : "Compartióse con {email} por {actor}",
    "Password for mail share sent to %1$s" : "Unvióse a %1$s la contraseña pa la compartición per corréu",
    "Password for mail share sent to {email}" : "Unvióse a {email} la contraseña pa la compartición per corréu",
    "Password for mail share sent to you" : "Unviósete la contraseña pa la compartición per corréu",
    "You shared %1$s with %2$s by mail" : "Compartiesti %1$s con %2$s per corréu",
    "You shared {file} with {email} by mail" : "Compartiesti {file} con {email} per corréu",
    "%3$s shared %1$s with %2$s by mail" : "%3$s compartió %1$s con %2$s per corréu",
    "{actor} shared {file} with {email} by mail" : "{actor} compartió {file} con {email} per corréu",
    "Password to access %1$s was sent to %2s" : "Unvióse a %2s la contraseña p'acceder a %1$s",
    "Password to access {file} was sent to {email}" : "Unvióse a {email} la contraseña p'acceder a {ficheru}",
    "Password to access %1$s was sent to you" : "Unviósete la contraseña p'acceder a %1$s",
    "Password to access {file} was sent to you" : "Unviósete la contraseña p'acceder a {file}",
    "We can't send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Nun podemos unviate la contraseña auto-xenerada. Afita una direición de corréu válida nos tos axustes personales y volvi tentalo.",
    "Failed to send share by email" : "Fallu al unviar la compartición per corréu",
    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
    "Open »%s«" : "Abrir «%s»",
    "Password to access »%s«" : "Contraseña p'acceder a »%s«",
    "You can choose a different password at any time in the share dialog." : "Pues escoyer una contraseña diferente en cualesquier momentu nel diálogu de compartir.",
    "Could not find share" : "Nun pudo alcontrase la compartición",
    "Share by mail" : "Unviar per corréu",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Permite a los usuarios compartir un enllaz personalizáu a un ficheru o carpeta poniendo una direición de corréu.",
    "Enforce password protection" : "Ameyora la proteición por contraseña."
},
"nplurals=2; plural=(n != 1);");
