OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas por pessoas que correspondem à integração do número de telefone através do Talk no celular",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Visível apenas por pessoas desta instância ou convidados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Sincronize apenas com servidores confiáveis",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronize com servidores confiáveis e catálogo de endereços global e público",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando...",
    "Unable to change password" : "Não foi possível alterar a senha",
    "Very weak password" : "Senha muito fraca",
    "Weak password" : "Senha fraca",
    "So-so password" : "Senha mais ou menos",
    "Good password" : "Boa senha",
    "Strong password" : "Senha forte",
    "Groups" : "Grupos",
    "Group list is empty" : "A lista de grupos está vazia",
    "Unable to retrieve the group list" : "Não é possível recuperar a lista de grupos",
    "{actor} added you to group {group}" : "{actor} adicionou você ao grupo {group}",
    "You added {user} to group {group}" : "Você adicionou {user} ao grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} adicionou {user} ao grupo {group}",
    "An administrator added you to group {group}" : "Um administrador adicionou você ao grupo {group}",
    "An administrator added {user} to group {group}" : "Um administrador adicionou {user} ao grupo {group}",
    "{actor} removed you from group {group}" : "{actor} removeu você do grupo {group}",
    "You removed {user} from group {group}" : "Você removeu {user} do grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} removeu {user} do grupo {group}",
    "An administrator removed you from group {group}" : "Um administrador removeu você do grupo {group}",
    "An administrator removed {user} from group {group}" : "Um administrador removeu {user} do grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Seus <strong>membros do grupo</strong> foram alterados",
    "{actor} changed your password" : "{actor} alterou sua senha",
    "You changed your password" : "Você alterou sua senha",
    "Your password was reset by an administrator" : "Sua senha foi redefinida pelo administrador",
    "Your password was reset" : "Sua senha foi redefinida",
    "{actor} changed your email address" : "{actor} alterou seu endereço de e-mail",
    "You changed your email address" : "Você alterou seu e-mail",
    "Your email address was changed by an administrator" : "Seu e-mail foi alterado pelo administrador",
    "You created an app password for a session named \"{token}\"" : "Você criou uma senha de aplicativo para uma sessão chamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Um administrador criou uma senha de aplicativo para uma sessão chamada \"{token}\"",
    "You deleted app password \"{token}\"" : "Você excluiu a senha de aplicativo \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Você renomeou a senha do aplicativo \"{token}\" para \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Você concedeu acesso ao sistema de arquivos para a senha do aplicativo \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Você revogou o acesso ao sistema de arquivos da senha do aplicativo \"{token}\"",
    "Security" : "Segurança",
    "You successfully logged in using two-factor authentication (%1$s)" : "Você conectou com sucesso usando a autenticação de dois fatores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "A tentativa de login usando  autenticação de dois fatores falhou (%1$s)",
    "Remote wipe was started on %1$s" : "Limpeza remota iniciou em %1$s",
    "Remote wipe has finished on %1$s" : "Limpeza remota terminou em %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sua <strong>senha</strong> ou <strong>e-mail</strong> foram alterados",
    "Apps" : "Aplicativos",
    "Could not remove app." : "Não foi possível remover o app.",
    "Could not update app." : "Não foi possível atualizar o app.",
    "Wrong password" : "Senha incorreta",
    "Unable to change personal password" : "Não foi possível alterar a senha pessoal",
    "Saved" : "Salvo",
    "No user supplied" : "Nenhum usuário fornecido",
    "Unable to change password. Password too long." : "Não foi possível alterar a senha. Senha muito longa.",
    "Authentication error" : "Erro de autenticação",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor, forneça uma senha de recuperação do administrador, caso contrário todos os dados serão perdidos.",
    "Wrong admin recovery password. Please check the password and try again." : "Senha de recuperação do administrador incorreta. Verifique a senha e tente novamente.",
    "Backend does not support password change, but the user's encryption key was updated." : "O backend não oferece suporte à alteração de senha, mas a chave de criptografia do usuário foi atualizada.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalar e atualizar aplicativos por meio da App Store ou do Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Federada",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está usando uma versão %1$s desatualizada (%2$s). Atualize seu sistema operacional ou recursos como %3$s não funcionarão adequadamente.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Não foi possível determinar se a versão TLS do cURL está desatualizada ou não porque ocorreu um erro durante a solicitação HTTPS em https://nextcloud.com. Verifique o arquivo de log do Nextcloud para obter mais detalhes.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "O módulo PHP OPcache não está carregado. Para um melhor desempenho, é recomendável carregá-lo em sua instalação do PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache está desabilitado. Para um melhor desempenho, recomenda-se aplicar <code>opcache.enable=1</code> para sua configuração PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache está configurado para remover comentários de código. Com o OPcache ativado, <code>opcache.save_comments=1</code> deve ser definido para que o Nextcloud funcione.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "O Nextcloud não tem permissão para usar a API OPcache. Com o OPcache ativado, é altamente recomendável incluir todos os diretórios do Nextcloud com <code>opcache.restrict_api</code>ou desmarque essa configuração para desabilitar as restrições da API OPcache, para evitar erros durante o núcleo do Nextcloud ou atualizações de aplicativos.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "O Nextcloud não tem permissão para usar a API OPcache. É altamente recomendável incluir todos os diretórios do Nextcloud com <code>opcache.restrict_api</code> ou desmarque essa configuração para desabilitar as restrições da API OPcache, para evitar erros durante o núcleo do Nextcloud ou atualizações de aplicativos.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves do OPcache é quase excedido. Para garantir que todos os scripts possam ser mantidos no cache, é recomendável aplicar <code>opcache.max_accelerated_files</code> à sua configuração PHP com um valor superior a <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "O buffer do OPcache está quase cheio. Para garantir que todos os scripts possam ser mantidos em cache, é recomendável aplicar<code>opcache.memory_consumption</code> to sua configuração PHP com um valor maior que<code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "O buffer de strings internas do OPcache está quase cheio. Para garantir que as strings repetidas possam ser efetivamente armazenadas em cache, é recomendável aplicar <code>opcache.interned_strings_buffer</code>para sua configuração PHP com um valor maior que <code>%s</code>.",
    "Administrator documentation" : "Documentação do administrador",
    "User documentation" : "Documentação do usuário",
    "Invalid SMTP password." : "Senha SMTP incorreta.",
    "Email setting test" : "Teste da configuração de e-mail",
    "Well done, %s!" : "Bom trabalho %s!",
    "If you received this email, the email configuration seems to be correct." : "Se você recebeu este e-mail, é sinal que a configuração do servidor de e-mail está correta.",
    "Email could not be sent. Check your mail server log" : "O e-mail não pôde ser enviado. Verifique o log do servidor de e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor, revise suas configurações. (Erro: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Você precisa definir seu e-mail de usuário antes de poder enviar e-mails de teste. Vá a %s para isso.",
    "Users" : "Usuários",
    "Invalid user" : "Usuário inválido",
    "Invalid mail address" : "Endereço de e-mail inválido",
    "Settings saved" : "Configurações salvas",
    "Unable to change full name" : "Não foi possível alterar o nome completo",
    "Unable to change email address" : "Não foi possível alterar o endereço de e-mail",
    "Unable to set invalid phone number" : "Não é possível definir um número de telefone inválido",
    "Unable to set invalid website" : "Não foi possível definir site: site inválido.",
    "Some account data was invalid" : "Alguns dados da conta eram inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "A fim de verificar sua conta no Twitter, poste o seguinte tweet no Twitter (certifique-se de postar sem nenhuma quebra de linha):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "A fim de verificar seu Website, armazene o seguinte conteúdo na página raiz em '.well-known/CloudIdVerificationCode.txt' (certifique-se que o texto inteiro esteja em uma só linha):",
    "%1$s changed your password on %2$s." : "%1$s mudou sua senha em %2$s.",
    "Your password on %s was changed." : "Sua senha em %s foi alterada.",
    "Your password on %s was reset by an administrator." : "Sua senha em %s foi redefinida por um administrador.",
    "Your password on %s was reset." : "Sua senha em %s foi redefinida.",
    "Password for %1$s changed on %2$s" : "Senha para %1$s alterada em %2$s",
    "Password changed for %s" : "Senha alterada para %s",
    "If you did not request this, please contact an administrator." : "Se você não solicitou isso, por favor contacte o administrador.",
    "Your email address on %s was changed." : "Seu e-mail em %s foi alterado.",
    "Your email address on %s was changed by an administrator." : "Seu e-mail em %s foi alterado por um administrador.",
    "Email address for %1$s changed on %2$s" : "O  endereço de e-mail para %1$s foi alterado em %2$s",
    "Email address changed for %s" : "E-mail alterado para %s",
    "The new email address is %s" : "O novo e-mail é %s",
    "Your %s account was created" : "Sua conta %s foi criada",
    "Welcome aboard" : "Bem-vindo a bordo",
    "Welcome aboard %s" : "%s, bem-vindo a bordo",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à sua conta %s. Você pode adicionar, proteger e compartilhar seus dados.",
    "Your username is: %s" : "Seu nome de usuário é: %s",
    "Set your password" : "Defina sua senha",
    "Go to %s" : "Ir para %s",
    "Install Client" : "Instalar Cliente",
    "Logged in user must be a subadmin" : "Usuário logado deve ser um subadministrador",
    "Settings" : "Configurações",
    "Personal" : "Pessoal",
    "Administration" : "Administração",
    "Additional settings" : "Configurações adicionais",
    "Administration privileges" : "Privilégios de administração",
    "Groupware" : "Groupware",
    "Overview" : "Visão geral",
    "Basic settings" : "Configurações básicas",
    "Sharing" : "Compartilhamento",
    "Availability" : "Disponibilidade",
    "Calendar" : "Calendário",
    "Personal info" : "Informação pessoal",
    "Mobile & desktop" : "Móvel & desktop",
    "Email server" : "Servidor de e-mail",
    "Security & setup warnings" : "Segurança & avisos de configuração",
    "Background jobs" : "Tarefas em segundo plano",
    "Create" : "Criar",
    "Change" : "Alterar",
    "Delete" : "Excluir",
    "Reshare" : "Recompartilhar",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificando",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Um trabalho em segundo plano está pendente que verifica se há certificados SSL importados pelo usuário. Por favor, volte mais tarde.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Existem alguns certificados SSL importados pelo usuário presentes, que não são mais usados com o Nextcloud 21. Eles podem ser importados na linha de comando através do comando \"occ security:certificates:import\". Seus caminhos dentro do diretório de dados são mostrados abaixo.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "UUIDs inválidos de usuários ou grupos LDAP foram encontrados. Revise suas configurações de \"Substituir detecção de UUID\" na parte Expert da configuração LDAP e use \"occ ldap:update-uuid\" para atualizá-las.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "O antigo formato de criptografia do lado do servidor está ativado. Recomendamos desativar isso.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "A versão do MariaDB \"1%s\" está sendo usada. Nextcloud 21 e superior não suportam esta versão e requerem MariaDB 10.2 ou superior.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "A versão do MySQL \"1%s\" está sendo usada. Nextcloud 21 e superior não suportam esta versão e requerem MySQL 8.0 ou MariaDB 10.2 ou superior.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "A versão do PostgreSQL \"1%s\" está sendo usada. Nextcloud 21 e superior não suportam esta versão e requerem o PostgreSQL 9.6 ou superior.",
    "Profile information" : "Informação do Perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto do perfil, nome completo, e-mail, número de telefone, endereço, site, Twitter, organização, função, título, biografia e se seu perfil está ativado",
    "Nextcloud settings" : "Configurações Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Aqui você pode decidir qual grupo pode acessar certas seções das configurações de administração.",
    "None" : "Nenhuma",
    "Unable to modify setting" : "Incapaz de modificar a configuração",
    "Two-Factor Authentication" : "Autenticação de Dois Fatores",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A autenticação de dois fatores pode ser imposta a todos os usuários e grupos específicos. Se eles não tiverem um provedor de dois fatores configurado, não poderão fazer login no sistema.",
    "Enforce two-factor authentication" : "Forçar o uso de autenticação de dois fatores",
    "Limit to groups" : "Limitado a grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "A obrigatoriedade da autenticação de dois fatores pode ser definida para determinados grupos apenas.",
    "Two-factor authentication is enforced for all members of the following groups." : "A autenticação de dois fatores é imposta a todos os membros dos seguintes grupos.",
    "Enforced groups" : "Grupos obrigatórios",
    "Two-factor authentication is not enforced for members of the following groups." : "A autenticação de dois fatores não é imposta aos membros dos seguintes grupos.",
    "Excluded groups" : "Grupos excluídos",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quando grupos são selecionados/excluídos, eles usam a seguinte lógica para determinar se um usuário tem 2FA forçado: Se nenhum grupo for selecionado, 2FA será habilitado para todos, exceto membros dos grupos excluídos. Se grupos são selecionados, 2FA é ativado para todos os membros deles. Se um usuário estiver em um grupo selecionado e excluído, o selecionado terá precedência e o 2FA será forçado.",
    "Save changes" : "Salvar mudanças",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar o uso de aplicativos a grupos",
    "No results" : "Sem resultados",
    "Update to {version}" : "Atualizar para {version}",
    "Remove" : "Excluir",
    "Disable" : "Desativar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não possui uma versão mínima atribuída para uso no Nextcloud. Isto poderá se converter em um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não possui uma versão máxima atribuida para uso no Nextcloud. Isto poderá se converter em um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Este aplicativo não pode ser instalado pois as seguintes dependências não forão cumpridas:",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar website",
    "Report a bug" : "Reportar um erro",
    "Admin documentation" : "Documentação do administrador",
    "Developer documentation" : "Documentação do desenvolvedor",
    "This app is supported via your current Nextcloud subscription." : "Este aplicativo é suportado pela sua assinatura atual do Nextcloud.",
    "Supported" : "Suportado",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Os aplicativos em destaque são desenvolvidos pela comunidade. Eles oferecem funcionalidade central e estão prontos para uso em produção.",
    "Featured" : "Destaques",
    "Update to {update}" : "Atualizar para {update}",
    "All apps are up-to-date." : "Todos os aplicativos estão atualizados.",
    "Results from other categories" : "Resultados de outras categorias",
    "No apps found for your version" : "Nenhum aplicativo encontrado para a sua versão",
    "Disable all" : "Desativar tudo",
    "Enable all" : "Ativar tudo",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicativo tem atualização disponível","%n aplicativos tem atualização disponível","%n aplicativos tem atualização disponível"],
    "_Update_::_Update all_" : ["Atualizar","Atualize tudo","Atualize tudo"],
    "Marked for remote wipe" : "Marcado para limpeza remota",
    "Device settings" : "Configuração dos dispositivos",
    "Allow filesystem access" : "Permitir acesso ao sistema de arquivos",
    "Rename" : "Renomear",
    "Revoke" : "Revogar",
    "Wipe device" : "Limpar o dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "A revogação deste token pode impedir a limpeza do seu dispositivo, caso ainda não tenha sido iniciada.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} aplicativo iOS",
    "{productName} Android app" : "{productName} Aplicativo Android",
    "{productName} Talk for iOS" : "{productName} Talk para iOS",
    "{productName} Talk for Android" : "{productName} Talk para Android ",
    "Sync client - {os}" : "Cliente de sincronização - {os}",
    "This session" : "Esta sessão",
    "Device" : "Dispositivo",
    "Last activity" : "Última atividade",
    "Devices & sessions" : "Dispositivos & sessões",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, desktop e móvel que estão conectados à sua conta.",
    "Do you really want to wipe your data from this device?" : "Quer realmente limpar seus dados deste dispositivo?",
    "Confirm wipe" : "Confirmar a limpeza",
    "Error while creating device token" : "Erro ao criar token de dispositivo",
    "Error while updating device token scope" : "Erro ao atualizar o escopo do token do dispositivo",
    "Error while updating device token name" : "Erro ao atualizar o nome do token do dispositivo",
    "Error while deleting the token" : "Erro ao excluir o token",
    "Error while wiping the device with the token" : "Erro ao limpar o dispositivo com o token",
    "App name" : "Nome do aplicativo",
    "Create new app password" : "Criar nova senha de aplicativo",
    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar seu aplicativo ou dispositivo.",
    "For security reasons this password will only be shown once." : "Por motivo de segurança, esta senha só será exibida uma vez.",
    "Username" : "Nome de Usuário",
    "Password" : "Senha",
    "Done" : "Concluído",
    "Show QR code for mobile apps" : "Exibir código QR para aplicativos móveis",
    "Copied!" : "Copiado!",
    "Copy" : "Copiar",
    "Could not copy app password. Please copy it manually." : "Não foi possível copiar a senha do aplicativo. Copie-a manualmente.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que o servidor funcione corretamente, é importante configurar corretamente os trabalhos em segundo plano. Cron é a configuração recomendada. Consulte a documentação para obter maiores informações.",
    "Last job execution ran {time}. Something seems wrong." : "A última execução do trabalho foi executada {time}. Algo parece errado.",
    "Last job ran {relativeTime}." : "A última tarefa foi executada {relativeTime}.",
    "Background job did not run yet!" : "O trabalho em segundo plano ainda não foi executado!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Execute uma tarefa com cada página carregada. Caso de uso: instância de usuário único.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php é registrado em um serviço webcron para chamar cron.php a cada 5 minutos por HTTP. Caso de uso: instância muito pequena (1–5 usuários dependendo do uso).",
    "Cron (Recommended)" : "Cron (Recomendado)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para executar isso, você precisa da extensão PHP POSIX. Veja a {linkstart} documentação do PHP {linkend} para mais detalhes.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Use o serviço cron do sistema para chamar o arquivo cron.php a cada 5 minutos. Recomendado para todas as instâncias.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "O cron.php precisa ser executado pelo usuário do sistema \"{user}\".",
    "Unable to update background job mode" : "Não foi possível atualizar o modo de trabalho em segundo plano",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new users." : "Habilite ou desabilite o perfil por padrão para novos usuários.",
    "Enable" : "Ativar",
    "Unable to update profile default setting" : "Não foi possível atualizar a configuração padrão do perfil",
    "Server-side encryption" : "Criptografia do lado do servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A criptografia do lado do servidor torna possível criptografar arquivos que são carregados para este servidor. Isso diminui um pouco o desempenho portanto habilite apenas se necessário.",
    "Enable server-side encryption" : "Ativar a criptografia do lado do servidor",
    "Please read carefully before activating server-side encryption:" : "Leia atentamente antes de ativar a criptografia do lado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez que a criptografia é ativada, todos os arquivos enviados ao servidor a partir desse ponto em diante serão criptografados e assim ficarão no servidor. Só será possível desativar a criptografia em uma data posterior se o módulo de criptografia ativo suportar essa função e todas as pré-condições sejam cumpridas (ex., defininindo uma chave de recuperação).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptografia por si só não garante a segurança do sistema. Por favor, veja a documentação para mais informações sobe como o aplicativo de criptografia funciona e os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Esteja ciente de que a criptografia sempre aumenta o tamanho do arquivo.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar backups regulares dos seus dados. No caso de criptografia, certifique-se de fazer backup das chaves de criptografia juntamente com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: Você realmente quer ativar a criptografia?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de criptografia carregado. Por favor, ative um deles no menu de aplicativos.",
    "Select default encryption module:" : "Selecione o módulo de criptografia padrão:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Você precisa migrar suas chaves de criptografia da criptografia antiga (ownCloud <= 8.0) para a nova. Ative o \"módulo de criptografia padrão\" e execute {command}",
    "Unable to update server side encryption config" : "Não foi possível atualizar a configuração de criptografia do lado do servidor",
    "Rename group" : "Renomear grupo",
    "Remove group" : "Excluir grupo",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Você está prestes a remover o grupo {group}. Os usuários NÃO serão apagados.",
    "Please confirm the group removal " : "Confirme a remoção do grupo",
    "Current password" : "Senha atual",
    "New password" : "Nova senha",
    "Change password" : "Alterar senha",
    "Your profile picture" : "Sua foto de perfil",
    "Upload profile picture" : "Carregar foto do perfil",
    "Choose profile picture from files" : "Escolha a foto do perfil dos arquivos",
    "Remove profile picture" : "Remover foto do perfil",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
    "Picture provided by original account" : "Imagem fornecida pela conta original",
    "Cancel" : "Cancelar",
    "Set as profile picture" : "Definir como imagem de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Observe que pode levar até 24 horas para que sua foto de perfil seja atualizada em todos os lugares.",
    "Choose your profile picture" : "Escolha sua foto de perfil",
    "Please select a valid png or jpg file" : "Selecione um arquivo png ou jpg válido",
    "Error setting profile picture" : "Erro ao definir a foto do perfil",
    "Error cropping profile picture" : "Erro ao recortar a foto do perfil",
    "Error saving profile picture" : "Erro ao salvar a foto do perfil",
    "Error removing profile picture" : "Erro ao remover a foto do perfil",
    "Your biography" : "Sua biografia",
    "Details" : "Detalhes",
    "You are a member of the following groups:" : "Você é membro dos seguintes grupos:",
    "You are using <strong>{usage}</strong>" : "Você está usando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Você está usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Seu nome completo",
    "Email options" : "Opções de e-mail ",
    "Primary email for password reset and notifications" : "E-mail principal para redefinição de senha e notificações ",
    "Remove primary email" : "Remover e-mail principal ",
    "Delete email" : "Excluir e-mail ",
    "Unset as primary email" : "Não definido como e-mail principal",
    "This address is not confirmed" : "Este endereço não foi confirmado",
    "Set as primary email" : "Definir como e-mail principal ",
    "Your email address" : "Seu endereço de e-mail",
    "Additional email address {index}" : "Endereço de e-mail adicional {index} ",
    "Unable to delete primary email address" : "Incapaz de deletar o endereço de e-mail primário",
    "Unable to update primary email address" : "Não foi possível atualizar o endereço de e-mail primário ",
    "Unable to add additional email address" : "Incapaz de adicionar endereço de e-mail adicional",
    "Unable to update additional email address" : "Não foi possível atualizar o endereço de e-mail adicional ",
    "Unable to delete additional email address" : "Incapaz de deletar endereços de e-mail adicionais",
    "No email address set" : "Nenhum endereço de e-mail foi configurado",
    "Additional emails" : "E-mails adicionais",
    "Your handle" : "Seu identificador",
    "Your headline" : "Seu título",
    "Language" : "Idioma",
    "Help translate" : "Ajude a traduzir",
    "Unable to update language" : "Não foi possível atualizar o idioma",
    "No language set" : "Nenhum conjunto de idiomas",
    "Locale" : "Localização",
    "Week starts on {firstDayOfWeek}" : "A semana começa em {firstDayOfWeek}",
    "Unable to update locale" : "Não foi possível atualizar a localidade",
    "No locale set" : "Nenhuma localidade definida",
    "Your location" : "Sua localização",
    "Your organisation" : "Sua organização",
    "Your phone number" : "Seu número de telefone",
    "Edit your Profile visibility" : "Edite a visibilidade do seu perfil",
    "Enable Profile" : "Habilitar Perfil",
    "Unable to update profile enabled state" : "Não é possível atualizar o estado de habilitação do perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "A configuração mais restritiva de visibilidade ou escopo é respeitada em seu perfil. Por exemplo, se a visibilidade for definida como \"Mostrar para todos\" e o escopo for definido como \"Privado\", \"Privado\" será respeitado.",
    "Unable to update visibility of {displayId}" : "Não foi possível atualizar a visibilidade de {displayId}",
    "Your role" : "Seu papel",
    "Your Twitter handle" : "Seu Twitter",
    "Your website" : "Seu website",
    "No {property} set" : "Nenhum conjunto de {property}",
    "Unable to update {property}" : "Não foi possível atualizar {property}",
    "Change scope level of {property}, current scope is {scope}" : "Alterar o nível de escopo de {property}, escopo atual é {scope}",
    "Unable to update federation scope of the primary {property}" : "Não foi possível atualizar o escopo da federação do primário {property}",
    "Unable to update federation scope of additional {property}" : "Não foi possível atualizar o escopo da federação de adicional {property}",
    "Add additional email" : "Adicionar e-mail adicional",
    "Add" : "Adicionar",
    "You do not have permissions to see the details of this user" : "Você não tem permissão para ver os detalhes deste usuário",
    "Add new password" : "Adicionar nova senha",
    "Add new email address" : "Adicionar novo endereço de e-mail",
    "Add user to group" : "Adicionar usuário ao grupo",
    "Set user as admin for" : "Definir como admin. para",
    "Select user quota" : "Selecionar a cota de usuário",
    "Delete user" : "Excluir usuário",
    "Wipe all devices" : "Limpar todos os dispositivos",
    "Disable user" : "Desativar usuário",
    "Enable user" : "Ativar usuário",
    "Resend welcome email" : "Reenviar e-mail de boas-vindas",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Em caso de perda do dispositivo ou saída da organização, pode-se limpar remotamente os dados do Nextcloud dos dispositivos associados ao {userid}. Só funciona se estiverem conectados à Internet.",
    "Remote wipe of devices" : "Limpeza remota de dispositivos",
    "Wipe {userid}'s devices" : "Limpar os dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Excluir a conta de {userid}, incluindo todos os arquivos pessoais, dados de aplicativos, etc",
    "Account deletion" : "Exclusão de conta",
    "Delete {userid}'s account" : "Excluir a conta de {userid}",
    "Welcome mail sent!" : "E-mail de boas-vindas enviado!",
    "Edit User" : "Editar Usuário",
    "Toggle user actions menu" : "Alternar o menu de ações do usuário",
    "{size} used" : "{size} usado",
    "New user" : "Novo usuário",
    "Will be autogenerated" : "Será autogerado",
    "Display name" : "Nome de exibição",
    "Email" : "E-mail",
    "Default language" : "Idioma padrão",
    "Add a new user" : "Adicione um novo usuário",
    "Group admin for" : "Admin. de grupo",
    "Quota" : "Cota",
    "User backend" : "Plataforma de serviço de usuário",
    "Storage location" : "Local do armazenamento",
    "Last login" : "Último acesso",
    "No users in here" : "Nenhum usuário aqui",
    "Default quota" : "Cota padrão",
    "Common languages" : "Idiomas comuns",
    "Other languages" : "Outros Idiomas",
    "Password change is disabled because the master key is disabled" : "A alteração de senha está desativada porque a chave mestra está desativada",
    "Passwordless authentication requires a secure connection." : "Autenticação sem senha necessita uma conexão segura.",
    "Add WebAuthn device" : "Adicionar dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorize seu dispositivo Webauthn.",
    "Name your device" : "Nomeie seu dispositivo",
    "Adding your device …" : "Adicionando seu dispositivo...",
    "Server error while trying to add WebAuthn device" : "Erro no servidor ao adicionar o dispositivo WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Erro no servidor ao finalizar o registro do dispositivo WebAuthn",
    "Unnamed device" : "Dispositivo sem nome",
    "Passwordless Authentication" : "Autenticação sem senha",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configure sua conta para autenticação sem senha, seguindo o padrão FIDO2.",
    "No devices configured." : "Nenhum dispositivo configurado.",
    "The following devices are configured for your account:" : "Os seguintes dispositivos estão configurados para sua conta:",
    "Your browser does not support WebAuthn." : "Seu navegador não suporta WebAuthn.",
    "Your apps" : "Seus aplicativos",
    "{license}-licensed" : "{license}-licenciado",
    "Changelog" : "Changelog",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Enter group name" : "Insira o nome do grupo",
    "Add group" : "Adicionar grupo",
    "Active users" : "Usuários ativos ",
    "Admins" : "Administradores",
    "Disabled users" : "Usuários desativados",
    "Default quota:" : "Cota padrão:",
    "Select default quota" : "Selecionar a cota padrão",
    "Show Languages" : "Exibir idiomas",
    "Show last login" : "Exibir último login",
    "Show user backend" : "Exibir plataforma de serviço de usuário",
    "Show storage path" : "Exibir caminho de armazenamento",
    "Send email to new user" : "Enviar um e-mail para o novo usuário",
    "Not saved" : "Não salvo",
    "Sending…" : "Enviando...",
    "Email sent" : "E-mail enviado",
    "Location" : "Localização",
    "Profile picture" : "Imagem do perfil",
    "About" : "Sobre",
    "Full name" : "Nome completo",
    "Additional email" : "E-mail adicional ",
    "Headline" : "Título",
    "Organisation" : "Organização",
    "Phone number" : "Número de telefone",
    "Role" : "Função",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (e.x. Mastodon)",
    "Website" : "Website",
    "Profile visibility" : "Visibilidade do perfil",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Não disponível porque esta propriedade é necessária para a funcionalidade principal, incluindo compartilhamento de arquivos e convites de calendário",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Não disponível como federação pois foi desabilitado para sua conta, entre em contato com seu administrador do sistema se tiver alguma dúvida",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Não disponível, pois a publicação de dados específicos do usuário no servidor de pesquisa não é permitida, entre em contato com o administrador do sistema se tiver alguma dúvida",
    "Active apps" : "Aplicativos ativados",
    "Disabled apps" : "Aplicativos desativados",
    "Updates" : "Atualizações",
    "App bundles" : "Pacotes de aplicativos",
    "Featured apps" : "Aplicativos em destaque",
    "Show to everyone" : "Mostrar para todos",
    "Show to logged in users only" : "Mostrar apenas para usuários conectados",
    "Hide" : "Esconder ",
    "Download and enable" : "Baixar e ativar",
    "Enable untested app" : "Ativar aplicativo não testado",
    "The app will be downloaded from the App Store" : "O aplicativo será baixado da App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Este aplicativo não está marcado como compatível com sua versão do Nextcloud. Se você continuar, ainda poderá instalar o aplicativo mas poderá não funcionar como esperado.",
    "Never" : "Nunca",
    "An error occurred during the request. Unable to proceed." : "Ocorreu um erro durante a solicitação. Não foi possível prosseguir.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "O aplicativo foi ativado, mas precisa ser atualizado. Você será redirecionado para a página de atualização em 5 segundos.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: Este aplicativo não pode ser habilitado pois torna o servidor instável.",
    "Documentation" : "Documentação",
    "Forum" : "Fórum",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Abrir documentação",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para poder enviar e-mails para redefinir a senha e notificações.",
    "Send mode" : "Modo de envio",
    "Encryption" : "Criptografia",
    "Sendmail mode" : "Modo do sendmail",
    "From address" : "Endereço \"From\"",
    "Server address" : "Endereço do servidor",
    "Port" : "Porta",
    "Authentication method" : "Método de autenticação",
    "Authentication required" : "Autenticação é necessária",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome do Usuário SMTP",
    "SMTP Password" : "Senha SMTP",
    "Save" : "Salvar",
    "Test and verify email settings" : "Testar e verificar as configurações de e-mail",
    "Send email" : "Enviar e-mail",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Para segurança e desempenho da sua instalação é importante que tudo esteja configurado corretamente. Para ajudá-lo com isso, estamos fazendo algumas verificações automáticas. Consulte a documentação para mais informações.",
    "All checks passed." : "Todas as verificações passaram.",
    "There are some errors regarding your setup." : "Existem alguns erros na configuração.",
    "There are some warnings regarding your setup." : "Existem alguns avisos na configuração.",
    "Checking for system and security issues." : "Verificando problemas de sistema e segurança.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Verifique novamente os <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">manuais de instalação ↗</a> e procure por erros ou avisos no <a href=\"%2$s\">log</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verifique a segurança do seu Nextcloud em <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nossa verificação de segurança ↗</a>.",
    "Version" : "Versão",
    "You need to enable the File sharing App." : "Você precisa habilitar o aplicativo de compartilhamento de arquivos.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, você pode ajustar o comportamento dos compartilhamentos. Consulte a documentação para obter mais informações.",
    "Allow apps to use the Share API" : "Permitir que aplicativos usem a API de compartilhamento",
    "Set default expiration date for shares" : "Definir data de validade padrão para compartilhamentos",
    "Expire after" : "Expira após",
    "day(s)" : "dia(s)",
    "Enforce expiration date" : "Fazer cumprir a data de expiração",
    "Set default expiration date for shares to other servers" : "Defina a data de expiração padrão para compartilhamentos com outros servidores",
    "Allow users to share via link and emails" : "Permitir que os usuários compartilhem via link e e-mails",
    "Allow public uploads" : "Permitir envio público",
    "Always ask for a password" : "Sempre pedir a senha",
    "Enforce password protection" : "Obrigar proteção com senha",
    "Exclude groups from password requirements:" : "Excluir grupos dos requerimentos de senha:",
    "Set default expiration date" : "Definir data de expiração padrão",
    "Exclude groups from creating link shares:" : "Impedir os seguintes grupos de criar compartilhamentos via link:",
    "Allow resharing" : "Permitir o recompartilhamento",
    "Allow sharing with groups" : "Permitir o compartilhamento com grupos",
    "Restrict users to only share with users in their groups" : "Restringir os usuários para compartilhar apenas com usuários em seus grupos",
    "Exclude groups from sharing" : "Impedir que alguns grupos compartilhem",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos ainda serão capazes de receber compartilhamentos, mas não iniciá-los.",
    "Allow username autocompletion in share dialog" : "Permitir autocompletar o nome de usuário na caixa de compartilhamento",
    "Allow username autocompletion to users within the same groups" : "Permitir autocompletar o nome de usuário para usuários dentro dos mesmos grupos",
    "Allow username autocompletion to users based on phone number integration" : "Permitir autocompletar o nome do usuário com base na integração do número de telefone",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Se autocompletar \"mesmo grupo\" e \"integração do número de telefone\" estiverem habilitadas, uma correspondência em qualquer um dos dois é suficiente para mostrar o usuário.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir preenchimento automático ao inserir o nome completo ou o endereço de e-mail (ignorando a correspondência ausente da agenda telefônica e estando no mesmo grupo)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Exibir o texto de aviso na página de envio do link público (somente mostrado quando a lista de arquivos está oculta).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será mostrado na página de envio do link público quando a lista de arquivos está oculta.",
    "Default share permissions" : "Permissões padrão de compartilhamento",
    "Reasons to use Nextcloud in your organization" : "Motivos para usar o Nextcloud na sua empresa.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela {communityopen}comunidade Nextcloud{linkclose}. O {githubopen}código-fonte{linkclose} é licenciado sob a {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Curta nossa página no Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Follow us on Mastodon" : "Siga-nos no Mastodon",
    "Check out our blog" : "Confira nosso blog",
    "Subscribe to our newsletter" : "Assine nosso boletim informativo",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis. ",
    "Use a second factor besides your password to increase security for your account." : "Use um segundo fator além de sua senha para aumentar a segurança da conta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Se usar aplicativos de terceiros para se conectar ao Nextcloud, certifique-se de criar e configurar uma senha para cada aplicativo antes de habilitar a autenticação em duas etapas.",
    "An error occurred while changing your language. Please reload the page and try again." : "Ocorreu um erro ao alterar seu idioma. Recarregue a página e tente novamente.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Ocorreu um erro ao alterar sua localidade. Rrecarregue a página e tente novamente.",
    "Select a profile picture" : "Selecione uma imagem para o perfil",
    "Week starts on {fdow}" : "A semana começa em {fdow}",
    "You created app password \"{token}\"" : "Você criou a senha de aplicativo \"{token}\"",
    "An administrator created app password \"{token}\"" : "Um administrador criou a senha do aplicativo \"{token}\"",
    "Couldn't remove app." : "Não foi possível excluir aplicativos.",
    "Couldn't update app." : "Não foi possível atualizar o aplicativo",
    "Backend doesn't support password change, but the user's encryption key was updated." : "A plataforma de serviço não suporta alteração de senha mas a chave de criptografia do usuário foi alterada.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Não foi possível determinar se a versão TLS de cURL está desatualizada ou não porque ocorreu um erro durante a solicitação HTTPS em https://nextcloud.com. Verifique o arquivo de log do nextcloud para obter mais detalhes.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves do OPcache é quase excedido. Para garantir que todos os scripts possam ser mantidos em cache, é recomendável aplicar <code>opcache.max_accelerated_files</code>para sua configuração PHP com um valor maior que <code>%s</code>.",
    "Admin privileges" : "Privilégios de administrador",
    "Unable to update biography" : "Incapaz de atualizar a biografia ",
    "Unable to update full name" : "Não foi possível atualizar o nome completo",
    "No full name set" : "Nenhum nome completo definido ",
    "Unable to update headline" : "Incapaz de atualizar o título ",
    "Unable to update organisation" : "Incapaz de atualizar a organização",
    "Unable to update role" : "Incapaz de atualizar a função ",
    "Change scope level of {accountProperty}" : "Alterar o nível de escopo de {accountProperty} ",
    "Unable to update federation scope of the primary {accountProperty}" : "Não é possível atualizar o escopo da federação do {accountProperty} principal ",
    "Unable to update federation scope of additional {accountProperty}" : "Não é possível atualizar o escopo da federação de {accountProperty} adicional ",
    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que esteja finalizada",
    "Migration started …" : "Migração iniciada...",
    "Address" : "Endereço",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Ocorreu um erro durante a requisição. Impossível continuar.",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gerenciador NT LAN",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Por favor, leia com atenção antes de ativar a criptografia do lado do servidor:",
    "Enable encryption" : "Ativar criptografia",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Você precisa migrar suas chaves de criptografia da antiga criptografia (ownCloud <= 8,0) para a nova. Por favor, ative o \"Módulo de criptografia padrão\" e execute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Você precisa migrar suas chaves de criptografia a partir da antiga criptografia (ownCloud <= 8,0) para a nova.",
    "Start migration" : "Iniciar migração",
    "Last job execution ran %s. Something seems wrong." : "Última tarefa rodou há %s. Algo parece errado.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Alguns trabalhos não são executados desde %s. Considere aumentar a frequência de execução.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Alguns trabalhos não são executados desde %s. Considere mudar para o cron do sistema.",
    "Last job ran %s." : "Última tarefa rodou há %s.",
    "Background job didn’t run yet!" : "O job em segundo plano ainda não rodou!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Para que o servidor funcione corretamente, é importante configurar corretamente os trabalhos em segundo plano. \"Cron\" é a configuração recomendada. Consulte a documentação para obter mais informações.",
    "Pick background job setting" : "Configuração de trabalhos em segundo plano",
    "Recommended" : "Recomendado",
    "The cron.php needs to be executed by the system user \"%s\"." : "O cron.php precisa ser executado pelo usuário de sistema \"%s\"",
    "Change privacy level of profile picture" : "Alterar o nível de privacidade da foto do perfil ",
    "Upload new" : "Enviar novo",
    "Select from Files" : "Selecionar de Arquivos",
    "Remove image" : "Remover imagem",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Observe que pode levar até 24 horas para que o avatar seja atualizado em todos os lugares.",
    "Choose as profile picture" : "Escolha como imagem de perfil",
    "You are using <strong>%s</strong>" : "Você está usando <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Você está usando <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of phone number" : "Alterar o nível de privacidade do número de telefone ",
    "Change privacy level of address" : "Alterar o nível de privacidade do endereço ",
    "Your postal address" : "Seu endereço de correspondência",
    "Change privacy level of website" : "Alterar o nível de privacidade do site ",
    "It can take up to 24 hours before the account is displayed as verified." : "Pode levar até 24 horas para que a conta seja mostrada como verificada.",
    "Link https://…" : "Link https://…",
    "Change privacy level of Twitter profile" : "Alterar o nível de privacidade do perfil do Twitter ",
    "Twitter handle @…" : "Twitter handle @…"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
