OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registros",
    "Log Reader" : "Lector del registro",
    "A log reader for Nextcloud" : "Un lector del registro para Nextcloud",
    "Log reader for Nextcloud" : "Lector del registro de Nextcloud",
    "Error parsing log" : "Error al analizar el registro",
    "Caused by " : "Causado por",
    "Debug" : "Depuración",
    "Info" : "Información",
    "Warning" : "Advertencia",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Copy" : "Copiar",
    "Copy raw" : "Copiar texto",
    "Copy formatted" : "Copiar con formato",
    "No server logs" : "No hay registros del servidor",
    "One or more entries are hidden by the log level filter" : "Una o más entradas están ocultas por el filtro de nivel del registro",
    "Everything is working fine" : "Todo está funcionando bien",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "Message" : "Mensaje",
    "Time" : "Hora",
    "Load log file" : "Cargar archivo de registro",
    "Invalid log file" : "Archivo de registro no válido",
    "Log levels" : "Niveles de registro",
    "Log content" : "Contenido del registro",
    "Live update" : "Mostrar en directo",
    "Download logs" : "Descargar registros"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
