OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Detectouse unha nova localización de acceso",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Detectouse un novo acceso na súa conta. O enderezo IP %s cualificouse como sospeitoso. Se foi vostede, pode ignorar esta mensaxe. Se non, debería cambiar o seu contrasinal.",
    "Suspicious Login" : "Acceso sospeitoso",
    "New login detected" : "Detectouse un novo acceso",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detectar e alertar sobre enderezos IP sospeitosos accedendo ao Nextcloud\n\t",
    "Suspicious login detection" : "Detección de accesos sospeitosos",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "A aplicación de detección de accesos sospeitosos está activa nesta instalación. Rexistraranse os enderezos IP dos usuarios que accedan e construirase un clasificador que alertará ao detectar un acceso dende un IP sospeitoso.",
    "Training data statistics" : "Estatísticas de datos de adestramento",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Polo de agora esta aplicación rexistrou {total} accesos (nos que se inclúen as conexións dos clientes), entre os cales hai {distinct} tuplas (IP, UID) distintas.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Estatísticas de modelos de clasificación",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Aínda non se adestrou ningún modelo de clasificador. Isto probabelmente significa que activou recentemente a aplicación. Por mor de que o adestramento dun modelo require uns bos datos, a aplicación agarda ata que se teñan capturados os inicios de sesión de polo menos {days} días.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Durante a avaliación, o último modelo (adestrado {time}) amosou capturar {recall}% de todos os inicios de sesión sospeitosos (lembrar), mentres que {precision}% dos inicios clasificados como sospeitosos son realmente sospeitosos (precisión). A seguir amosase unha vista do rendemento do modelo histórico.",
    "Precision" : "Precisión",
    "Recall" : "Lembrar"
},
"nplurals=2; plural=(n != 1);");
