OC.L10N.register(
    "files_external",
    {
    "External storage" : "外部儲存空間",
    "Personal" : "個人",
    "System" : "系統",
    "Grant access" : "授予存取權",
    "Error configuring OAuth1" : "設定 OAuth1 時發生錯誤",
    "Please provide a valid app key and secret." : "請提供有效的應用程式金鑰及密碼。",
    "Error configuring OAuth2" : "設定 OAuth2 時發生錯誤",
    "Generate keys" : "生成金鑰",
    "Error generating key pair" : "生成金鑰對時發生錯誤",
    "Type to select user or group." : "輸入以選取使用者或群組。",
    "(Group)" : "（群組）",
    "Compatibility with Mac NFD encoding (slow)" : "與 Mac 的 NFD 編碼相容（較慢）",
    "Enable encryption" : "啟用加密",
    "Enable previews" : "啟動預覽",
    "Enable sharing" : "啟動分享",
    "Check for changes" : "檢查變動",
    "Never" : "永不",
    "Once every direct access" : "在每次進行存取動作時",
    "Read only" : "唯讀",
    "Disconnect" : "解除連線",
    "Admin defined" : "管理員自訂",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "因為設定的儲存空間數量過多，自動狀態檢查被停用，點擊以檢查狀態",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "您確定要斷開這個外部儲存空間嗎？這將讓該儲存空間無法在 Nextcloud 中使用，並將會在目前連線的任何同步客戶端上刪除這些檔案與資料夾，但不會刪除外部儲存空間本身的任何檔案與資料夾。",
    "Delete storage?" : "刪除儲存空間？",
    "Saved" : "已儲存",
    "Saving …" : "正在儲存……",
    "Save" : "儲存",
    "Empty response from the server" : "伺服器回應為空",
    "Couldn't access. Please log out and in again to activate this mount point" : "無法存取。請登出並重新登入以啟用此掛載點",
    "Couldn't get the information from the remote server: {code} {type}" : "無法從遠端伺服器取得資訊：{code} {type}",
    "Couldn't get the list of external mount points: {type}" : "無法得到外部掛載點的列表：{type}",
    "There was an error with message: " : "錯誤訊息：",
    "External mount error" : "外部掛載錯誤",
    "external-storage" : "外部儲存空間",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "無法擷取 Windows 網路磁碟掛載點列表：來自伺服器的空回應",
    "Please enter the credentials for the {mount} mount" : "請輸入 {mount} 掛載的帳號密碼",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Credentials saved" : "已儲存認證資訊",
    "Credentials saving failed" : "認證資訊儲存失敗",
    "Credentials required" : "需要認證資訊",
    "Forbidden to manage local mounts" : "禁止管理本機掛載",
    "Storage with ID \"%d\" not found" : "沒有找到 ID 為「%d」的儲存空間 ",
    "Invalid backend or authentication mechanism class" : "無效的後端或認證機制類別",
    "Invalid mount point" : "無效的掛載點",
    "Objectstore forbidden" : "物件儲存禁止存取",
    "Invalid storage backend \"%s\"" : "無效的儲存後端「%s」",
    "Not permitted to use backend \"%s\"" : "不允許使用後端「%s」",
    "Not permitted to use authentication mechanism \"%s\"" : "不允許使用驗證機制「%s」",
    "Unsatisfied backend parameters" : "無法滿足後端所需的參數條件",
    "Unsatisfied authentication mechanism parameters" : "無法滿足驗證機制所需的參數條件",
    "Insufficient data: %s" : "資料不足：%s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "使用者無法編輯 ID 為「%d」的儲存空間",
    "Access key" : "存取金鑰",
    "Secret key" : "私鑰",
    "Builtin" : "內建",
    "None" : "無",
    "OAuth1" : "OAuth1",
    "App key" : "應用程式金鑰",
    "App secret" : "應用程式密碼",
    "OAuth2" : "OAuth2",
    "Client ID" : "客戶端 ID",
    "Client secret" : "客戶端密碼",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "租戶名稱",
    "Identity endpoint URL" : "身份識別端點 URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "網域",
    "Rackspace" : "Rackspace",
    "API key" : "API 金鑰",
    "Global credentials" : "全域認證資訊",
    "Log-in credentials, save in database" : "登入憑證，儲存於資料庫",
    "Username and password" : "使用者名稱和密碼",
    "Log-in credentials, save in session" : "登入資訊，儲存於工作階段",
    "Global credentials, user entered" : "全域認證資訊，使用者輸入",
    "User entered, store in database" : "使用者輸入，儲存於資料庫",
    "RSA public key" : "RSA 公開金鑰",
    "Public key" : "公開金鑰",
    "RSA private key" : "RSA 私鑰",
    "Private key" : "私鑰",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos 預設領域，預設為 \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos 票證 Apache 模式",
    "Kerberos ticket" : "Kerberos 票據",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "主機名稱",
    "Port" : "連接埠",
    "Region" : "地區",
    "Storage Class" : "儲存類型",
    "Enable SSL" : "啟用 SSL",
    "Enable Path Style" : "啟用路徑樣式",
    "Legacy (v2) authentication" : "舊版認證 (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "遠端子資料夾",
    "Secure https://" : "安全 https://",
    "FTP" : "FTP",
    "Host" : "主機",
    "Secure ftps://" : "安全 ftps://",
    "Local" : "本機",
    "Location" : "路徑",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "以私鑰登入 SFTP",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "分享",
    "Show hidden files" : "顯示隱藏的檔案",
    "Verify ACL access when listing files" : "列出檔案時驗證 ACL 存取權",
    "Check the ACL's of each file or folder inside a directory to filter out items where the user has no read permissions, comes with a performance penalty" : "檢查目錄中每個檔案或資料夾的 ACL，以過濾掉使用者沒有讀取權限的項目，但可能會影響效能",
    "Timeout" : "逾時",
    "SMB/CIFS using OC login" : "使用 OC 登入的 SMB/CIFS",
    "Username as share" : "以使用者名稱分享",
    "OpenStack Object Storage" : "OpenStack 物件儲存",
    "Service name" : "服務名稱",
    "Request timeout (seconds)" : "請求逾時（秒）",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP 的 cURL 支援未啟用或安裝。無法掛載 %s。請要求您的系統管理員安裝它。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP 的 FTP 支援未啟用或安裝。無法掛載 %s。請要求您的系統管理員安裝它。",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "「%1$s」未安裝。無法掛載 %2$s。請要求您的系統管理員安裝它。",
    "External storage support" : "外部儲存空間支援",
    "Adds basic external storage support" : "新增基本的外部儲存空間支援",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "此應用程式讓管理員可以設定到外部儲存空間提供者的連線，如 FTP 伺服器、S3 或 SWIFT 物件儲存、其他 Nextcloud 伺服器、WebDAV 伺服器與更多。管理員可以選擇要啟用的儲存空間類型，並可以為使用者、群組或整個系統掛載這些儲存位置。使用者將會在他們的 Nextcloud 根目錄看到一個新的資料夾，他們可以像其他 Nextcloud 資料夾那樣存取並使用該資料夾。外部儲存空間也允許使用者分享儲存在這些外部空間的檔案。在這種情況下，當收件者從外部儲存空間請求檔案時，將使用檔案擁有者的憑證來確保收件者可以存取被分享的檔案。\n\n可以使用圖形使用者介面或命令列設定外部儲存空間。後者提供了進階使用者更大的彈性，可用於設定大容量儲存空間的掛載並設定掛載屬性。更多資訊可在外部儲存空間圖形化使用者介面的文件與外部儲存空間設定檔文件中檢視。",
    "No external storage configured or you don't have the permission to configure them" : "未設定外部儲存空間，或您沒有權限設定它們",
    "Name" : "名稱",
    "Storage type" : "儲存空間類型",
    "Scope" : "範圍",
    "Open documentation" : "開啟文件",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "外部儲存空間讓您可以掛載外部儲存空間服務與裝置來作為次要的 Nextcloud 儲存裝置。您也可以允許使用者掛載他們自己的儲存服務。",
    "Folder name" : "資料夾名稱",
    "Authentication" : "驗證",
    "Configuration" : "設定",
    "Available for" : "可用的",
    "Click to recheck the configuration" : "點擊以重新檢查設定",
    "Add storage" : "新增儲存空間",
    "All users" : "所有使用者",
    "Advanced settings" : "進階設定",
    "Allow users to mount external storage" : "允許使用者自行掛載外部儲存空間",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "全域憑證可用於驗證多個有相同憑證的外部儲存空間。",
    "All users. Type to select user or group." : "所有使用者。輸入以選取使用者或群組。"
},
"nplurals=1; plural=0;");
