OC.L10N.register(
    "serverinfo",
    {
    "Shares" : "ການແບ່ງປັນ",
    "Copy" : "ສຳເນົາ",
    "Users" : "ຜູ້ໃຊ້",
    "1 hour" : "1 ຊົ່ວໂມງ",
    "Size" : "ຂະຫນາດ",
    "Available" : "ມີຢູ່",
    "Files" : "ຟາຍ",
    "Type" : "ພິມ"
},
"nplurals=1; plural=0;");
