OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Brakujące hasło klucza odzyskiwania",
    "Please repeat the recovery key password" : "Powtórz hasło klucza odzyskiwania",
    "Repeated recovery key password does not match the provided recovery key password" : "Hasła klucza odzyskiwania nie zgadzają się",
    "Recovery key successfully enabled" : "Klucz odzyskiwania został pomyślnie włączony",
    "Could not enable recovery key. Please check your recovery key password!" : "Nie można włączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Recovery key successfully disabled" : "Klucz odzyskiwania został pomyślnie wyłączony",
    "Could not disable recovery key. Please check your recovery key password!" : "Nie można wyłączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Missing parameters" : "Brakujące dane",
    "Please provide the old recovery password" : "Podaj stare hasło odzyskiwania",
    "Please provide a new recovery password" : "Podaj nowe hasło odzyskiwania",
    "Please repeat the new recovery password" : "Proszę powtórz nowe hasło odzyskiwania",
    "Password successfully changed." : "Zmiana hasła udana.",
    "Could not change the password. Maybe the old password was not correct." : "Nie można zmienić hasła. Może stare hasło nie było poprawne.",
    "Recovery Key disabled" : "Klucz odzyskiwania wyłączony",
    "Recovery Key enabled" : "Klucz odzyskiwania włączony",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nie można włączyć klucza odzyskiwania. Proszę spróbować ponownie lub skontakuj sie z administratorem",
    "Could not update the private key password." : "Nie można zmienić hasła klucza prywatnego.",
    "The old password was not correct, please try again." : "Stare hasło nie było poprawne. Spróbuj jeszcze raz.",
    "The current log-in password was not correct, please try again." : "Obecne hasło logowania nie było poprawne. Spróbuj ponownie.",
    "Private key password successfully updated." : "Pomyślnie zaktualizowano hasło klucza prywatnego.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nieprawidłowy klucz prywatny aplikacji szyfrującej. Zaktualizuj hasło klucza prywatnego w ustawieniach osobistych, aby odzyskać dostęp do zaszyfrowanych plików.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikacja szyfrująca jest włączona, ale Twoje klucze nie są zainicjowane. Proszę się wylogować i zalogować ponownie.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Aby móc korzystać z modułu szyfrowania trzeba włączyć w panelu administratora szyfrowanie po stronie serwera. ",
    "Encryption app is enabled and ready" : "Aplikacja szyfrująca jest włączona i gotowa",
    "Bad Signature" : "Zła sygnatura",
    "Missing Signature" : "Brakująca sygnatura",
    "one-time password for server-side-encryption" : "jednorazowe hasło do serwera szyfrowania strony",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odszyfrować tego pliku, prawdopodobnie jest to plik udostępniony. Poproś właściciela pliku o ponowne udostępnienie pliku.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odczytać tego pliku. Prawdopodobnie plik nie jest już udostępniony. Zwróć się do właściciela pliku, aby udostępnił go ponownie.",
    "Default encryption module" : "Domyślny moduł szyfrowania",
    "Default encryption module for server-side encryption" : "Domyślny moduł szyfrujący po stronie serwera",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "Aby korzystać z modułu szyfrowania, musisz włączyć opcję po stronie serwera\n\t\tszyfrowanie w ustawieniach administratora. Po włączeniu opcji moduł będzie szyfrował\n\t\twszystkie Twoje pliki w sposób transparentny. Szyfrowanie oparte jest na kluczach AES 256.\n\t\tModuł nie będzie ingerował w istniejące pliki, tylko nowe pliki będą szyfrowane\n\t\tpo włączeniu szyfrowania po stronie serwera. Nie jest to również możliwe\n\t\tponownie wyłączenie szyfrowania i przełączenie z powrotem do niezaszyfrowanego systemu.\n\t\tPrzeczytaj dokumentację, aby zapoznać się ze wszystkimi konsekwencjami, zanim podejmiesz decyzję\n\t\to włączeniu szyfrowania po stronie serwera.",
    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "Hej tam,\n\nAdministracja włączyła szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła \"%s\".\n\nZaloguj się do interfejsu internetowego, przejdź do sekcji \"Podstawowy moduł szyfrowania\" w ustawieniach osobistych i zaktualizuj swoje hasło szyfrowania, wprowadzając je w polu \"Stare hasło logowania\" i bieżące hasło logowania.\n\n",
    "The share will expire on %s." : "Udostępnienie wygaśnie w %s.",
    "Cheers!" : "Dzięki!",
    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "Hej tam,<br><br>Administracja włączyła szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła <strong>%s</strong>.<br><br>Zaloguj się do interfejsu internetowego, przejdź do sekcji \"Podstawowy moduł szyfrowania\" w ustawieniach osobistych i zaktualizuj swoje hasło szyfrowania, wprowadzając je w polu \"Stare hasło logowania\" i bieżące hasło logowania.<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Szyfrowanie w aplikacji jest włączone, ale klucze nie są zainicjowane. Prosimy wylogować się i ponownie zalogować się.",
    "Encrypt the home storage" : "Zaszyfruj magazyn główny",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Włączenie tej opcji spowoduje szyfrowanie wszystkich plików zapisanych na pamięci wewnętrznej. W innym wypadku szyfrowane będą tylko pliki na pamięci zewnętrznej.",
    "Enable recovery key" : "Włącz klucz odzyskiwania",
    "Disable recovery key" : "Wyłącz klucz odzyskiwania",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kluczem do odzyskiwania jest dodatkowy klucz szyfrujący, który służy do szyfrowania plików. Umożliwia on odzyskanie plików użytkownika, jeśli użytkownik zapomni swoje hasło.",
    "Recovery key password" : "Hasło klucza odzyskiwania",
    "Repeat recovery key password" : "Powtórz hasło klucza odzyskiwania",
    "Change recovery key password:" : "Zmień hasło klucza odzyskiwania",
    "Old recovery key password" : "Stare hasło klucza odzyskiwania",
    "New recovery key password" : "Nowe hasło klucza odzyskiwania",
    "Repeat new recovery key password" : "Powtórz nowe hasło klucza odzyskiwania",
    "Change Password" : "Zmień hasło",
    "Basic encryption module" : "Podstawowy moduł szyfrowania",
    "Your private key password no longer matches your log-in password." : "Hasło Twojego klucza prywatnego nie pasuje już do Twojego hasła logowania.",
    "Set your old private key password to your current log-in password:" : "Ustaw stare hasło klucza prywatnego na aktualne hasło logowania:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jeśli nie pamiętasz swojego starego hasła, poproś swojego administratora, aby odzyskać pliki.",
    "Old log-in password" : "Stare hasło logowania",
    "Current log-in password" : "Bieżące hasło logowania",
    "Update Private Key Password" : "Aktualizacja hasła klucza prywatnego",
    "Enable password recovery:" : "Włącz hasło odzyskiwania:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Włączenie tej opcji umożliwia otrzymać dostęp do zaszyfrowanych plików w przypadku utraty hasła",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
