OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ju aktivizuat vërtetimin TOTP të dyfishtë për llogarinë tuaj",
    "You disabled TOTP two-factor authentication for your account" : "Keni çaktivizuar vertëtimin me dy faktorë TOTP për llogarinë tënde",
    "TOTP (Authenticator app)" : "TOTP (Aplikacion autentifikues)",
    "Authenticate with a TOTP app" : "Mirëfilltësimin kryejeni me një aplikacion TOTP",
    "Enable TOTP" : "Aktivizo TOTP",
    "Could not enable TOTP" : "Nuk mund të aktivizohej TOTP",
    "Could not verify your key. Please try again" : "Çelësi juaj s'mund të verifikohej. Ju lutem provoni përsëri",
    "Authentication code" : "Kod mirëfilltësimi",
    "Verify" : "Verifiko",
    "Get the authentication code from the two-factor authentication app on your device." : "Merreni kodin e mirëfilltësimit pre aplikacionit të mirëfilltësimit dyfaktorësh te pajisja juaj.",
    "Submit" : "Dërgo"
},
"nplurals=2; plural=(n != 1);");
