OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Vous avez activé l'authentification à deux facteurs TOTP  pour votre compte",
    "You disabled TOTP two-factor authentication for your account" : "Vous avez désactivé l'authentification à deux facteurs TOTP  pour votre compte",
    "TOTP two-factor authentication disabled by an admin" : "L'authentification à deux facteurs TOTP a été désactivée par un administrateur",
    "TOTP (Authenticator app)" : "TOTP (Application d'authentification)",
    "Authenticate with a TOTP app" : "Authentification avec votre application TOTP",
    "Two-Factor TOTP Provider" : "Fournisseur de TOTP pour l'authentification en deux étapes",
    "TOTP two-factor provider" : "Fournisseur TOTP à deux facteurs",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un fournisseur d'authentification à deux facteurs pour TOTP (RFC 6238)",
    "Enable TOTP" : "Activer les mots de passe à usage unique (TOTP)",
    "Could not enable TOTP" : "Impossible d'activer les mots de passe à usage unique (TOTP)",
    "Could not verify your key. Please try again" : "Impossible de vérifier votre clé. Merci de réeessayer",
    "Your new TOTP secret is:" : "Votre nouveau secret TOTP est:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pour un paramétrage facile, scannez ce QR code avec votre application TOTP.",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Après avoir configuré votre application, entrez un code de test ci-dessous pour vous assurer que tout fonctionne correctement:",
    "Authentication code" : "Code d'authentification",
    "Verify" : "Vérifier",
    "Get the authentication code from the two-factor authentication app on your device." : "Récupérez un code d'authentification à partir de l'application d'authentification à deux facteurs de votre appareil.",
    "Submit" : "Envoyer"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
