OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Begin je dag goed geïnformeerd\n\nHet Nextcloud-dashboard is je startpunt van de dag en geeft een\noverzicht van je aanstaande afspraken, dringende e-mails, chatberichten,\ninkomende tickets, laatste tweets en nog veel meer! Gebruikers kunnen zelf widgets die ze leuk v indentoevoegen\nen de achtergrond naar hun zin veranderen.",
    "Customize" : "Aanpassen",
    "Edit widgets" : "Widgets bewerken",
    "Get more widgets from the App Store" : "Haal meer widgets op uit de App Store",
    "Weather service" : "Weerberichten",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Voor je privacy worden de weergegevens namens jou opgevraagd door je Nextcloud-server, zodat de weerservice geen persoonlijke informatie ontvangt.",
    "Weather data from Met.no" : "Weerbericht via Met.no",
    "geocoding with Nominatim" : "geocoding met Nominatim",
    "elevation data from OpenTopoData" : "hoogtedata via OpenTopoData",
    "Weather" : "Weer",
    "Status" : "Status",
    "Good morning" : "Goedemorgen",
    "Good morning, {name}" : "Goedemorgen, {name}",
    "Good afternoon" : "Goedemiddag",
    "Good afternoon, {name}" : "Goedemiddag, {name}",
    "Good evening" : "Goedenavond",
    "Good evening, {name}" : "Goedenavond, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Change background image" : "Wijzig achtergrondafbeelding",
    "Pick from Files" : "Kies uit Bestanden",
    "Default images" : "Standaardafbeeldingen",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}"
},
"nplurals=2; plural=(n != 1);");
