OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "Load average: {cpu} (last minute)" : "Moyenne de la charge : {cpu} (dernière minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes}/Utilisation actuelle : {memUsageBytes}",
    "RAM info not available" : "Informations sur la RAM non disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes}/Utilisation actuelle : {swapUsageBytes}",
    "SWAP info not available" : "L'information SWAP n'est pas disponible",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Pressez Ctrl-C pour copier.",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System:" : "Système d'exploitation:",
    "CPU:" : "CPU :",
    "Unknown Processor" : "Processeur inconnu",
    "Memory:" : "Mémoire :",
    "Server time:" : "Heure du serveur :",
    "Uptime:" : "Durée de fonctionnement :",
    "Temperature" : "Température",
    "Load" : "Charge",
    "Memory" : "Mémoire",
    "Disk" : "Disque",
    "Mount:" : "Montage :",
    "Filesystem:" : "Système de fichiers :",
    "Size:" : "Taille :",
    "Available:" : "Disponible :",
    "Used:" : "Utilisé :",
    "You will get a notification once one of your disks is nearly full." : "Vous recevrez une notification une fois que l’un de vos disques sera presque plein.",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname:" : "Nom d'hôte :",
    "DNS:" : "DNS :",
    "Gateway:" : "Passerelle :",
    "Status:" : "Statut :",
    "Speed:" : "Vitesse :",
    "Duplex:" : "Duplex :",
    "MAC:" : "MAC :",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Utilisateurs actifs",
    "Total users:" : "Nombre total d'utilisateurs :",
    "24 hours:" : "24 heures :",
    "1 hour:" : "1 heure :",
    "5 mins:" : "5 minutes :",
    "Shares" : "Partages",
    "Users:" : "Utilisateurs :",
    "Groups:" : "Groupes :",
    "Links:" : "Liens :",
    "Emails:" : "E-mails :",
    "Federated sent:" : "Offre de fédération envoyée :",
    "Federated received:" : "Offre de fédération reçue :",
    "Talk conversations:" : "Conversations Talk :",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory limit:" : "Limite de mémoire :",
    "Max execution time:" : "Max Execution Time:",
    "Upload max size:" : "Taille de téléversement maximale :",
    "Extensions:" : "Extensions :",
    "Unable to list extensions" : "Impossible de lister les extensions",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "External monitoring tool" : "Outil de surveillance externe",
    "You can connect an external monitoring tool by using this end point:" : "Vous pouvez connecter un outil de surveillance externe en utilisant ce point d'extrémité :",
    "Copy" : "Copier",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ajoutez \"?format=json\" à la fin de l'URL pour obtenir le résultat au format JSON. ",
    "To use an access token, please generate one then set it using the following command:" : "Pour utiliser un jeton d'accès, veuillez en générer un puis le définir à l'aide de la commande suivante :",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Puis transmettez le jeton avec l'entête \"NC-Token\" lorsque vous appelez l'URL.",
    "Users" : "Utilisateurs",
    "Groups" : "Groupes",
    "Links" : "Liens",
    "Emails" : "E-mails",
    "Federated sent" : "Offre de fédération envoyée",
    "Federated received" : "Offre de fédération reçue",
    "Talk conversations" : "Conversations orales",
    "24 hours" : "24 heures",
    "1 hour" : "1 heure",
    "5 mins" : "5 mins",
    "Copied!" : "Copié !",
    "Operating System" : "Système d'exploitation",
    "CPU" : "CPU",
    "Server time" : "Heure du serveur",
    "Uptime" : "Durée de fonctionnement",
    "Mount" : "Montage",
    "Filesystem" : "Système de fichiers",
    "Size" : "Taille",
    "Available" : "Disponible",
    "Used" : "Utilisé",
    "Files" : "Fichiers",
    "Storages" : "Stockages",
    "Free Space" : "Espace disponible",
    "Hostname" : "Nom de l'hôte",
    "DNS" : "DNS",
    "Gateway" : "Passerelle",
    "Status" : "État",
    "Speed" : "Vitesse",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Total users" : "Nombre total d'utilisateurs",
    "Version" : "Version",
    "Memory limit" : "Limite de mémoire",
    "Max execution time" : "Temps d'exécution maximum",
    "Upload max size" : "Taille maximale du téléchargement",
    "Type" : "Type",
    "You can connect an external monitoring tool by using this end point" : "Vous pouvez connecter un outil de surveillance externe en utilisant ce point de terminaison.",
    "To use an access token, please generate one then set it using the following command" : "Pour utiliser un token d'accès, veuillez en générer un puis le définir en utilisant la commande suivante"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
