OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Habilitesti l'autenticación en dos pasos de TOTP pa la to cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Deshabilitesti l'autenticación en dos pasos de TOTP pa la to cuenta",
    "TOTP (Authenticator app)" : "TOTP (aplicación autenticadora)",
    "Authenticate with a TOTP app" : "Autenticar con una aplicación TOTP",
    "Enable TOTP" : "Habilitar TOTP",
    "Could not enable TOTP" : "Nun pudo activase TOTP",
    "Could not verify your key. Please try again" : "Nun pudo verificase la to clave. Volvi tentalo, por favor",
    "Authentication code" : "Códigu de configuración",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Consigui'l códigu de l'aplicación d'autenticación en dos pasos nel to preséu.",
    "Submit" : "Unviar"
},
"nplurals=2; plural=(n != 1);");
