OC.L10N.register(
    "files_trashbin",
    {
    "Deleted files" : "الملفات المحذوفة",
    "restored" : "تمت الاستعادة",
    "Restore" : "استعيد",
    "Delete permanently" : "حذف بشكل دائم",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر, الرجاء مراجعة سجل الأخطاء أو الاتصال بمدير النظام",
    "No deleted files" : "لا يوجد ملفات محذوفة",
    "You will be able to recover deleted files from here" : "سوف تكون قادر على استعادة الملفات المحذوفة من هنا",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Name" : "اسم",
    "Actions" : "الإجراءات",
    "Deleted" : "تم الحذف",
    "Delete" : "إلغاء"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
