OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Idatzitako izena luzeegia da",
    "The given web address is too long" : "Idatzitako web helbidea luzeegia da",
    "The given web address is not a valid URL" : "Emandako web helbidea URL baliogabea da",
    "The given legal notice address is too long" : "Emandako lege-ohar helbidea luzeegia da",
    "The given legal notice address is not a valid URL" : "Emandako lege-ohar helbidea ez da baliozko URLa",
    "The given privacy policy address is too long" : "Emandako pribatutasun-gidalerro helbidea luzeegia da",
    "The given privacy policy address is not a valid URL" : "Emandako pribatutasun-gidalerro helbidea ez da baliozko URLa",
    "The given slogan is too long" : "Emandako leloa luzeegia da",
    "The given color is invalid" : "Emandako kolorea ez du balio",
    "Saved" : "Gordeta",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Kargatutako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kargatutako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka kargatu da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren karga gelditu du",
    "No file uploaded" : "Ez da fitxategirik kargatu",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Gai pertsonalizatua erabiltzen ari zara dagoeneko. Gaiaren aplikazioaren ezarpenak gainidatzi ditzake.",
    "Theming" : "Itxura",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "Dark theme with high contrast mode" : "Gai iluna kontraste handiko moduarekin",
    "Enable dark high contrast mode" : "Gaitu kontraste handiko modu iluna",
    "Similar to the high contrast mode, but with dark colours." : "Kontraste handiko moduaren antzekoa, baina kolore ilunekin.",
    "Dark theme" : "Gai iluna",
    "Enable dark theme" : "Gaitu gai iluna",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Gai iluna begiak arintzeko argitasuna eta distira orokorra murriztuz.",
    "System default theme" : "Sistemaren gai lehenetsia",
    "Enable the system default" : "Gaitu sistema lehenetsia",
    "Using the default system appearance." : "Sistemaren itxura lehenetsia erabiltzen.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "Enable dyslexia font" : "Gaitu dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da, dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "High contrast mode" : "Kontraste handiko modua",
    "Enable high contrast mode" : "Gaitu kontraste handiko modua",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste handiko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "Light theme" : "Gai argia",
    "Enable the default light theme" : "Gaitu gai argi lehenetsia",
    "The default light appearance." : "Itxura argi lehenetsia.",
    "Legal notice" : "Ohar legala",
    "Privacy policy" : "Pribatutasun politika",
    "Adjust the Nextcloud theme" : "Doitu Nextcloud gaia",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Gaiak aukera ematen du zure instantziaren eta onartutako bezeroen itxura eta izaera erraz pertsonalizatzeko. Hau erabiltzaile guztientzat ikusgai egongo da.",
    "Advanced options" : "Ezarpen aurreratuak",
    "Name" : "Izena",
    "Web link" : "Web esteka",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Slogan" : "Eslogana",
    "Color" : "Kolorea",
    "Logo" : "Logoa",
    "Upload new logo" : "Kargatu logo berria",
    "Legal notice link" : "Ohar legalaren esteka",
    "Privacy policy link" : "Pribatutasun politikaren esteka",
    "Header logo" : "Goiburuaren logoa",
    "Upload new header logo" : "Kargatu goiburuaren logo berria",
    "Favicon" : "Gogoko-ikonoa",
    "Upload new favicon" : "Kargatu gogoko-ikono berria",
    "User settings" : "Erabiltzaile ezarpenak",
    "Disable user theming" : "Desgaitu erabiltzaile itxura",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "Disable all keyboard shortcuts" : "Desgaitu teklatuaren lasterbide guztiak",
    "Background" : "Atzeko planoa",
    "Set a custom background" : "Ezarri atzeko planoko irudi pertsonalizatua",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sarbide unibertsala izatea oso garrantzitsua da guretzat. Web estadandarrak jarraitu eta guztia sagurik gabe erabili ahal izatea bermatzen dugu, pantaila-irakurle moduko software laguntzaileak barne. Helburu bezala jartzen dugu {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA mailan betetzea, kontraste altuko modua AAA mailaraino betez.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Arazoren bat aurkitzen baduzu, ez izan zalantzarik eta jakinarazi {issuetracker}gure arazoen jarraipena{linkend} zerbitzuan. Eta parte hartu nahi baduzu, etorri {designteam}gure diseinu taldera{linkend}!",
    "Change color" : "Aldatu kolorea",
    "Theme selection is enforced" : "Gaiaren hautaketa behartuta dago",
    "Select a custom color" : "Hautatu kolore pertsonalizatu bat",
    "Reset to default" : "Berezarri balio lehenetsira",
    "Upload" : "Kargatu",
    "Remove background image" : "Kendu atzeko-planoko irudia",
    "Loading preview…" : "Aurreikuspena kargatzen...",
    "Admin" : "Administratzailea",
    "Error uploading the file" : "Errorea fitxategia igotzen",
    "Name cannot be empty" : "Izena ezin da hutsik egon",
    "Open documentation" : "Ireki dokumentazioa",
    "https://…" : "https://…",
    "Login image" : "Saio-hasiera irudia",
    "Upload new login background" : "Kargatu saio-hasiera atzeko-plano berria",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu Imagemagick PHP luzapena SVG irudien laguntzarekin igotako logotipoan eta kolorean oinarritutako gogoko-ikonoak automatikoki sortzeko.",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Pick from Files" : "Hautatu fitxategietatik",
    "Default image" : "Irudi lehenetsia",
    "Custom color" : "Kolore pertsonalizatua",
    "Plain background" : "Atzeko plano arrunta",
    "Insert from {productName}" : "Txertatu hemendik: {productName}"
},
"nplurals=2; plural=(n != 1);");
