OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Megosztva a következővel: {email}",
    "Shared with {email} by {actor}" : "{actor} megosztotta vele: {email}",
    "Unshared from {email}" : "Megosztás visszavonva a következőtől: {email}",
    "Unshared from {email} by {actor}" : "{actor} visszavonta tőle a megosztást: {email}",
    "Password for mail share sent to {email}" : "Az e-mailes megosztáshoz szükséges jelszó elküldve a következőnek: {email}",
    "Password for mail share sent to you" : "Az e-mailes megosztáshoz szükséges jelszó elküldve Önnek",
    "You shared {file} with {email} by mail" : "{file} megosztva e-mailben a következővel: {email}",
    "{actor} shared {file} with {email} by mail" : "{actor} e-mailben megosztotta a(z) {file} elemet a következővel: {email}",
    "You unshared {file} from {email} by mail" : "E-mailben visszavonta a(z) {file} megosztását a következőtől: {email}",
    "{actor} unshared {file} from {email} by mail" : "{actor} e-mailben visszavonta a(z) {file} megosztását a következőtől: {email}",
    "Password to access {file} was sent to {email}" : "A(z) {file} eléréséhez szükséges jelszó elküldve a következőhöz: {email}",
    "Password to access {file} was sent to you" : "A(z) {file} eléréséhez szükséges jelszó elküldve Önnek",
    "Share by mail" : "Megosztás e-mailben",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "A(z) %1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Nem lehet az automatikusan előállított jelszót elküldeni. Állítson be érvényes e-mail-címet a személyes beállításokban, és próbálja újra.",
    "Failed to send share by email. Got an invalid email address" : "Az e-mailben történő megosztás sikertelen. Érvénytelen e-mail-cím.",
    "Failed to send share by email" : "Az e-mailben történő megosztás sikertelen",
    "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel a következőt: „%2$s”",
    "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel a következőt: „%2$s”.",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitásához.",
    "Open »%s«" : "„%s” megnyitása",
    "%1$s via %2$s" : "%1$s ezen keresztül: %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s megosztotta Önnel a következőt: „%2$s”.\nKapnia kellett egy külön e-mailt, amelyben megtalálhatja a hozzáférési hivatkozást.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s megosztotta Önnel a következőt: „%2$s”. Kapnia kellett egy külön e-mailt, amelyben megtalálhatja a hozzáférési hivatkozást.",
    "Password to access »%1$s« shared to you by %2$s" : "Jelszó a(z) %2$s által megosztott „%1$s” eléréséhez",
    "Password to access »%s«" : "Jelszó a(z) „%s” eléréséhez",
    "It is protected with the following password:" : "A következő jelszó védi:",
    "This password will expire at %s" : "Ez a jelszó ekkor jár le: %s.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta Önnel a(z) „%2$s” elemet, és a következőt fűzi hozzá:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta Önnel a(z) „%2$s” elemet, és a következőt fűzi hozzá",
    "»%s« added a note to a file shared with you" : "„%s” megjegyzést fűzött az Önnel megosztott fájlhoz",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Most osztotta meg a(z) „%1$s” elemet a következővel: %2$s. A megosztást már el lett küldve a címzettnek. A(z) %3$s rendszergazdája által meghatározott biztonsági házirend miatt minden megosztást jelszóval kell védeni, és nem szabad közvetlenül a címzettnek elküldeni a jelszót. Ezért kézzel kell a jelszót továbbítania a címzettnek.",
    "Password to access »%1$s« shared by you with %2$s" : "Jelszó a(z) „%1$s” elem eléréséhez, amelyet %2$s osztott meg Önnel",
    "This is the password:" : "Ez a jelszó:",
    "You can choose a different password at any time in the share dialog." : "Bármikor másik jelszót választhat a megosztási párbeszédablakon.",
    "Could not find share" : "Nem található a megosztás",
    "Share provider which allows you to share files by mail" : "Megosztási szolgáltató, amely lehetővé teszi fájlok e-mailben történő megosztását",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Lehetővé teszi, hogy a felhasználók személyre szabott megosztási hivatkozásokat hozzanak létre egy fájlhoz vagy mappához az e-mail-cím megadásával.",
    "Send password by mail" : "Jelszó kiküldése e-mailben",
    "Reply to initiator" : "Válasz a kezdeményezőnek",
    "Unable to update share by mail config" : "Az e-mailes megosztás beállításai nem frissíthetők",
    "Shared with %1$s" : "Megosztva a következővel: %1$s",
    "Shared with %1$s by %2$s" : "%2$s megosztotta a következővel: %1$s",
    "Unshared from %1$s" : "Megosztás visszavonva a következőtől: %1$s",
    "Unshared from %1$s by %2$s" : "%2$s visszavonta tőle a megosztást: %1$s",
    "Password for mail share sent to %1$s" : "Az e-mailes megosztáshoz szükséges jelszó elküldve a következőnek: %1$s",
    "You shared %1$s with %2$s by mail" : "%1$s megosztva e-mailben a következővel: %2$s",
    "%3$s shared %1$s with %2$s by mail" : "%3$s e-mailben megosztotta a(z) %1$s elemet a következővel: %2$s",
    "You unshared %1$s from %2$s by mail" : "E-mailben visszavonta a(z) %1$s megosztását a következőtől: %2$s",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s e-mailben visszavonta a(z) %1$s megosztását a következőtől: %2$s",
    "Password to access %1$s was sent to %2s" : "A(z) %1$s eléréséhez szükséges jelszó elküldve a következőhöz: %2s",
    "Password to access %1$s was sent to you" : "A(z) %1$s eléréséhez szükséges jelszó elküldve Önnek"
},
"nplurals=2; plural=(n != 1);");
