OC.L10N.register(
    "logreader",
    {
    "Logging" : "ورود به سیستم",
    "Log Reader" : "ورود به سیستم خواننده",
    "A log reader for Nextcloud" : "خواننده گزارش برای Nextcloud",
    "Log reader for Nextcloud" : "خواننده را برای Nextcloud وارد کنید",
    "Error parsing log" : "خطا در ثبت گزارش",
    "Caused by " : "ناشی از",
    "Info" : "اطلاعات",
    "Warning" : "هشدار",
    "Error" : "خطا",
    "Copy" : "کپی کردن",
    "Copy raw" : "کپی کردن خام",
    "Copy formatted" : "قالب کپی کنید",
    "No server logs" : "هیچ سرور ثبت نمی شود",
    "One or more entries are hidden by the log level filter" : "یک یا چند مدخل توسط فیلتر سطح ورود پنهان است",
    "Everything is working fine" : "همه چیز خوب است",
    "Level" : "ترک",
    "App" : "برنامه",
    "Message" : "پیام",
    "Time" : "زمان",
    "Log levels" : "سطح ورود به سیستم",
    "Log content" : "محتوا را وارد کنید",
    "Live update" : "به روز رسانی زنده",
    "Download logs" : "بارگیری لگاریتم"
},
"nplurals=2; plural=(n > 1);");
