<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  37525 => 'БеСТ',
  375292 => 'МТС',
  375294 => 'БелСел',
  375295 => 'МТС',
  375297 => 'МТС',
  375298 => 'МТС',
  37533 => 'МТС',
);
