OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Sevimlilər",
    "Shared with you" : "Shared with you",
    "Tags" : "Işarələr",
    "Save" : "Saxla",
    "Favorite" : "İstəkli",
    "Remove from favorites" : "Remove from favorites",
    "Add" : "Əlavə etmək",
    "Settings" : "Quraşdırmalar"
},
"nplurals=2; plural=(n != 1);");
