OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Скапіявана!",
    "Not supported!" : "Не падтрымліваецца!",
    "Press ⌘-C to copy." : "Націсніце ⌘-C для капіявання.",
    "Press Ctrl-C to copy." : "Націсніце Ctrl-C для капіявання.",
    "Copy to clipboard" : "Капіяваць у буфер абмену"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
