OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Takvim",
    "Calendar \"%s\"" : "\"%s\" takvimi",
    "Deck" : "Tahta",
    "Deck board \"%s\"" : "\"%s\" tahta panosu",
    "Files" : "Dosyalar",
    "File \"%s\"" : "\"%s\" dosyası",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "\"%s\" Talk görüşmesi",
    "Related Resources" : "İlişkili kaynaklar",
    "Displays resources related to current item in right panel" : "Geçerli öge ile ilişkili kaynaklar sağ panoda görüntülensin",
    "Displays resources related to current item in right panel." : "Bu seçenek etkinleştirildiğinde, geçerli öge ile ilişkili kaynaklar sağ panoda görüntülenir.",
    "Talk conversation" : "Talk görüşmesi",
    "Conversation with %s" : "%s ile görüşme"
},
"nplurals=2; plural=(n > 1);");
