OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Ogłoszenia Nextcloud",
    "Nextcloud announcement" : "Ogłoszenie Nextcloud",
    "Read more" : "Czytaj więcej",
    "Disable announcements" : "Wyłącz ogłoszenia",
    "(These announcements are only shown to administrators)" : "(Te ogłoszenia są wyświetlane tylko administratorom)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Ogłoszenia Nextcloud dostarczają najnowsze wiadomości z Nextcloud do powiadomień",
    "Shows the latest news of Nextcloud in your notifications." : "Pokazuj najnowsze wiadomości o Nextcloud w swoich powiadomieniach.",
    "These groups will be notified about the announcements." : "Grupy te będą powiadamiane o komunikatach."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
