OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Neznámá adresa",
    "No result." : "Bez výsledku.",
    "Malformed JSON data." : "Nesprávně formátovaná JSON data.",
    "Error" : "Chyba",
    "Weather status" : "Stav počasí",
    "Weather status in your dashboard" : "Stav počasí na vaší nástěnce",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Napojení ohledně stavu počasí pro aplikaci Nástěnka.\n    Polohu uživatele je možné zjistit automaticky nebo zadat ručně. Poté je zobrazována předpověď na příštích 6 hodin.\n    Tento stav je také možné začlenit do ostatních míst, jako například Kalendář.",
    "Detect location" : "Zjistit polohu",
    "Set custom address" : "Nastavit vlastní adresu",
    "Favorites" : "Oblíbené",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} bude jasná obloha",
    "{temperature} {unit} clear sky" : "{temperature} {unit} jasná obloha",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} bude zataženo",
    "{temperature} {unit} cloudy" : "{temperature} {unit} zataženo",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} bude hezky",
    "{temperature} {unit} fair weather" : "{temperature} {unit} krásné počasí",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} bude polojasno",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} polojasno",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} bude mlhavo",
    "{temperature} {unit} foggy" : "{temperature} {unit} mlhavo",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} bude drobně pršet",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} drobný déšť",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} bude pršet",
    "{temperature} {unit} rainfall" : "{temperature} {unit} déšť",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} bude vydatně pršet",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} hustý déšť",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} budou přeháňky",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} přeháňky",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} budou drobné přeháňky",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} drobné přeháňky",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} budou vydatné přeháňky",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} intenzivní přeháňky",
    "More weather for {adr}" : "Více o počasí pro {adr}",
    "Loading weather" : "Načítání údajů o počasí",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add as favorite" : "Přidat do oblíbených",
    "You are not logged in." : "Nejste přihlášení.",
    "There was an error getting the weather status information." : "Při získávání informací o stavu počasí došlo k chybě.",
    "No weather information found" : "Nenalezeny žádné údaje o počasí",
    "Location not found" : "Umístění nenalezeno",
    "There was an error setting the location address." : "Při nastavování adresy umístění došlo k chybě.",
    "There was an error setting the location." : "Při nastavování umístění došlo k chybě.",
    "There was an error saving the mode." : "Při ukládání režimu došlo k chybě.",
    "There was an error using personal address." : "Při použití vaší osobní adresy došlo k chybě.",
    "Set location for weather" : "Nastavit místo pro které předpovídat počasí"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
