OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "No se encontró la contraseña de la llave de recuperación",
    "Please repeat the recovery key password" : "Por favor reingresa la contraseña de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "Las contraseñas de la llave de recuperación no coinciden",
    "Recovery key successfully enabled" : "Llave de recuperación habilitada exitosamente",
    "Could not enable recovery key. Please check your recovery key password!" : "No fue posible habilitar la llave de recuperación. ¡Por favor comprueba la contraseña de tu llave de recuperación!",
    "Recovery key successfully disabled" : "Llave de recuperación deshabilitada exitosamente",
    "Could not disable recovery key. Please check your recovery key password!" : "No fue posible deshabilitar la llave de recuperación. ¡Por favor comprueba la contraseña de tu llave de recuperación!",
    "Missing parameters" : "Parámetros faltantes",
    "Please provide the old recovery password" : "Por favor proporciona tu contraseña de recuperación anterior",
    "Please provide a new recovery password" : "Por favor proporciona una nueva contraseña de recuperación",
    "Please repeat the new recovery password" : "Por favor reingresa la nueva contraseña de recuperación",
    "Password successfully changed." : "La contraseña ha sido cambiada exitosamente",
    "Could not change the password. Maybe the old password was not correct." : "No fue posible cambiar la contraseña. Por favor verifica que contraseña anterior sea correcta.",
    "Recovery Key disabled" : "Llave de recuperación deshabilitada",
    "Recovery Key enabled" : "Llave de recuperación habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "No fue posible habilitar la llave de recuperación, por favor intentalo de nuevo o contacta a tu administrador",
    "Could not update the private key password." : "No fue posible actualizar la contraseña de la llave privada.",
    "The old password was not correct, please try again." : "La contraseña anterior no es correcta, favor de intentar de nuevo. ",
    "The current log-in password was not correct, please try again." : "La contraseña actual para iniciar sesión fue incorrecta, por favor vuelvelo a intentar. ",
    "Private key password successfully updated." : "Contraseña de llave privada actualizada exitosamente.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "La llave de encripción privada es inválida para la aplicación de encripción. Por favor actualiza la contraseña de tu llave privada en tus configuraciones personales para recuperar el acceso a tus archivos encriptados. ",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "La aplicación de encripción está habilitada, pero tus llaves no han sido inicializadas. Por favor cierra sesión e inicia sesión de nuevo. ",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Por favor activa el encriptado del lado del servidor en los ajustes de administración para usar el módulo de encripción.",
    "Encryption app is enabled and ready" : "La aplicación de encripción se cuentra habilitada y lista",
    "Bad Signature" : "Firma equivocada",
    "Missing Signature" : "Firma faltante",
    "one-time password for server-side-encryption" : "Contraseña de una-sola-vez para la encripción del lado del servidor",
    "Default encryption module" : "Módulo de encripción predeterminado",
    "The share will expire on %s." : "El elemento compartido expirará el %s.",
    "Cheers!" : "¡Saludos!",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "La aplicación de encripción esta habilitada pero tus llaves no han sido inicializadas, por favor sal y vuelve a entrar a tu sesión",
    "Encrypt the home storage" : "Encriptar el almacenamiento de inicio",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Habilitar esta opción encripta todos los archivos almacenados en el almacenamiento principal, de otro modo, sólo los archivos en el almacenamiento externo serán encriptados",
    "Enable recovery key" : "Habilitar llave de recuperación",
    "Disable recovery key" : "Deshabilitar llave de recuperación",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "La llave de recuperación es una llave de encripción que se usa para encriptar archivos. Permite la recuperación de los archivos del usuario si este olvida su contraseña. ",
    "Recovery key password" : "Contraseña de llave de recuperación",
    "Repeat recovery key password" : "Repetir la contraseña de la llave de recuperación",
    "Change recovery key password:" : "Cambiar la contraseña de la llave de recuperación:",
    "Old recovery key password" : "Anterior contraseña de llave de recuperación",
    "New recovery key password" : "Nueva contraseña de llave de recuperación",
    "Repeat new recovery key password" : "Reingresar la nueva contraseña de llave de recuperación",
    "Change Password" : "Cambiar contraseña",
    "Basic encryption module" : "Módulo de encripción básica",
    "Your private key password no longer matches your log-in password." : "Tu contraseña de llave privada ya no corresónde con tu contraseña de inicio de sesión. ",
    "Set your old private key password to your current log-in password:" : "Establece tu contraseña de llave privada a tu contraseña actual de inicio de seisón:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Si no recuerdas tu contraseña anterior le puedes pedir a tu administrador que recupere tus archivos.",
    "Old log-in password" : "Contraseña anterior",
    "Current log-in password" : "Contraseña actual",
    "Update Private Key Password" : "Actualizar Contraseña de Llave Privada",
    "Enable password recovery:" : "Habilitar la recuperación de contraseña:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar esta opción te permitirá volver a tener acceso a tus archivos encriptados en caso de que pierdas la contraseña",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
