<?php
namespace Aws\RDSDataService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS RDS DataService** service.
 */
class RDSDataServiceException extends AwsException {}
