OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Άγνωστη διεύθυνση",
    "No result." : "Κανένα αποτέλεσμα.",
    "Malformed JSON data." : "Κακή μορφή δεδομένων JSON.",
    "Error" : "Σφάλμα",
    "Weather status" : "Κατάσταση καιρού",
    "Weather status in your dashboard" : "Κατάσταση καιρού στον πίνακα ελέγχου",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Η κατάσταση του καιρού ενσωματώνεται στην εφαρμογή Πίνακας ελέγχου.\n    Η θέση του χρήστη μπορεί να προσδιοριστεί αυτόματα ή να καθοριστεί χειροκίνητα. Στη συνέχεια εμφανίζεται μια πρόβλεψη 6 ωρών.\n    Αυτή η κατάσταση μπορεί επίσης να ενσωματωθεί σε άλλα μέρη όπως στην εφαρμογή Ημερολόγιο.",
    "Detect location" : "Εντοπισμός τοποθεσίας",
    "Set custom address" : "Ορισμός προσαρμοσμένης διεύθυνσης",
    "Favorites" : "Αγαπημένα",
    "{temperature} {unit} clear sky" : "{temperature} {unit} καθαρός ουρανός",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} συννεφιά αργότερα σήμερα",
    "{temperature} {unit} cloudy" : "{temperature} {unit} συννεφιά",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} αίθριος καιρός αργότερα σήμερα",
    "{temperature} {unit} fair weather" : "{temperature} {unit} αίθριος καιρός",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit}  λίγα σύννεφα αργότερα σήμερα",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} λίγα σύννεφα",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ομίχλη αργότερα σήμερα",
    "{temperature} {unit} foggy" : "{temperature} {unit} ομίχλη",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} ασθενείς βροχοπτώσεις αργότερα σήμερα",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} ασθενείς βροχοπτώσεις",
    "More weather for {adr}" : "Περισσότερος καιρός για {adr}",
    "Loading weather" : "Φόρτωση καιρού",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add as favorite" : "Προσθήκη ως αγαπημένο",
    "You are not logged in." : "Δεν έχετε συνδεθεί.",
    "There was an error getting the weather status information." : "Παρουσιάστηκε σφάλμα κατά τη λήψη των πληροφοριών σχετικά με την κατάσταση καιρού.",
    "No weather information found" : "Δεν βρέθηκαν πληροφορίες για τον καιρό",
    "Location not found" : "Δεν βρέθηκε η τοποθεσία",
    "There was an error setting the location address." : "Παρουσιάστηκε σφάλμα κατά τον καθορισμό της διεύθυνσης τοποθεσίας.",
    "There was an error setting the location." : "Παρουσιάστηκε σφάλμα κατά τη ρύθμιση της τοποθεσίας.",
    "There was an error saving the mode." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της λειτουργίας.",
    "There was an error using personal address." : "Παρουσιάστηκε σφάλμα κατά τη χρήση της προσωπικής διεύθυνσης.",
    "Set location for weather" : "Ορισμός τοποθεσίας καιρού"
},
"nplurals=2; plural=(n != 1);");
