OC.L10N.register(
    "files",
    {
    "File could not be found" : "Lêer kon nie gevind word nie",
    "Move or copy" : "Kopieer of skuif",
    "Download" : "Laai af",
    "Delete" : "Skrap",
    "Tags" : "Merkers",
    "Home" : "Tuis",
    "Close" : "Sluit",
    "Favorites" : "Gunstelinge",
    "Could not create folder \"{dir}\"" : "Kan nie vouer “{dir}” skep nie",
    "This will stop your current uploads." : "Dit sal u huidige oplaaie stop.",
    "Upload cancelled." : "Oplaai gekanselleer.",
    "Processing files …" : "Verwerk tans lêers …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan nie {filename} oplaai nie aangesien dit óf 'n gids is óf 0 grepe groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie genoeg oop spasie nie, u laai {size1} op maar slegs {size2} is oor",
    "Target folder \"{dir}\" does not exist any more" : "Teikengids \"{dir}\" bestaan nie meer nie",
    "Not enough free space" : "Nie genoeg oop spasie nie",
    "An unknown error has occurred" : "’n Onbekende fout het voorgekom",
    "Uploading …" : "Laai tans op …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Teikengids bestaan nie meer nie",
    "Actions" : "Aksies",
    "Rename" : "Hernoem",
    "Move" : "Skuif",
    "Copy" : "Kopieer",
    "Choose target folder" : "Kies teikenvouer",
    "Open" : "Open",
    "Delete file" : "Skrap lêer",
    "Delete folder" : "Skrap vouer",
    "Disconnect storage" : "Ontkoppel berging",
    "Could not load info for file \"{file}\"" : "Kon nie inligting vir lêer: “{file}” laai nie ",
    "Files" : "Lêers",
    "Details" : "Besonderhede",
    "Pending" : "Hangend",
    "Unable to determine date" : "Kan nie datum bepaal nie",
    "This operation is forbidden" : "Die operasie is verbode",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hierdie gids is onbeskikbaar, gaan die logs na of kontak die administrateur",
    "Storage is temporarily not available" : "Berging is tydelik onbeskikbaar",
    "Could not move \"{file}\", target exists" : "Kon nie \"{file}\" skuif nie, teiken bestaan",
    "Could not move \"{file}\"" : "Kon nie \"{file}\" skuif nie",
    "copy" : "kopie",
    "Could not copy \"{file}\", target exists" : "Kon nie \"{file}\" kopieer nie, teiken bestaan",
    "Could not copy \"{file}\"" : "Kon nie \"{file}\" kopieer nie",
    "Copied {origin} inside {destination}" : "{origin} binne {destination} gekopieer",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} en {nbfiles} ander lêers binne {destination} gekopieer",
    "{newName} already exists" : "{newName} bestaan reeds",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon nie “{fileName}” hernoem nie, dit bestaan nie meer nie",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Die naam “{targetName}” word reeds in vouer “{dir}” gebruik. Kies asb. ’n ander naam.",
    "Could not rename \"{fileName}\"" : "Kon nie “{file}” hernoem nie",
    "Could not create file \"{file}\"" : "Kan nie lêer “{file}” skep nie",
    "Could not create file \"{file}\" because it already exists" : "Kon nie lêer “{file}” skep nie omdat dit reeds bestaan",
    "Could not create folder \"{dir}\" because it already exists" : "Kon nie vouer “{dir}” skep nie omdat dit reeds bestaan",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Gewysig",
    "_%n folder_::_%n folders_" : ["%n gids","%n gidse"],
    "_%n file_::_%n files_" : ["%n lêer","%n lêers"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["insluitend %n verborge","insluitende %n verborge"],
    "_Uploading %n file_::_Uploading %n files_" : ["Laai tans %n lêer op ","Laai tans %n lêers op"],
    "{used} of {quota} used" : "{used} van {quota} gebruik",
    "{used} used" : "{used} gebruik",
    "\"{name}\" is an invalid file name." : "\"{name}\" is nie 'n geldige lêer naam nie.",
    "File name cannot be empty." : "Lêernaam kan nie leeg wees nie.",
    "\"/\" is not allowed inside a file name." : "\"/\" word nie binne 'n lêernaam toegelaat nie.",
    "View in folder" : "Vertoon in gids",
    "Path" : "Roete",
    "_%n byte_::_%n bytes_" : ["%n greep","%n grepe"],
    "Favorited" : "As gunsteling ",
    "Favorite" : "Gunsteling",
    "New folder" : "Nuwe gids",
    "Upload file" : "Laai lêer op",
    "Recent" : "Onlangs",
    "Not favorited" : "Nie as gunsteling",
    "Remove from favorites" : "Verwyder uit gunstelinge",
    "Add to favorites" : "Voeg by gunstelinge",
    "An error occurred while trying to update the tags" : "'n Fout het voorgekom terwyl die merkers opgedateer word",
    "Added to favorites" : "Tot gunstelinge bygevoeg",
    "Removed from favorites" : "Uit gunstelinge verwyder",
    "You added {file} to your favorites" : "U het {file} tot u gunstelinge bygevoeg",
    "You removed {file} from your favorites" : "U het {file} uit u gunstelinge verwyder",
    "File changes" : "Lêer veranderinge ",
    "Created by {user}" : "Geskep deur {user}",
    "Changed by {user}" : "Verander deur {user}",
    "Deleted by {user}" : "Geskrap deur {user}",
    "Restored by {user}" : "Herstel deur {user}",
    "Renamed by {user}" : "Naam verander deur {user}",
    "Moved by {user}" : "Geskuif deur {user}",
    "\"remote user\"" : "“afstandsgebruiker”",
    "You created {file}" : "U het {file} geskep",
    "{user} created {file}" : "{user} het {file} geskep",
    "{file} was created in a public folder" : "{file} is in 'n publieke gids geskep",
    "You changed {file}" : "U het {file} verander",
    "{user} changed {file}" : "{user} het {file} verander",
    "You deleted {file}" : "U het {file} geskrap",
    "{user} deleted {file}" : "{user} het {file} geskrap",
    "You restored {file}" : "U het {file} herstel",
    "{user} restored {file}" : "{user} het {file} herstel",
    "You renamed {oldfile} to {newfile}" : "U het die naam van {oldfile} na {newfile} verander",
    "{user} renamed {oldfile} to {newfile}" : "{user} het die naam van {oldfile} na {newfile} verander",
    "You moved {oldfile} to {newfile}" : "U het {oldfile} na {newfile} geskuif",
    "{user} moved {oldfile} to {newfile}" : "{user} het {oldfile} na {newfile} geskuif",
    "All files" : "Alle lêers",
    "Upload (max. %s)" : "Oplaai (maks. %s)",
    "Accept" : "Aanvaar",
    "in %s" : "in %s",
    "File Management" : "Lêerbestuur",
    "Unknown error" : "Onbekende fout",
    "Show hidden files" : "Vertoon verborge lêers ",
    "WebDAV" : "WebDAV",
    "Cancel" : "Kanselleer",
    "Create" : "Skep",
    "No files in here" : "Geen lêers hierbinne nie",
    "Upload some content or sync with your devices!" : "Laai 'n paar lêers op of sinchroniseer met u toestelle",
    "No entries found in this folder" : "Geen inskrwyings in hierdie gids gevind",
    "Select all" : "Merk alles",
    "Upload too large" : "Oplaai te groot",
    "No favorites yet" : "Tans geen gunstelinge ",
    "Files and folders you mark as favorite will show up here" : "Lêers en gidse wat u as gunsteling merk sal hier vertoon word",
    "Deleted files" : "Geskrapte lêers",
    "Shared with others" : "Gedeel met ander",
    "Shared with you" : "Met u gedeel",
    "Shared by link" : "Gedeel per skakel",
    "Text file" : "Tekslêer",
    "New text file.txt" : "Nuwe tekslêer.txt",
    "Storage invalid" : "Berging ongeldig",
    "Select" : "Kies",
    "You don’t have permission to upload or create files here" : "U het nie toestemming om lêers hier op te laai of te skep nie",
    "New" : "Nuwe",
    "Copied!" : "Gekopieer!",
    "Unlimited" : "Onbeperkte",
    "%s used" : "%s gebruik",
    "%1$s of %2$s used" : "%1$s van %2$s gebruik",
    "Settings" : "Instellings"
},
"nplurals=2; plural=(n != 1);");
