OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Paràmetres de la força bruta",
    "Whitelist IPs" : "Adreces IP permeses",
    "Brute Force Protection is meant to protect Nextcloud servers from attempts to\nguess user passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute force protection makes requests coming from an IP on a\nbruteforce protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of users on one IP address." : "La protecció contra atacs per força bruta serveix per a protegir els servidors del Nextcloud dels intents d'esbrinar\nles contrasenyes dels usuaris de diverses maneres. A més dels atacs obvis, com ara\n«provem aquesta llista immensa de contrasenyes més habituals», aquest servei també ajuda\na dificultar atacs més sofisticats que utilitzen el formulari de recuperació de la contrasenya\no que intenten trobar els testimonis de les contrasenyes d'aplicació.\n\nSi s'activa, la protecció contra la força bruta farà que les sol·licituds que provinguin d'una IP\nen un controlador protegit contra força bruta amb la mateixa API siguin més lentes durant un període de 24 hores.\n\nAmb aquesta aplicació, l'administrador pot excloure una adreça IP o un interval d'IP d'aquesta protecció,\nla qual cosa pot ser útil per a fer proves, o quan hi ha falsos positius perquè molts usuaris\nfan servir la mateixa adreça IP.",
    "Brute-force IP whitelist" : "Llista d'IP permeses per a la força bruta",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Per a afegir intervals d'IP a la llista d'adreces permeses per a la protecció contra la força bruta, especifiqueu-les a continuació. Tingueu en compte que qualsevol adreça IP que s'indiqui aquí podrà fer intents d'autenticació sense cap limitació. Per seguretat, es recomana que n'indiqueu el mínim possible o, idealment, cap.",
    "Add new whitelist" : "Afegeix una llista de permisos nova",
    "Add" : "Afegeix",
    "Delete" : "Suprimeix"
},
"nplurals=2; plural=(n != 1);");
