OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privasi",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Pusat privasi menunjukkan Anda di mana data Anda disimpan dan siapa yang dapat mengaksesnya, entah karena Anda membagikan dengan mereka atau karena mereka adalah administrator.",
    "Remove external {propertyName} admin" : "Hapus admin eksternal {propertyName}",
    "Add external admin" : "Tambahkan admin eksternal",
    "Name of external admin" : "Nama admin eksternal",
    "Adapt encryption" : "Adaptasi enkripsi",
    "This server is using full-disk-encryption." : "Server ini menggunakan enkripsi diska penuh.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Penyimpanan beranda Anda dienkripsi menggunakan {linkopen}enkripsi sisi server ↗{linkclose} dengan sebuah kunci utama. Ini berarti administrator dapat mengakses berkas Anda, tetapi tidak dapat melihat isinya.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Berkas Anda di penyimpanan eksternal dapat terenkripsi menggunakan {linkopen}enkripsi sisi server ↗{linkclose} dengan sebuah kunci utama berdasarkan konfigurasinya. ",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Penyimpanan beranda Anda dienkripsi menggunakan {linkopen}enkripsi sisi server ↗{linkclose} dengan kunci individu pengguna. Ini berarti administrator dapat mengakses berkas Anda, tetapi tidak dapat melihat isinya.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Berkas Anda di penyimpanan eksternal dapat terenkripsi menggunakan {linkopen}enkripsi sisi server ↗{linkclose} dengan kunci individu berdasarkan konfigurasinya.",
    "Additionally, this server is protected with full-disk-encryption." : "Secara tambahan, server ini dilindungi dengan enkripsi diska penuh.",
    "This server is protected with full-disk-encryption." : "Server ini dilindungi dengan enkripsi diska penuh.",
    "Your files are not protected by encryption." : "Berkas Anda tidak dilindungi oleh enkripsi.",
    "Your data is located in:" : "Data Anda disimpan di:",
    "The admin has not selected the location of the server yet." : "Admin belum memilih lokasi server.",
    "Change data location" : "Ubah lokasi data",
    "Please select a region" : "Mohon pilih sebuah wilayah",
    "You don't have any shares with individual users." : "Anda tidak memiliki pembagian dengan pengguna individu.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Uni Emirat Arab",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua dan Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartika",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Amerika",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Pulau Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia dan Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius dan Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Pulau Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Pulau Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Republik Demokrasi Kongo",
    "Central African Republic" : "Republik Afrika Tengah",
    "Congo" : "Congo",
    "Switzerland" : "Swiss",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Cook Islands" : "Pulau Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Pulau Natal",
    "Cyprus" : "Cyprus",
    "Czech" : "Czech",
    "Germany" : "Jerman",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Republik Dominika",
    "Algeria" : "Algeria",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Mesir",
    "West Sahara" : "Sahara Barat",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanyol",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Pulau Falkland",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Pulau Faroe",
    "France" : "Prancis",
    "Gabon" : "Gabon",
    "United Kingdom" : "Britania Raya",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Prancis",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinea Khatulistiwa",
    "Greece" : "Yunani",
    "South Georgia and the South Sandwich Islands" : "Georgia Selatan dan Kepulauan Sandwich Selatan",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Pulau Heard dan Kepulauan McDonald",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungaria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlandia",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Wilayah Samudra Hindia Inggris",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaika",
    "Jordan" : "Yordania",
    "Japan" : "Jepang",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizstan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts dan Nevis",
    "North Korea" : "Korea Utara",
    "South Korea" : "Korea Selatan",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kepulauan Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Kepulauan Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Kepulauan Mariana Utara",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maladewa",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Kaledonia Baru",
    "Niger" : "Niger",
    "Norfolk Island" : "Kepulauan Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Belanda",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Selandia Baru",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia Prancis",
    "Papua New Guinea" : "Papua Nugini",
    "Philippines" : "Filipina",
    "Pakistan" : "Pakistan",
    "Poland" : "Polandia",
    "Saint Pierre and Miquelon" : "Saint Pierre dan Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugis",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arab Saudi",
    "Solomon Islands" : "Kepulauan Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Swedia",
    "Singapore" : "Singapura",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension dan Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard dan Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan Selatan",
    "Sao Tome and Principe" : "Sao Tome dan Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Kepulauan Turks dan Caicos",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Pater S. Tanah Antartika",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turki",
    "Trinidad and Tobago" : "Trinidad dan Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Pulau Kecil Terluar Amerika Serikat",
    "United States" : "Amerika Serikat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent dan Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Kepulauan Virgin (Inggris)",
    "Virgin Islands (U.S.)" : "Kepulauan Virgin (AS)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis dan Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrika Selatan",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "Akun %s Anda",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Data Anda mewakili diri Anda dan dapat dengan mudah disalahgunakan. Kami di Nextcloud percaya bahwa Anda memiliki hak untuk memutuskan apa yang terjadi dengan data Anda. Nextcloud melindungi hak-hak Anda sebagaimana didefinisikan dalam Manifesto Data Pengguna!",
    "User Data Manifesto 2.0" : "Manifesto Data Pengguna 2.00",
    "Defining basic rights for people to control their own data in the internet age" : "Mendefinisikan hak-hak dasar bagi masyarakat untuk mengendalikan data mereka sendiri di era internet",
    "Control" : "Kendali",
    "over user data access" : "atas pengaksesan data pengguna",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data yang secara eksplisit dan dengan sukarela diunggah oleh pengguna harus berada di bawah kendali pengguna. Pengguna harus dapat memutuskan siapa yang akan diberikan akses langsung ke data mereka dan dengan izin dan lisensi apa akses tersebut harus diberikan.",
    "Knowledge" : "Pengetahuan",
    "of how the data is stored" : "bagaimana data disimpan",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Ketika data diunggah ke penyedia layanan tertentu, pengguna harus diberi tahu tentang di mana penyedia layanan tertentu tersebut menyimpan data, berapa lama, di yurisdiksi mana penyedia layanan tertentu tersebut beroperasi, dan hukum mana yang berlaku.",
    "Freedom" : "Kebebasan",
    "to choose a platform" : "untuk memilih sebuah platform",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Pengguna harus selalu dapat mengekstrak data mereka dari layanan kapan saja tanpa mengalami penguncian oleh vendor. Standar terbuka untuk format dan protokol diperlukan untuk menjamin hal ini.",
    "Learn more ↗" : "Pelajari lebih lanjut ↗",
    "Where is your data?" : "Di mana data Anda?",
    "Who has access to your data?" : "Siapa yang memiliki akses ke data Anda?",
    "Administrators" : "Administrator",
    "People you shared with" : "Orang yang Anda bagikan",
    "Privacy policy" : "Kebijakan privasi",
    "Read the privacy policy." : "Baca kebijakan privasi.",
    "Encryption" : "Enkripsi",
    "Remove external admin" : "Hapus admin eksternal",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Penyimpanan beranda Anda dienkripsi menggunakan {linkopen}enkripsi sisi server ↗{linkclose} dengan sebuah kunci utama.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Penyimpanan beranda Anda dienkripsi menggunakan {linkopen}enkripsi-sisi-server ↗{linkclose} dengan kunci pengguna individu."
},
"nplurals=1; plural=0;");
