<?php
namespace Aws\ResilienceHub\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Resilience Hub** service.
 */
class ResilienceHubException extends AwsException {}
