OC.L10N.register(
    "viewer",
    {
    "Edit" : "தொகுக்க",
    "Download" : "பதிவிறக்குக",
    "Delete" : "நீக்குக",
    "Name" : "பெயர்",
    "Save" : "சேமிக்க ",
    "Back" : "பின்னுக்கு",
    "Cancel" : "இரத்து செய்க",
    "Continue" : "Continue",
    "Value" : "Value",
    "Size" : "அளவு"
},
"nplurals=2; plural=(n != 1);");
