OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kалендар",
    "Calendar \"%s\"" : "Календар \"%s\"",
    "Deck" : "Набор",
    "Deck board \"%s\"" : "Deck табло \"%s\"",
    "Files" : "Файлове",
    "File \"%s\"" : "Файл \"%s\"",
    "Talk" : "Разговор",
    "Talk conversation \"%s\"" : "Talk разговори \"%s\"",
    "Related Resources" : "Свързани ресурси",
    "Displays resources related to current item in right panel" : "Показва ресурси, свързани с текущия елемент в десния панел",
    "Displays resources related to current item in right panel." : "Показва ресурси, свързани с текущия елемент в десния панел.",
    "Talk conversation" : "Talk разговор",
    "Conversation with %s" : "Разговор с %s"
},
"nplurals=2; plural=(n != 1);");
