OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "日曆",
    "Calendar \"%s\"" : "日曆「%s」",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Deck 看板「%s」",
    "Files" : "檔案",
    "File \"%s\"" : "檔案「%s」",
    "Talk" : "交談",
    "Talk conversation \"%s\"" : "交談對話「%s」",
    "Related Resources" : "相關資源",
    "Displays resources related to current item in right panel" : "在右側面板中顯示與目前項目相關的資源",
    "Displays resources related to current item in right panel." : "在右側面板中顯示與目前項目相關的資源。",
    "Talk conversation" : "Talk 對話",
    "Conversation with %s" : "與 %s 的對話"
},
"nplurals=1; plural=0;");
