OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Недавние контакты",
    "Contacts Interaction" : "Взаимодействие с контактами",
    "Manages interaction between users and contacts" : "Отслеживание взаимодейтсвей пользователей и контактов",
    "Collect data about user and contacts interactions and provide an address book for the data" : "Сбор данных о взаимодействиях пользователей и контактов и создание адресных книг на основе этих данных"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
