OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Rediañ stumm",
    "Whitelist IPs" : "Whitelist IPs",
    "Brute Force Protection is meant to protect Nextcloud servers from attempts to\nguess user passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute force protection makes requests coming from an IP on a\nbruteforce protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of users on one IP address." : "Brute Force Protection a zo graet evit gwarezi ho servijourioù Nextcloud eus\ndivin ger-tremenn un implijer en meur a doare. Estreget ar \"*klaskomp ar roll eus ar gerioù-tremenn implijet peurvuiañ*\",\n gwarez a ra ivez eus takgadennoù graet gant ar cheñch ger-tremenn \npe klask jedouer meziant ar ger-tremenn.\n\nMa ve distegnet, brute force protection a lak da dreiñ ar goulennoù eus controler an IP\ngwarezet gantañ gant  memes API da mont gorekoc'h e pad 24 heurvez.\n\nGant ar meziant mañ, galout a ra ar merour lakaat un IP pe er re IPoù da dreiñ en un doare boutiñ memstra pe a c'hell bezhañ mat evit amprouadennoù pe pa vez ditegnioù\nfaoz abalamour d'an niver a implijourien war ur chom-lec'h IP.",
    "Brute-force IP whitelist" : "Rediañ IP whitelist",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Evit lakaat ur strollad IP war ar whitelist adalek ar brute-force protection, lakit pere dindan. Pep IP war ar whitelist a hel klask gwiriekañ hep strizhadur. Blam d'ar surentez, gweloc'h eo lakaat war ar whitelist an neubetañ à implijourienn posuple, memes implijour ebet.",
    "Add new whitelist" : "Ouzhpennaén ur whitlist nevez",
    "Add" : "Ouzhpennañ",
    "Delete" : "Dilemel"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
