OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "您已將您的帳戶啟用了 TOTP 兩階段驗證",
    "You disabled TOTP two-factor authentication for your account" : "您已將您的帳戶停用了 TOTP 兩階段驗證",
    "TOTP two-factor authentication disabled by an admin" : "TOTP 兩階段驗證功能已被系統管理員停用",
    "TOTP (Authenticator app)" : "TOTP （驗證應用程式）",
    "Authenticate with a TOTP app" : "使用 TOTP 應用程式驗證身分",
    "Two-Factor TOTP Provider" : "雙因驗證 TOTP 碼提供者",
    "TOTP two-factor provider" : "TOTP 兩階段驗證供應商",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP 兩階段驗證裝置供應商 (RFC 6238)",
    "Enable TOTP" : "啟用 TOTP",
    "Could not enable TOTP" : "無法啟用 TOTP",
    "Could not verify your key. Please try again" : "無法驗證你的驗證碼，請重新再試",
    "Your new TOTP secret is:" : "您的新 TOTP 密鑰為：",
    "For quick setup, scan this QR code with your TOTP app:" : "使用你的 TOTP 應用程式掃描此QR碼可快速設定",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "當你設定好你的應用程式，請試著在下方輸入應用程式產生的驗證碼，以確保一切正常運作。",
    "Authentication code" : "驗證碼",
    "Verify" : "核對",
    "Get the authentication code from the two-factor authentication app on your device." : "從你裝置上的兩階段驗證應用程式取得驗證碼.",
    "Submit" : "送出"
},
"nplurals=1; plural=0;");
