<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  3892 => 'Skopje',
  38931 => 'Kumanovo/Kriva Palanka/Kratovo',
  38932 => 'Stip/Probistip/Sveti Nikole/Radovis',
  38933 => 'Kocani/Berovo/Delcevo/Vinica',
  38934 => 'Gevgelija/Valandovo/Strumica/Dojran',
  38942 => 'Gostivar',
  38943 => 'Veles/Kavadarci/Negotino',
  38944 => 'Tetovo',
  38945 => 'Kicevo/Makedonski Brod',
  38946 => 'Ohrid/Struga/Debar',
  389472 => 'Bitola/Demir Hisar/Resen',
  389474 => 'Bitola/Demir Hisar/Resen',
  389475 => 'Bitola/Demir Hisar/Resen',
  38947600 => 'Bitola/Demir Hisar/Resen',
  38947608 => 'Bitola/Demir Hisar/Resen',
  38947609 => 'Bitola/Demir Hisar/Resen',
  3894761 => 'Bitola/Demir Hisar/Resen',
  3894762 => 'Bitola/Demir Hisar/Resen',
  3894763 => 'Bitola/Demir Hisar/Resen',
  3894764 => 'Bitola/Demir Hisar/Resen',
  3894765 => 'Bitola/Demir Hisar/Resen',
  3894766 => 'Bitola/Demir Hisar/Resen',
  3894767 => 'Bitola/Demir Hisar/Resen',
  3894768 => 'Bitola/Demir Hisar/Resen',
  3894769 => 'Bitola/Demir Hisar/Resen',
  389478 => 'Bitola/Demir Hisar/Resen',
  389484 => 'Prilep/Krusevo',
  389485 => 'Prilep/Krusevo',
  3894861 => 'Prilep/Krusevo',
  3894862 => 'Prilep/Krusevo',
  3894863 => 'Prilep/Krusevo',
  3894864 => 'Prilep/Krusevo',
  3894865 => 'Prilep/Krusevo',
  3894866 => 'Prilep/Krusevo',
  3894867 => 'Prilep/Krusevo',
  3894868 => 'Prilep/Krusevo',
  3894869 => 'Prilep/Krusevo',
  389488 => 'Prilep/Krusevo',
);
