OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Pasahitza iraungi egin da, erabili pasahitz ahaztuak berrezartzeko metodoa",
    "Password must not have been used recently before." : "Pasahitzak azkenaldian erabili gabea izan behar du.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Pasahitz hori 1000000 pasahitz ohikoenen zerrendan dago. Sortu pasahitz berezi bat.",
    "Password is present in compromised password list. Please choose a different password." : "Pasahitz hau pasahitz ezagunen zerrenda batean dago. Aukeratu beste bat.",
    "Password needs to be at least %s characters long." : "Pasahitzak gutxienez %s karaktere izan behar ditu.",
    "Password needs to contain at least one numeric character." : "Pasahitzek zenbaki bat izan behar dute gutxienez.",
    "Password needs to contain at least one special character." : "Pasahitzek karaktere berezi bat izan behar dute gutxienez.",
    "Password needs to contain at least one lower and one upper case character." : "Pasahitzek hizki xehe eta hizki larri bana izan behar dute gutxienez.",
    "Password policy" : "Pasahitz politika",
    "Allows admins to configure a password policy" : "Baimendu administratzaileei pasahitzen politika bat konfiguratzea",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Baimendu administratzaileari pasahitzen inguruko baldintzak ezartzea, adib: luzera minimo bat izatera derrigortu.",
    "Minimum password length" : "Pasahitzaren gutxieneko luzera",
    "User password history" : "Erabiltzailearen pasahitz historia",
    "Number of days until user password expires" : "Erabiltzailearen pasahitza iraungi arteko egun kopurua",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Erabiltzaile kontua blokeatu aurretik saioa hasteko saiakera kopurua (0 mugarik ez ezartzeko) ",
    "Forbid common passwords" : "Pasahitz ohikoenak debekatu",
    "Enforce upper and lower case characters" : "Behartu hizki xehe eta larriak erabiltzera",
    "Enforce numeric characters" : "Behartu karaktere numerikoak erabiltzera",
    "Enforce special characters" : "Behartu karaktere bereziak erabiltzera",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Pasahitzak haveibeenpwned.com zerbitzuan egiaztatu",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Egiaztapen honek pasahitzaren hash bat sortzen du eta lehenengo bost karaktereak haveibeenpwned.com zerbitzuaren APIra bidaltzen ditu, berdin hasten diren hashak jasotzeko. Ondoren Nextcloud instantzia barruan egiaztatzen du pasahitzaren hasha zerrenda horretan dagoen ala ez.",
    "Unknown error" : "Errore ezezaguna",
    "Minimal length has to be a non negative number" : "Gutxieneko luzerak zenbaki ez negatiboa izan behar du",
    "History size has to be a non negative number" : "Historiaren tamainak zenbaki ez negatiboa izan behar du",
    "Expiration days have to be a non negative number" : "Iraungitze egun kopuruak zenbaki ez negatiboa izan behar du",
    "Maximum login attempts have to be a non negative number" : "Saioa hasteko saiakera mugak zenbaki ez negatiboa izan behar du",
    "Settings saved" : "Ezarpenak gordeta",
    "Saved" : "Gordeta",
    "Error while saving" : "Errore bat gertatu da gordetzean"
},
"nplurals=2; plural=(n != 1);");
