<?php
/**
 * This file has been @generated by a phing task from CLDR version 40.0.0.
 * See [README.md](README.md#generating-data) for more information.
 *
 * @internal Please do not require this file directly.
 * It may change location/format between versions
 *
 * Do not modify this file directly!
 */

return array (
  'AC' => 'Ìsula de s’Ascensione',
  'AD' => 'Andorra',
  'AE' => 'Emirados Àrabos Unidos',
  'AF' => 'Afghànistan',
  'AG' => 'Antigua e Barbuda',
  'AI' => 'Anguilla',
  'AL' => 'Albania',
  'AM' => 'Armènia',
  'AO' => 'Angola',
  'AQ' => 'Antàrticu',
  'AR' => 'Argentina',
  'AS' => 'Samoa americanas',
  'AT' => 'Àustria',
  'AU' => 'Austràlia',
  'AW' => 'Aruba',
  'AX' => 'Ìsulas Åland',
  'AZ' => 'Azerbaigiàn',
  'BA' => 'Bòsnia e Erzegòvina',
  'BB' => 'Barbados',
  'BD' => 'Bangladèsh',
  'BE' => 'Bèlgiu',
  'BF' => 'Burkina Faso',
  'BG' => 'Bulgaria',
  'BH' => 'Bahrein',
  'BI' => 'Burundi',
  'BJ' => 'Benin',
  'BL' => 'Santu Bartolomeu',
  'BM' => 'Bermudas',
  'BN' => 'Brunei',
  'BO' => 'Bolìvia',
  'BQ' => 'Caràibes olandesas',
  'BR' => 'Brasile',
  'BS' => 'Bahamas',
  'BT' => 'Bhutàn',
  'BW' => 'Botswana',
  'BY' => 'Bielorùssia',
  'BZ' => 'Belize',
  'CA' => 'Cànada',
  'CC' => 'Ìsulas Cocos (Keeling)',
  'CD' => 'Congo - Kinshasa',
  'CF' => 'Repùblica Tzentrafricana',
  'CG' => 'Congo - Bratzaville',
  'CH' => 'Isvìtzera',
  'CI' => 'Costa de Avòriu',
  'CK' => 'Ìsulas Cook',
  'CL' => 'Tzile',
  'CM' => 'Camerùn',
  'CN' => 'Tzina',
  'CO' => 'Colòmbia',
  'CR' => 'Costa Rica',
  'CU' => 'Cuba',
  'CV' => 'Cabu birde',
  'CW' => 'Curaçao',
  'CX' => 'Ìsula de sa Natividade',
  'CY' => 'Tzipru',
  'CZ' => 'Tzèchia',
  'DE' => 'Germània',
  'DG' => 'Diego Garcia',
  'DJ' => 'Gibuti',
  'DK' => 'Danimarca',
  'DM' => 'Dominica',
  'DO' => 'Repùblica Dominicana',
  'DZ' => 'Algeria',
  'EA' => 'Ceuta e Melilla',
  'EC' => 'Ècuador',
  'EE' => 'Estònia',
  'EG' => 'Egitu',
  'EH' => 'Sahara otzidentale',
  'ER' => 'Eritrea',
  'ES' => 'Ispagna',
  'ET' => 'Etiòpia',
  'FI' => 'Finlàndia',
  'FJ' => 'Fiji',
  'FK' => 'Ìsulas Falkland',
  'FM' => 'Micronèsia',
  'FO' => 'Ìsulas Føroyar',
  'FR' => 'Frantza',
  'GA' => 'Gabòn',
  'GB' => 'Regnu Unidu',
  'GD' => 'Grenada',
  'GE' => 'Geòrgia',
  'GF' => 'Guiana frantzesa',
  'GG' => 'Guernsey',
  'GH' => 'Ghana',
  'GI' => 'Gibilterra',
  'GL' => 'Groenlàndia',
  'GM' => 'Gàmbia',
  'GN' => 'Guinea',
  'GP' => 'Guadalupa',
  'GQ' => 'Guinea Ecuadoriale',
  'GR' => 'Grètzia',
  'GS' => 'Geòrgia de su Sud e Ìsulas Sandwich Australes',
  'GT' => 'Guatemala',
  'GU' => 'Guàm',
  'GW' => 'Guinea-Bissau',
  'GY' => 'Guyana',
  'HK' => 'RAS tzinesa de Hong Kong',
  'HN' => 'Honduras',
  'HR' => 'Croàtzia',
  'HT' => 'Haiti',
  'HU' => 'Ungheria',
  'IC' => 'Ìsulas Canàrias',
  'ID' => 'Indonèsia',
  'IE' => 'Irlanda',
  'IL' => 'Israele',
  'IM' => 'Ìsula de Man',
  'IN' => 'Ìndia',
  'IO' => 'Territòriu Britànnicu de s’Otzèanu Indianu',
  'IQ' => 'Iraq',
  'IR' => 'Iràn',
  'IS' => 'Islanda',
  'IT' => 'Itàlia',
  'JE' => 'Jersey',
  'JM' => 'Giamàica',
  'JO' => 'Giordània',
  'JP' => 'Giapone',
  'KE' => 'Kènya',
  'KG' => 'Kirghìzistan',
  'KH' => 'Cambòdia',
  'KI' => 'Kiribati',
  'KM' => 'Comoras',
  'KN' => 'Santu Cristolu e Nevis',
  'KP' => 'Corea de su Nord',
  'KR' => 'Corea de su Sud',
  'KW' => 'Kuwait',
  'KY' => 'Ìsulas Cayman',
  'KZ' => 'Kazàkistan',
  'LA' => 'Laos',
  'LB' => 'Lèbanu',
  'LC' => 'Santa Lughia',
  'LI' => 'Liechtenstein',
  'LK' => 'Sri Lanka',
  'LR' => 'Libèria',
  'LS' => 'Lesotho',
  'LT' => 'Lituània',
  'LU' => 'Lussemburgu',
  'LV' => 'Letònia',
  'LY' => 'Lìbia',
  'MA' => 'Marocu',
  'MC' => 'Mònacu',
  'MD' => 'Moldàvia',
  'ME' => 'Montenegro',
  'MF' => 'Santu Martine',
  'MG' => 'Madagascàr',
  'MH' => 'Ìsulas Marshall',
  'MK' => 'Matzedònia de su Nord',
  'ML' => 'Mali',
  'MM' => 'Myanmàr (Birmània)',
  'MN' => 'Mongòlia',
  'MO' => 'RAS tzinesa de Macao',
  'MP' => 'Ìsulas Mariannas setentrionales',
  'MQ' => 'Martinica',
  'MR' => 'Mauritània',
  'MS' => 'Montserrat',
  'MT' => 'Malta',
  'MU' => 'Maurìtzius',
  'MV' => 'Maldivas',
  'MW' => 'Malawi',
  'MX' => 'Mèssicu',
  'MY' => 'Malèsia',
  'MZ' => 'Mozambicu',
  'NA' => 'Namìbia',
  'NC' => 'Caledònia Noa',
  'NE' => 'Niger',
  'NF' => 'Ìsula Norfolk',
  'NG' => 'Nigèria',
  'NI' => 'Nicaràgua',
  'NL' => 'Paisos Bassos',
  'NO' => 'Norvègia',
  'NP' => 'Nèpal',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Zelanda Noa',
  'OM' => 'Omàn',
  'PA' => 'Pànama',
  'PE' => 'Perù',
  'PF' => 'Polinèsia frantzesa',
  'PG' => 'Pàpua Guinea Noa',
  'PH' => 'Filipinas',
  'PK' => 'Pàkistan',
  'PL' => 'Polònia',
  'PM' => 'Santu Predu e Miquelon',
  'PN' => 'Ìsulas Pìtcairn',
  'PR' => 'Puerto Rico',
  'PS' => 'Territòrios palestinesos',
  'PT' => 'Portogallu',
  'PW' => 'Palau',
  'PY' => 'Paraguày',
  'QA' => 'Catar',
  'RE' => 'Riunione',
  'RO' => 'Romania',
  'RS' => 'Sèrbia',
  'RU' => 'Rùssia',
  'RW' => 'Ruanda',
  'SA' => 'Aràbia Saudita',
  'SB' => 'Ìsulas Salomone',
  'SC' => 'Seychelles',
  'SD' => 'Sudàn',
  'SE' => 'Isvètzia',
  'SG' => 'Singapore',
  'SH' => 'Santa Elene',
  'SI' => 'Islovènia',
  'SJ' => 'Svalbard e Jan Mayen',
  'SK' => 'Islovàchia',
  'SL' => 'Sierra Leone',
  'SM' => 'Santu Marinu',
  'SN' => 'Senegal',
  'SO' => 'Somàlia',
  'SR' => 'Suriname',
  'SS' => 'Sudan de su Sud',
  'ST' => 'São Tomé e Príncipe',
  'SV' => 'El Salvador',
  'SX' => 'Sint Maarten',
  'SY' => 'Sìria',
  'SZ' => 'Eswatini',
  'TA' => 'Tristan da Cunha',
  'TC' => 'Ìsulas Turks e Caicos',
  'TD' => 'Chad',
  'TF' => 'Terras australes frantzesas',
  'TG' => 'Togo',
  'TH' => 'Tailàndia',
  'TJ' => 'Tagìkistan',
  'TK' => 'Tokelau',
  'TL' => 'Timor-Est',
  'TM' => 'Turkmènistan',
  'TN' => 'Tunisia',
  'TO' => 'Tonga',
  'TR' => 'Turchia',
  'TT' => 'Trinidad e Tobago',
  'TV' => 'Tuvalu',
  'TW' => 'Taiwàn',
  'TZ' => 'Tanzània',
  'UA' => 'Ucraina',
  'UG' => 'Uganda',
  'UM' => 'Ìsulas perifèricas de sos Istados Unidos',
  'US' => 'Istados Unidos',
  'UY' => 'Uruguày',
  'UZ' => 'Uzbèkistan',
  'VA' => 'Tzitade de su Vaticanu',
  'VC' => 'Santu Vissente e sas Grenadinas',
  'VE' => 'Venetzuela',
  'VG' => 'Ìsulas Vèrgines Britànnicas',
  'VI' => 'Ìsulas Vèrgines de sos Istados Unidos',
  'VN' => 'Vietnam',
  'VU' => 'Vanuatu',
  'WF' => 'Wallis e Futuna',
  'WS' => 'Samoa',
  'XK' => 'Kòssovo',
  'YE' => 'Yemen',
  'YT' => 'Mayotte',
  'ZA' => 'Sudàfrica',
  'ZM' => 'Zàmbia',
  'ZW' => 'Zimbabwe',
);
