OC.L10N.register(
    "files",
    {
    "File could not be found" : "파일을 찾을 수 없음",
    "Move or copy" : "이동이나 복사",
    "Download" : "다운로드",
    "Delete" : "삭제",
    "Tags" : "태그",
    "Show list view" : "리스트 보기",
    "Show grid view" : "그리드 보기",
    "Home" : "홈",
    "Close" : "닫기",
    "Favorites" : "즐겨찾기",
    "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
    "This will stop your current uploads." : "이것은 현재 업로드를 중단시킬 것입니다.",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "Processing files …" : "파일 처리중 ...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "남은 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 남아 있습니다",
    "Target folder \"{dir}\" does not exist any more" : "대상 폴더 \"{dir}\"이(가) 더 이상 존재하지 않습니다",
    "Not enough free space" : "남은 공간이 부족함",
    "An unknown error has occurred" : "알 수 없는 에러 발생",
    "File could not be uploaded" : "파일을 업로드할 수 없음",
    "Uploading …" : "업로드 중…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize}({bitrate})",
    "Uploading that item is not supported" : "이 항목의 업로드를 지원하지 않습니다",
    "Target folder does not exist any more" : "대상 폴더가 더 이상 존재하지 않습니다",
    "Operation is blocked by access control" : "접근 설정에 의해 동작이 차단됨",
    "Error when assembling chunks, status code {status}" : "조각을 모으는 중 오류 발생, 상태 코드 {status}",
    "Actions" : "작업",
    "Rename" : "이름 바꾸기",
    "Move" : "이동",
    "Copy" : "복사",
    "Choose target folder" : "폴더 선택",
    "Open" : "열기",
    "Delete file" : "파일 삭제",
    "Delete folder" : "폴더 삭제",
    "Disconnect storage" : "저장소 연결 해제",
    "Leave this share" : "이 공유에서 떠나기",
    "Could not load info for file \"{file}\"" : "파일 \"{file}\"의 정보를 가져올 수 없음",
    "Files" : "파일",
    "Details" : "자세한 정보",
    "Please select tag(s) to add to the selection" : "선택한 항목에 추가할 태그를 고르세요",
    "Apply tag(s) to selection" : "선택한 항목에 태그 적용하기",
    "Select directory \"{dirName}\"" : "디렉터리 \"{dirName}\" 선택",
    "Select file \"{fileName}\"" : "파일 \"{fileName}\" 선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "Storage is temporarily not available" : "저장소를 일시적으로 사용할 수 없음",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "copy" : "복사",
    "Could not copy \"{file}\", target exists" : "\"{file}\"을(를) 복사할 수 없음, 대상이 존재함",
    "Could not copy \"{file}\"" : "\"{file}\"을(를) 복사할 수 없음",
    "Copied {origin} inside {destination}" : "{origin}을(를) {destination}(으)로 복사함",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} 및 다른 파일 {nbfiles}개를 {destination}(으)로 복사함",
    "{newName} already exists" : "{newName}이(가) 이미 존재함",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "폴더 \"{dir}\" 내에 파일 \"{targetName}\"이(가) 이미 있습니다. 다른 이름을 사용하십시오.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
    "Could not fetch file details \"{file}\"" : "\"{file}\"의 세부사항을 불러올 수 없음",
    "Error deleting file \"{fileName}\"." : "파일 \"{fileName}\"을(를) 삭제할 수 없습니다.",
    "No search results in other folders for {tag}{filter}{endtag}" : "다른 폴더에 {tag}{filter}{endtag} 검색 결과가 없음",
    "Enter more than two characters to search in other folders" : "여러 폴더에서 검색하기 위해 2글자 이상 입력하십시오",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n개의 숨겨진 파일 포함"],
    "You do not have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New file/folder menu" : "새 파일/폴더 메뉴",
    "{used} of {quota} used" : "{quota} 중 {used} 사용함",
    "{used} used" : "{used} 사용함",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "\"/\" is not allowed inside a file name." : "파일 이름에 \"/\"를 사용할 수 없습니다.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\"은 허용된 파일 형식이 아님",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "그룹 폴더 \"{mountPoint}\"이(가) 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "외부 저장소 \"{mountPoint}\"이(가) 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files cannot be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "그룹 폴더 \"{mountPoint}\"이(가) 거의 가득 찼습니다({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "외부 저장소 \"{mountPoint}\"이(가) 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)." : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["'{filter}'와(과) 일치"],
    "View in folder" : "폴더에서 보기",
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n 바이트"],
    "Favorited" : "즐겨찾기에 추가됨",
    "Favorite" : "즐겨찾기",
    "Copy direct link (only works for users who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
    "You can only favorite a single file or folder at a time" : "한번에 한 파일 혹은 한 폴더만 즐겨찾기로 지정할 수 있습니다",
    "New folder" : "새 폴더",
    "Upload file" : "파일 업로드",
    "Recent" : "최근",
    "Not favorited" : "즐겨찾기에 없음",
    "Remove from favorites" : "즐겨찾기에서 삭제",
    "Add to favorites" : "즐겨찾기에 추가",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "Added to favorites" : "즐겨찾기에 추가됨",
    "Removed from favorites" : "즐겨찾기에서 삭제됨",
    "You added {file} to your favorites" : "내가 {file}을(를) 즐겨찾기에 추가함",
    "You removed {file} from your favorites" : "내가 {file}을(를) 즐겨찾기에서 삭제함",
    "File changes" : "파일 변경",
    "Created by {user}" : "{user} 님이 만듦",
    "Changed by {user}" : "{user} 님이 변경함",
    "Deleted by {user}" : "{user} 님이 삭제함",
    "Restored by {user}" : "{user} 님이 복원함",
    "Renamed by {user}" : "{user} 님이 이름을 변경함",
    "Moved by {user}" : "{user} 님이 이동함",
    "\"remote user\"" : "\"원격 사용자\"",
    "You created {file}" : "{file}을(를) 만듦",
    "You created an encrypted file in {file}" : "{file}에 암호화된 파일을 생성했습니다",
    "{user} created {file}" : "{user} 님이 {file}을(를) 만듦",
    "{user} created an encrypted file in {file}" : "{user}이(가) {file}에 암호화된 파일을 생성했습니다",
    "{file} was created in a public folder" : "공유 폴더에 {file}이(가) 생성됨",
    "You changed {file}" : "{file}을(를) 변경함",
    "You changed an encrypted file in {file}" : "{file}에 암호화된 파일을 변경했습니다",
    "{user} changed {file}" : "{user} 님이 {file}을(를) 변경함",
    "{user} changed an encrypted file in {file}" : "{user}이(가) {file}에 암호화된 파일을 변경했습니다",
    "You deleted {file}" : "{file}을(를) 삭제함",
    "You deleted an encrypted file in {file}" : "{file}에 암호화된 파일을 제거했습니다",
    "{user} deleted {file}" : "{user} 님이 {file}을(를) 삭제함",
    "{user} deleted an encrypted file in {file}" : "{user}이(가) {file}에 암호화된 파일을 제거했습니다",
    "You restored {file}" : "내가 {file}을(를) 복원함",
    "{user} restored {file}" : "{user} 님이 {file}을(를) 복원함",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (숨겨짐)을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (숨겨짐)을(를) {newfile}(으)로 이름을 바꿈",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "You renamed {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user}이(가) {oldfile} (숨겨짐)을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user}이(가) {oldfile} (숨겨짐)을(를) {newfile}(으)로 이름을 바꿈",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}이(가) {oldfile}을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "{user} renamed {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "You moved {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이동함",
    "{user} moved {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이동함",
    "A file has been added to or removed from your <strong>favorites</strong>" : "파일이 <strong>즐겨찾기</strong>에서 추가 또는 삭제됨",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "즐겨찾기된 파일이나 폴더가 <strong>변경됨</strong>",
    "All files" : "모든 파일",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "Accept" : "수락",
    "Reject" : "거절",
    "Incoming ownership transfer from {user}" : "{user}(으)로부터 들어오는 중인 소유권 이전",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path}을(를) 받아들이시겠습니까?\n\n참고: 전송 과정은 동의한 시점으로부터 최대 1시간 소요됩니다.",
    "Ownership transfer failed" : "소유권 이전 실패",
    "Your ownership transfer of {path} to {user} failed." : "{user}을(를) 향한 {path}의 소유권 이전에 실패했습니다.",
    "The ownership transfer of {path} from {user} failed." : "{user}(으)로부터 {path}의 소유권을 받는 것에 실패했습니다.",
    "Ownership transfer done" : "소유권 이전 완료",
    "Your ownership transfer of {path} to {user} has completed." : "{user}을(를) 향한 {path}의 소유권 이전을 완료했습니다.",
    "The ownership transfer of {path} from {user} has completed." : "{user}(으)로부터 {path}의 소유권을 받았습니다.",
    "in %s" : "%s",
    "File Management" : "파일 관리",
    "Transfer ownership of a file or folder" : "파일이나 폴더의 소유권 이전",
    "Choose file or folder to transfer" : "이전할 파일이나 폴더 고르기",
    "Change" : "변경",
    "New owner" : "새 소유자",
    "Search users" : "사용자 검색",
    "Choose a file or folder to transfer" : "이전할 파일이나 폴더 고르기",
    "Transfer" : "이전",
    "Transfer {path} to {userid}" : "{path}을(를) {userid}에게 이전하기",
    "Invalid path selected" : "잘못된 경로가 선택됨",
    "Unknown error" : "알 수 없는 오류",
    "Ownership transfer request sent" : "소유권 이전 요청이 전송됨",
    "Cannot transfer ownership of a file or folder you do not own" : "내가 소유하지 않은 파일이나 폴더의 소유권을 이전할 수 없음",
    "Files settings" : "파일 설정",
    "Show hidden files" : "숨김 파일 보이기",
    "Additional settings" : "고급 설정",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "클립보드로 복사",
    "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하십시오",
    "Unable to change the favourite state of the file" : "파일의 즐겨찾기 상태를 변경할 수 없음",
    "Error while loading the file data" : "파일 데이터를 불러오는 중 오류 발생",
    "Pick a template for {name}" : "{name}을(를) 위한 템플릿 선택",
    "Cancel" : "취소",
    "Create" : "생성",
    "Create a new file with the selected template" : "선택한 템플릿으로 새 파일 만들기",
    "Creating file" : "파일 만들기",
    "Blank" : "여백",
    "Unable to create new file from template" : "템플릿으로 새 파일을 만들 수 없음",
    "Set up templates folder" : "템플릿 폴더 설정",
    "Templates" : "템플릿",
    "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
    "Toggle grid view" : "모눈 보기 전환",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "No favorites yet" : "즐겨찾는 항목 없음",
    "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
    "Deleted files" : "삭제된 파일",
    "Shares" : "공유",
    "Shared with others" : "다른 사람과 공유됨",
    "Shared with you" : "나와 공유됨",
    "Shared by link" : "링크로 공유됨",
    "Deleted shares" : "삭제된 공유",
    "Pending shares" : "진행중인 공유",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt",
    "Storage invalid" : "저장소가 잘못됨",
    "Select" : "선택",
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "New" : "새로 만들기",
    "Copied!" : "복사 성공!",
    "Unlimited" : "무제한",
    "Cannot transfer ownership of a file or folder you don't own" : "내가 소유하지 않은 파일이나 폴더의 소유권을 이전할 수 없음",
    "%s used" : "%s 사용함",
    "%1$s of %2$s used" : "%2$s 중 %1$s 사용됨",
    "Settings" : "설정"
},
"nplurals=1; plural=0;");
