OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalender",
    "Calendar \"%s\"" : "Kalender \"%s\"",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Deck-tavla \"%s\"",
    "Files" : "Filer",
    "File \"%s\"" : "Fil \"%s\"",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "Talk-konversation \"%s\"",
    "Related Resources" : "Relaterade resurser",
    "Displays resources related to current item in right panel" : "Visar resurser relaterade till aktuellt objekt i den högra panelen",
    "Displays resources related to current item in right panel." : "Visar resurser relaterade till aktuellt objekt i den högra panelen.",
    "Talk conversation" : "Talk-konversation",
    "Conversation with %s" : "Konversation med %s"
},
"nplurals=2; plural=(n != 1);");
