OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Kopirano!",
    "Not supported!" : "Opravilo ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "First run wizard" : "Čarovnik prvega zagona",
    "Add your profile information! For example your email is needed to receive notifications." : "Dodajte podatke profila! Elektronski naslov mora biti vpisan za prejemanje obvestil.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Dodajte podatke profila! Elektronski naslov mora biti vpisan za prejemanje obvestil in ponastavitev gesla.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Dodajte svoje podatke profilu! Nastavite sliko profila in polno ime za lažje povezovanje v sistemu.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Dodajte podatke profila! Nastavite polno ime za lažje povezovanje v sistemu.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Dodajte svoje podatke profilu! Nastavite sliko profila za lažje povezovanje v sistemu.",
    "App recommendation: Nextcloud Calendar" : "Priporočilo programa: Koledar Nextcloud",
    "Schedule work & meetings, synced with all your devices." : "Načrtujte delo in sestanke, usklajene z vsemi vašimi napravami.",
    "App recommendation: Nextcloud Contacts" : "Priporočilo programa: Stiki Nextcloud",
    "Keep your colleagues and friends in one place without leaking their private info." : "Združite sodelavce in prijatelje na enem mestu brez skrbi za njihove zasebne podatke.",
    "App recommendation: Nextcloud Mail" : "Priporočilo programa: Pošta Nextcloud",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enostaven program za pošto se odlično povezuje z Datotekami, Stiki in Koledarjem.",
    "App recommendation: Tasks" : "Priporočilo programa: Naloge",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Usklajevanje in spletno urejanje nalog z različnih naprav v okolje Nextcloud.",
    "App recommendation: Deck" : "Priporočilo programa: Deck",
    "Kanban style organization for personal planning and team projects." : "Program za načrtovanje skupinskih projektov s slogu kanban.",
    "Smart media tagging for Nextcloud" : "Pametno označevanje predstavnih virov za Nextcloud",
    "App recommendation: Group folders" : "Priporočilo programa: Skupinske mape",
    "Admin-configured folders shared by everyone in a group." : "Skrbniško določene mape v souporabi vseh v skupini",
    "About" : "O programu",
    "A welcome and introduction wizard for Nextcloud" : "Čarovnik za dobrodošlico in uvod v delo z okoljem Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Program omogoči prikaz pojavnega okna, ko se uporabnik prvič prijavi v okolje Nextcloud. Ob pozdravnem besedilu so zbrane tudi povezave do namiznega odjemalca in programov za Android in iOS in do povezave za dostop do strežnika prek protokola WebDAV. Čarovnika je mogoče odpreti kadarkoli prek povezave »O programu« v meniju nastavitev.\nČarovnika je mogoče prilagoditi. Spremeniti je mogoče oblikovanje, povezave in sporočila. To storite tako, da izberete ustrezno temo in spremenite lastnosti. Več podrobnosti je na voljo v dokumentaciji čarovnika in dokumentaciji o prilagajanju teme.",
    "Start using {cloudName}" : "Začnite uporabljati oblak {cloudName}",
    "Welcome to {cloudName}!" : "Dobrodošli v oblaku {cloudName}!",
    "Extend your cloud" : "Razširite storitve v oblaku",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Prebrskajte med več kot 100 programi v trgovini Nextcloud in si prilagodite oblak:",
    "Groupware apps like Calendar, Contacts, Mail" : "Programi za vodenje skupinskega dela, kot so Koledar, Stiki in Pošta",
    "Communication with Nextcloud Talk" : "Pogovor z uporabo Nextcloud Talk",
    "Collaboration apps for document editing" : "Sodelovalni programi za urejanje dokumentov",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Varnostne funkcije, kot sta dvostopenjsko overjanje, enojno prijavljanje in zaščita pred vdori in krajo podatkov",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Mnogi so navdušeni tudi nad predvajalnikom glasbe, upravljalnikom gesel, programom za organizacijo nalog in enostavnim skupinskim urejevalnikom besedil.",
    "Browse the App Store" : "Prebrskaj po trgovini programov",
    "Stay in sync" : "Ostanite usklajeni",
    "Nextcloud gives you access to your files wherever you are." : "Okolje Nextcloud omogoča dostop do datotek, kjerkoli že ste.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Za uporabo na namizju in na mobilnih napravah so za različne sisteme na voljo samostojni usklajevalni programi.",
    "Get the apps to sync your files" : "Programi za usklajevanje datotek",
    "Desktop client" : "Odjemalec za namizne računalnike",
    "Android app on Google Play Store" : "Program za Android na Goggle Play Store",
    "Android app on F-Droid" : "Program za Android na F-Droid",
    "iOS app" : "Odjemalec za iOS",
    "Connect your desktop apps to %s" : "Povežite namizne programe z okoljem %s",
    "Connect your calendar" : "Poveži koledar",
    "Connect your contacts" : "Poveži stike",
    "Access files via WebDAV" : "Dostop do datotek z WebDAV",
    "Download macOS/iOS configuration profile" : "Prejmi nastavitveni profil za macOS/iOS",
    "Get help" : "Poišči pomoč",
    "Start contributing" : "Veliko lahko prispevate",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Ali bi želeli videti kakšno posebno posodobitev v oblaku Nextcloud? Ali ste morda naleteli na težave? Ali bi morda želeli pomagati pri prevajanju, promociji ali pripravi dokumentacije?",
    "Become part of the Community" : "Postanite del skupnosti.",
    "Enterprise support" : "Podpora za podjetja",
    "Get more information" : "Pridobite več podrobnosti",
    "The Nextcloud documentation for home users:" : "Dokumentacija NextCloud za uporabnike:",
    "User manual" : "Uporabniški priročnik",
    "Admin manual" : "Skrbniški priročnik",
    "Developer manual" : "Priročnik za razvijalce",
    "You can also ask for help in our community support channels:" : "Pomoč lahko najdete tudi na podpornih kanalih skupnosti:",
    "the Nextcloud forums" : "na forumih Nextcloud",
    "A safe home for all your data" : "varno okolje za vse vaše podatke",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Okolje Nextcloud omogoči zbiranje in shranjevanje podatkov pod vašim nadzorom. Dokumente, koledarje, stike in fotografije je mogoče shranjevani na strežniku podjetja, osebno, ali pri kateremkoli ponudniku, ki storitev omogoča. ",
    "Host your data and files where you decide" : "Shranjujte podatke in datoteke, kjer vi želite",
    "Learn more about %s" : "Raziščite dodatne možnosti okolja %s",
    "This Nextcloud is on version %s" : "Okolje Nextcloud deluje na različici %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "Spletni oblak %s omogoča dostop do datotek, kjerkoli že ste. Za uporabo na namizju in na mobilnih napravah so za različne sisteme na voljo samostojni usklajevalni programi.",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Nastavite si programe za usklajevanje in omogočite podporo za <a href=\"%s\">programska gesla</a>. S tem si zagotovite dostop tudi, če napravo izgubite.",
    "Connect other apps to %s" : "Povežite druge programe z okoljem %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Ob odjemalcih za usklajevanje je mogoča povezava okoljem %s tudi z drugo programsko opremo, ki podpira protokole WebDAV / CalDAV / CardDAV.",
    "Server address" : "Naslov strežnika",
    "Use this link to connect your apps and desktop client to this server:" : "Naslov za povezavo programa s strežnikom:",
    "Copy link" : "Kopiraj povezavo",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "App recommendation: Notes" : "App recommendation: Notes",
    "Distraction-free notes and writing." : "Enostavno beleženje in zapisovanje",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Če uporabljate oblak Nextcloud v produkcijskem okolju, gostite veliko uporabnikov in združujete večje količine podatkov, morda razmišljate tudi o zanesljivi podpori strokovnjakov, ki so tehnologijo zasnovali. Na voljo je poslovna naročnina, ki omogoča telefonsko podporo in ciljno pomoč po elektronski pošti.",
    "Get enterprise support" : "Pridobite podporo za podjetja",
    "the Nextcloud IRC chat channel on freenode.net" : "na klepetalnem kanalu Nextcloud IRC na freenode.net"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
