OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Anúncios Nextcloud",
    "Nextcloud announcement" : "Anúncio Nextcloud",
    "Read more" : "Ler mais",
    "Disable announcements" : "Desativar anúncios",
    "(These announcements are only shown to administrators)" : "(Estes anúncios são mostrados apenas aos administradores)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Anúncios Nexcloud trazem as notícias mais recentes às suas notificações",
    "Shows the latest news of Nextcloud in your notifications." : "Mostra as últimas notícias nas suas notificações.",
    "These groups will be notified about the announcements." : "Estes grupos serão notificados sobre anúncios."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
