OC.L10N.register(
    "password_policy",
    {
    "Password policy" : "سياسة الكلمة السرية",
    "Unknown error" : "خطأ غير معروف",
    "Settings saved" : "تم حفظ الإعدادات",
    "Saved" : "تم الحفظ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
