OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versiot",
    "This application automatically maintains older versions of files that are changed." : "Tämä sovellus säilyttää automaattisesti vanhempia versioita muuttuneista tiedostoista.",
    "Name this version" : "Nimeä tämä versio",
    "Edit version name" : "Muokkaa version nimeä",
    "Restore version" : "Palauta versio",
    "Download version" : "Lataa versio",
    "Delete version" : "Poista versio",
    "Version name" : "Version nimi",
    "Remove version name" : "Poista version nimi",
    "Save version name" : "Tallenna version nimi",
    "Initial version restored" : "Ensimmäinen versio palautettu",
    "Version restored" : "Versio palautettu",
    "Could not restore version" : "Versiota ei voitu palauttaa",
    "Could not set version name" : "Versionimeä ei voitu asettaa",
    "Could not delete version" : "Versiota ei voitu poistaa",
    "${version.label} restored" : "${version.label} palautettu",
    "Failed to revert {file} to revision {timestamp}." : "Tiedoston {file} palautus versioon {timestamp} epäonnistui.",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Restore" : "Palauta",
    "No other versions available" : "Ei muita versioita saatavilla"
},
"nplurals=2; plural=(n != 1);");
