OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Esat iespējojis TOTP divu faktoru autentifikāciju jūsu kontam",
    "You disabled TOTP two-factor authentication for your account" : "Esat atspējojis TOTP divu faktoru autentifikāciju jūsu kontam",
    "TOTP (Authenticator app)" : "TOTP (Autentifikācijas lietotne)",
    "Authenticate with a TOTP app" : "Autentificēties ar TOTP lietotni",
    "Enable TOTP" : "Iespējot TOTP",
    "Could not verify your key. Please try again" : "Nevarēja verificēt tavu atslēgu. Mēģini vēlreiz.",
    "Authentication code" : "Autentifikācijas kods",
    "Verify" : "Verificēt",
    "Get the authentication code from the two-factor authentication app on your device." : "Iegūstiet autentifikācijas kodu no divu faktoru autentifikācijas koda autentifikācijas jūsu ierīcē.",
    "Submit" : "Iesniegt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
