<?php
/**
 * This file has been @generated by a phing task from CLDR version 40.0.0.
 * See [README.md](README.md#generating-data) for more information.
 *
 * @internal Please do not require this file directly.
 * It may change location/format between versions
 *
 * Do not modify this file directly!
 */

return array (
  'AC' => 'Асенсион арал',
  'AD' => 'Андорра',
  'AE' => 'Арабын Нэгдсэн Эмирт Улс',
  'AF' => 'Афганистан',
  'AG' => 'Антигуа ба Барбуда',
  'AI' => 'Ангилья',
  'AL' => 'Албани',
  'AM' => 'Армени',
  'AO' => 'Ангол',
  'AQ' => 'Антарктид',
  'AR' => 'Аргентин',
  'AS' => 'Америкийн Самоа',
  'AT' => 'Австри',
  'AU' => 'Австрали',
  'AW' => 'Аруба',
  'AX' => 'Аландын арлууд',
  'AZ' => 'Азербайжан',
  'BA' => 'Босни-Герцеговин',
  'BB' => 'Барбадос',
  'BD' => 'Бангладеш',
  'BE' => 'Бельги',
  'BF' => 'Буркина Фасо',
  'BG' => 'Болгар',
  'BH' => 'Бахрейн',
  'BI' => 'Бурунди',
  'BJ' => 'Бенин',
  'BL' => 'Сент-Бартельми',
  'BM' => 'Бермуда',
  'BN' => 'Бруней',
  'BO' => 'Боливи',
  'BQ' => 'Карибын Нидерланд',
  'BR' => 'Бразил',
  'BS' => 'Багамын арлууд',
  'BT' => 'Бутан',
  'BW' => 'Ботсван',
  'BY' => 'Беларусь',
  'BZ' => 'Белизе',
  'CA' => 'Канад',
  'CC' => 'Кокос (Кийлинг) арлууд',
  'CD' => 'Конго-Киншаса',
  'CF' => 'Төв Африкийн Бүгд Найрамдах Улс',
  'CG' => 'Конго-Браззавиль',
  'CH' => 'Швейцарь',
  'CI' => 'Кот-д’Ивуар',
  'CK' => 'Күүкийн арлууд',
  'CL' => 'Чили',
  'CM' => 'Камерун',
  'CN' => 'Хятад',
  'CO' => 'Колумби',
  'CR' => 'Коста-Рика',
  'CU' => 'Куба',
  'CV' => 'Кабо-Верде',
  'CW' => 'Кюрасао',
  'CX' => 'Зул сарын арал',
  'CY' => 'Кипр',
  'CZ' => 'Чех',
  'DE' => 'Герман',
  'DG' => 'Диего Гарсиа',
  'DJ' => 'Джибути',
  'DK' => 'Дани',
  'DM' => 'Доминика',
  'DO' => 'Бүгд Найрамдах Доминикан Улс',
  'DZ' => 'Алжир',
  'EA' => 'Сеута ба Мелилья',
  'EC' => 'Эквадор',
  'EE' => 'Эстони',
  'EG' => 'Египет',
  'EH' => 'Баруун Сахар',
  'ER' => 'Эритрей',
  'ES' => 'Испани',
  'ET' => 'Этиоп',
  'FI' => 'Финлянд',
  'FJ' => 'Фижи',
  'FK' => 'Фолклендийн арлууд',
  'FM' => 'Микронези',
  'FO' => 'Фарерын арлууд',
  'FR' => 'Франц',
  'GA' => 'Габон',
  'GB' => 'Их Британи',
  'GD' => 'Гренада',
  'GE' => 'Гүрж',
  'GF' => 'Францын Гвиана',
  'GG' => 'Гернси',
  'GH' => 'Гана',
  'GI' => 'Гибралтар',
  'GL' => 'Гренланд',
  'GM' => 'Гамби',
  'GN' => 'Гвиней',
  'GP' => 'Гваделуп',
  'GQ' => 'Экваторын Гвиней',
  'GR' => 'Грек',
  'GS' => 'Өмнөд Жоржиа ба Өмнөд Сэндвичийн арлууд',
  'GT' => 'Гватемал',
  'GU' => 'Гуам',
  'GW' => 'Гвиней-Бисау',
  'GY' => 'Гайана',
  'HK' => 'БНХАУ-ын Тусгай захиргааны бүс Хонг Конг',
  'HN' => 'Гондурас',
  'HR' => 'Хорват',
  'HT' => 'Гаити',
  'HU' => 'Унгар',
  'IC' => 'Канарын арлууд',
  'ID' => 'Индонез',
  'IE' => 'Ирланд',
  'IL' => 'Израиль',
  'IM' => 'Мэн Арал',
  'IN' => 'Энэтхэг',
  'IO' => 'Британийн харьяа Энэтхэгийн далай дахь нутаг дэвсгэр',
  'IQ' => 'Ирак',
  'IR' => 'Иран',
  'IS' => 'Исланд',
  'IT' => 'Итали',
  'JE' => 'Жерси',
  'JM' => 'Ямайка',
  'JO' => 'Йордан',
  'JP' => 'Япон',
  'KE' => 'Кени',
  'KG' => 'Кыргызстан',
  'KH' => 'Камбож',
  'KI' => 'Кирибати',
  'KM' => 'Коморын арлууд',
  'KN' => 'Сент-Киттс ба Невис',
  'KP' => 'Хойд Солонгос',
  'KR' => 'Өмнөд Солонгос',
  'KW' => 'Кувейт',
  'KY' => 'Кайманы арлууд',
  'KZ' => 'Казахстан',
  'LA' => 'Лаос',
  'LB' => 'Ливан',
  'LC' => 'Сент Люсиа',
  'LI' => 'Лихтенштейн',
  'LK' => 'Шри-Ланка',
  'LR' => 'Либери',
  'LS' => 'Лесото',
  'LT' => 'Литва',
  'LU' => 'Люксембург',
  'LV' => 'Латви',
  'LY' => 'Ливи',
  'MA' => 'Морокко',
  'MC' => 'Монако',
  'MD' => 'Молдова',
  'ME' => 'Монтенегро',
  'MF' => 'Сент-Мартин',
  'MG' => 'Мадагаскар',
  'MH' => 'Маршаллын арлууд',
  'MK' => 'Хойд Македон',
  'ML' => 'Мали',
  'MM' => 'Мьянмар',
  'MN' => 'Монгол',
  'MO' => 'БНХАУ-ын Тусгай захиргааны бүс Макао',
  'MP' => 'Хойд Марианы арлууд',
  'MQ' => 'Мартиник',
  'MR' => 'Мавритани',
  'MS' => 'Монтсеррат',
  'MT' => 'Мальта',
  'MU' => 'Маврикий',
  'MV' => 'Мальдив',
  'MW' => 'Малави',
  'MX' => 'Мексик',
  'MY' => 'Малайз',
  'MZ' => 'Мозамбик',
  'NA' => 'Намиби',
  'NC' => 'Шинэ Каледони',
  'NE' => 'Нигер',
  'NF' => 'Норфолк арал',
  'NG' => 'Нигери',
  'NI' => 'Никарагуа',
  'NL' => 'Нидерланд',
  'NO' => 'Норвеги',
  'NP' => 'Балба',
  'NR' => 'Науру',
  'NU' => 'Ниуэ',
  'NZ' => 'Шинэ Зеланд',
  'OM' => 'Оман',
  'PA' => 'Панам',
  'PE' => 'Перу',
  'PF' => 'Францын Полинез',
  'PG' => 'Папуа Шинэ Гвиней',
  'PH' => 'Филиппин',
  'PK' => 'Пакистан',
  'PL' => 'Польш',
  'PM' => 'Сент-Пьер ба Микело',
  'PN' => 'Питкэрн арлууд',
  'PR' => 'Пуэрто-Рико',
  'PS' => 'Палестины нутаг дэвсгэр',
  'PT' => 'Португал',
  'PW' => 'Палау',
  'PY' => 'Парагвай',
  'QA' => 'Катар',
  'RE' => 'Реюнион',
  'RO' => 'Румын',
  'RS' => 'Серби',
  'RU' => 'Орос',
  'RW' => 'Руанда',
  'SA' => 'Саудын Араб',
  'SB' => 'Соломоны арлууд',
  'SC' => 'Сейшелийн арлууд',
  'SD' => 'Судан',
  'SE' => 'Швед',
  'SG' => 'Сингапур',
  'SH' => 'Сент Хелена',
  'SI' => 'Словени',
  'SJ' => 'Свалбард ба Ян Майен',
  'SK' => 'Словак',
  'SL' => 'Сьерра-Леоне',
  'SM' => 'Сан-Марино',
  'SN' => 'Сенегал',
  'SO' => 'Сомали',
  'SR' => 'Суринам',
  'SS' => 'Өмнөд Судан',
  'ST' => 'Сан-Томе ба Принсипи',
  'SV' => 'Эль Сальвадор',
  'SX' => 'Синт Мартен',
  'SY' => 'Сири',
  'SZ' => 'Эсватини',
  'TA' => 'Тристан да Кунъя',
  'TC' => 'Турк ба Кайкосын Арлууд',
  'TD' => 'Чад',
  'TF' => 'Францын өмнөд газар нутаг',
  'TG' => 'Того',
  'TH' => 'Тайланд',
  'TJ' => 'Тажикистан',
  'TK' => 'Токелау',
  'TL' => 'Тимор-Лесте',
  'TM' => 'Туркменистан',
  'TN' => 'Тунис',
  'TO' => 'Тонга',
  'TR' => 'Турк',
  'TT' => 'Тринидад ба Тобаго',
  'TV' => 'Тувалу',
  'TW' => 'Тайвань',
  'TZ' => 'Танзани',
  'UA' => 'Украин',
  'UG' => 'Уганда',
  'UM' => 'Америкийн Нэгдсэн Улсын бага арлууд',
  'US' => 'Америкийн Нэгдсэн Улс',
  'UY' => 'Уругвай',
  'UZ' => 'Узбекистан',
  'VA' => 'Ватикан хот улс',
  'VC' => 'Сент-Винсент ба Гренадин',
  'VE' => 'Венесуэл',
  'VG' => 'Британийн Виржиний арлууд',
  'VI' => 'АНУ-ын Виржиний арлууд',
  'VN' => 'Вьетнам',
  'VU' => 'Вануату',
  'WF' => 'Уоллис ба Футуна',
  'WS' => 'Самоа',
  'XK' => 'Косово',
  'YE' => 'Йемен',
  'YT' => 'Майотта',
  'ZA' => 'Өмнөд Африк',
  'ZM' => 'Замби',
  'ZW' => 'Зимбабве',
);
