OC.L10N.register(
    "twofactor_totp",
    {
    "TOTP (Authenticator app)" : "TOTP (Aplikasi autentikasi)",
    "Authenticate with a TOTP app" : "Autentikasi dengan aplikasi TOTP",
    "Verify" : "Verifikasi"
},
"nplurals=1; plural=0;");
