OC.L10N.register(
    "serverinfo",
    {
    "Size:" : "Maint:",
    "Type:" : "Math:",
    "Copy" : "Copïo",
    "Users" : "Defnyddwyr",
    "Groups" : "Grwpiau",
    "Size" : "Maint",
    "Available" : "Ar gael?",
    "Files" : "Ffeiliau",
    "Status" : "Statws",
    "Version" : "Fersiwn",
    "Type" : "Math"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
