OC.L10N.register(
    "settings",
    {
    "Private" : "Privaatne",
    "Local" : "Kohalik",
    "Federated" : "Federated",
    "Verify" : "Kontrolli",
    "Verifying …" : "Kontrollin ...",
    "Unable to change password" : "Ei suuda parooli muuta",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "Groups" : "Grupid",
    "{actor} added you to group {group}" : "{actor} lisas sind gruppi {group}",
    "You added {user} to group {group}" : "Sa lisasid {user} gruppi {group}",
    "{actor} added {user} to group {group}" : "{actor} lisas {user} gruppi {group}",
    "{actor} changed your password" : "{actor} muutis sinu parooli",
    "You changed your password" : "Sa muutsid oma parooli",
    "Your password was reset by an administrator" : "Administraator lähtestas sinu parooli",
    "{actor} changed your email address" : "{actor} muutis sinu e-posti aadressi",
    "You changed your email address" : "Sa muutsid oma e-posti aadressi",
    "Your email address was changed by an administrator" : "Administraator muutis sinu e-posti aadressi",
    "Security" : "Turvalisus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Logisid edukalt sisse, kasutades kaheastmelist autentimiset (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Sisselogimiskatse, kasutades kaheastmelist autentimist, ebaõnnestus (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sinu <strong>parooli</strong> või <strong>e-posti aadressi</strong> muudeti",
    "Apps" : "Rakendused",
    "Wrong password" : "Vale parool",
    "Saved" : "Salvestatud",
    "No user supplied" : "Kasutajat ei sisestatud",
    "Authentication error" : "Autentimise viga",
    "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
    "Federated Cloud Sharing" : "Jagamine liitpilves",
    "Administrator documentation" : "Administraatori dokumentatsioon",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Invalid SMTP password." : "Vale SMTP parool.",
    "Email setting test" : "E-posti sätete kontroll",
    "Well done, %s!" : "Suurepärane, %s!",
    "If you received this email, the email configuration seems to be correct." : "Kui saite selle kirja, näib e-posti seadistus õige.",
    "Email could not be sent. Check your mail server log" : "E-posti ei saanud saata. Kontrollige oma meiliserveri logi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posti saatmisel ilmnes viga. Palun kontrollige seadeid. (Viga: %s)",
    "Users" : "Kasutajad",
    "Invalid user" : "Vigane kasutaja",
    "Invalid mail address" : "Vigane e-posti aadress",
    "Settings saved" : "Seaded salvestatud",
    "Unable to change full name" : "Täispika nime muutmine ebaõnnestus",
    "Unable to change email address" : "E-posti aadressi muutmine ebaõnnestus",
    "%1$s changed your password on %2$s." : "%1$s muutis su parooli %2$s.",
    "Your password on %s was changed." : "Sinu %s parool muudeti.",
    "Your password on %s was reset by an administrator." : "Administraator lähtestas sinu %s parooli.",
    "Password for %1$s changed on %2$s" : "%1$s parool muudetud %2$s",
    "Password changed for %s" : "%s parool muudetud",
    "If you did not request this, please contact an administrator." : "Kui sa pole seda taotlenud, võta ühendust administraatoriga.",
    "Your email address on %s was changed." : "Sinu %s e-posti aadressi muudeti.",
    "Your email address on %s was changed by an administrator." : "Administraator muutis sinu %s e-posti aadressi.",
    "Email address for %1$s changed on %2$s" : "%1$s e-posti aadress muudetud %2$s",
    "Email address changed for %s" : "%s e-posti aadress muudetud",
    "The new email address is %s" : "Uus e-posti aadress on %s",
    "Your %s account was created" : "Sinu %s konto on loodud",
    "Welcome aboard" : "Tere tulemast",
    "Welcome aboard %s" : "Tere tulemast %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tere tulemast oma %s kontole. Sa saad lisada, kaitsta ja jagada oma andmeid.",
    "Your username is: %s" : "Sinu kasutajanimi on: %s",
    "Set your password" : "Määra oma parool",
    "Go to %s" : "Mine %s",
    "Install Client" : "Paigalda kliendiprogramm",
    "Settings" : "Seaded",
    "Personal" : "Isiklik",
    "Administration" : "Haldus",
    "Additional settings" : "Lisaseaded",
    "Groupware" : "Grupitöö",
    "Overview" : "Ülevaade",
    "Basic settings" : "Põhiseaded",
    "Sharing" : "Jagamine",
    "Calendar" : "Kalender",
    "Personal info" : "Isiklik info",
    "Mobile & desktop" : "Mobiil ja töölaud",
    "Email server" : "E-kirjade server",
    "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
    "Create" : "Loo",
    "Change" : "Muuda",
    "Delete" : "Kustuta",
    "Unlimited" : "Piiramatult",
    "Verifying" : "Kontrollin",
    "Nextcloud settings" : "Nextcloud seaded",
    "None" : "Pole",
    "Limit to groups" : "Luba gruppidele",
    "Save changes" : "Salvesta muudatused",
    "All" : "Kõik",
    "No results" : "Vasteid ei leitud",
    "Update to {version}" : "Uuenda versioonile {version}",
    "Remove" : "Eemalda",
    "Disable" : "Lülita välja",
    "Visit website" : "Külasta veebisaiti",
    "Report a bug" : "Teata veast",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "Featured" : "Esile tõstetud",
    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
    "Enable all" : "Luba kõik",
    "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
    "Rename" : "Nimeta ümber",
    "Revoke" : "Tühista",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "Sync client - {os}" : "Kliendiprogramm - {os}",
    "This session" : "See sessioon",
    "Device" : "Seade",
    "Last activity" : "Viimane tegevus",
    "Devices & sessions" : "Seadmed & sessioonid",
    "Web, desktop and mobile clients currently logged in to your account." : "Sinu kontole hetkel sisse loginud veebi-, töölaua-, ja mobiilsed kliendid.",
    "App name" : "Rakenduse nimi",
    "Create new app password" : "Loo uus rakenduse parool",
    "Use the credentials below to configure your app or device." : "Rakenduse või seadme konfigureerimiseks kasutage allpool toodud mandaate.",
    "For security reasons this password will only be shown once." : "Turvalisuse huvides kuvatakse see parool ainult üks kord.",
    "Username" : "Kasutajanimi",
    "Password" : "Parool",
    "Done" : "Valmis",
    "Copied!" : "Kopeeritud!",
    "Copy" : "Kopeeri",
    "Enable" : "Lülita sisse",
    "Server-side encryption" : "Serveripoolne krüpteerimine",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serveripoole krüpteerimine võimaldab serverisse üleslaetud faile krüpteerida. Sellega kaasnevad piirangud, näiteks jõudluskadu. Lülita see sisse ainult siis, kui vaja on.",
    "Enable server-side encryption" : "Luba serveripoolne krüpteerimine",
    "Select default encryption module:" : "Määra vaikimisi krüpteerimise moodul:",
    "Remove group" : "Eemalda grupp",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Sa oled eemaldamas gruppi {group}. Selles grupis olevaid kasutajaid EI kustutata.",
    "Please confirm the group removal " : "Palun kinnita grupi eemaldamine",
    "Current password" : "Praegune parool",
    "New password" : "Uus parool",
    "Change password" : "Muuda parooli",
    "png or jpg, max. 20 MB" : "png või jpg, max. 20 MB",
    "Cancel" : "Loobu",
    "Details" : "Üksikasjad",
    "You are a member of the following groups:" : "Sa oled nende gruppide liige:",
    "Your email address" : "Sinu e-posti aadress",
    "No email address set" : "E-posti aadressi pole veel määratud",
    "Language" : "Keel",
    "Help translate" : "Aita tõlkida",
    "Locale" : "Kasutuskoht",
    "Your phone number" : "Sinu telefoninumber",
    "Your website" : "Sinu veebileht",
    "Add" : "Lisa",
    "You do not have permissions to see the details of this user" : "Sul puuduvad õigused selle kasutaja üksikasjade vaatamiseks",
    "Delete user" : "Kustuta kasutaja",
    "Disable user" : "Keela kasutaja",
    "Enable user" : "Luba kasutaja",
    "Resend welcome email" : "Saada tervitusmeil uuesti",
    "Welcome mail sent!" : "Tervitusmeil saadetud!",
    "{size} used" : "{size} kasutatud",
    "New user" : "Uus kasutaja",
    "Display name" : "Kuvatav nimi",
    "Email" : "E-post",
    "Default language" : "Vaikekeel",
    "Add a new user" : "Lisa uus kasutaja",
    "Group admin for" : "Grupi admin",
    "Quota" : "Mahupiir",
    "User backend" : "Kasutaja taustarakendus",
    "Storage location" : "Salvestusruumi asukoht",
    "Last login" : "Viimane sisselogimine",
    "Default quota" : "Vaikimisi mahupiir",
    "Common languages" : "Levinud keeled",
    "Unnamed device" : "Nimetu seade",
    "Your apps" : "Sinu rakendused",
    "{license}-licensed" : "{license} litsents",
    "Changelog" : "Muudatuste logi",
    "Add group" : "Lisa grupp",
    "Active users" : "Aktiivseid kasutajaid",
    "Admins" : "Haldurid",
    "Disabled users" : "Keelatud kasutajad",
    "Default quota:" : "Vaikekvoot:",
    "Show last login" : "Näita viimast sisselogimist",
    "Send email to new user" : "Saada uuele kasutajale e-kiri",
    "Not saved" : "Ei ole salvestatud",
    "Sending…" : "Saadan...",
    "Email sent" : "E-kiri on saadetud",
    "Location" : "Asukoht",
    "Profile picture" : "Profiili pilt",
    "About" : "Info",
    "Full name" : "Täielik nimi",
    "Organisation" : "Organisatsioon",
    "Phone number" : "Telefoninumber",
    "Role" : "Roll",
    "Twitter" : "Twitter",
    "Website" : "Veebileht",
    "Disabled apps" : "Keelatud rakendused",
    "Updates" : "Uuendused",
    "App bundles" : "Rakenduste kogumikud",
    "Hide" : "Peida",
    "Never" : "Mitte kunagi",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Rakendus on lubatud, aga see vajab uuendamist. Sind suunatakse 5 sekundi pärast uuendamise lehele.",
    "Documentation" : "Dokumentatsioon",
    "Forum" : "Foorum",
    "Login" : "Logi sisse",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Ava dokumentatsioon",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "E-kirjad saatmise võimekus on olulile seadistada paroolide lähtestamiseks ja teavituste saatmiseks.",
    "Send mode" : "Saatmise viis",
    "Encryption" : "Krüpteerimine",
    "From address" : "Saatja aadress",
    "Server address" : "Serveri aadress",
    "Port" : "Port",
    "Authentication method" : "Autentimise meetod",
    "Authentication required" : "Autentimine on vajalik",
    "Credentials" : "Kasutajatunnused",
    "SMTP Username" : "SMTP kasutajatunnus",
    "SMTP Password" : "SMTP parool",
    "Save" : "Salvesta",
    "Send email" : "Saada kiri",
    "All checks passed." : "Kõik kontrollid on läbitud.",
    "Version" : "Versioon",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administraatorina saate jagamise valikuid täpselt seadistada. Lisateavet leiad dokumentatsioonist.",
    "Allow apps to use the Share API" : "Luba rakendustel kasutada Share API-t",
    "Enforce expiration date" : "Sunnitud aegumise kuupäev",
    "Allow public uploads" : "Luba avalikud üleslaadimised",
    "Always ask for a password" : "Alati küsi parooli",
    "Enforce password protection" : "Jõusta paroolikaitse",
    "Set default expiration date" : "Määra vaikimisi aegumise kuupäev",
    "Allow resharing" : "Luba edasijagamine",
    "Allow sharing with groups" : "Luba gruppidega jagamine",
    "Restrict users to only share with users in their groups" : "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
    "Exclude groups from sharing" : "Eemalda grupid jagamisest",
    "These groups will still be able to receive shares, but not to initiate them." : "Need grupid saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
    "This text will be shown on the public link upload page when the file list is hidden." : "Seda teksti näidatakse avaliku lingiga üleslaadimise lehel kui failide loend on peidetud.",
    "Select a profile picture" : "Vali profiili pilt",
    "Week starts on {fdow}" : "Nädala esimene päev: {fdow}",
    "Couldn't remove app." : "Ei suutnud rakendit eemaldada.",
    "Couldn't update app." : "Rakenduse uuendamine ebaõnnestus.",
    "Migration in progress. Please wait until the migration is finished" : "Kolimine on käimas. Palun oota, kuni see on lõpetatud",
    "Migration started …" : "Kolimist on alustatud ...",
    "Address" : "Aadress",
    "Avatar" : "Avatar",
    "Plain" : "Tavatekst",
    "NT LAN Manager" : "NT LAN Manager",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Palun loe hoolikalt enne serveripoolse krüpteerimise lubamist:",
    "Enable encryption" : "Luba krüpteerimine",
    "Start migration" : "Alusta kolimist",
    "Recommended" : "Soovitatud",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php tuleb käivitada süsteemikasutaja \"%s\" poolt.",
    "Upload new" : "Laadi uus üles",
    "Select from Files" : "Vali failidest",
    "Remove image" : "Eemalda pilt",
    "Choose as profile picture" : "Vali kui profiili pilt",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Kasutusel on <strong>%1$s</strong>/ <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
    "Your postal address" : "Sinu postiaadress",
    "It can take up to 24 hours before the account is displayed as verified." : "Võib võtta kuni 24 tundi enne kui konto kuvatakse kui kinnitatud."
},
"nplurals=2; plural=(n != 1);");
