OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendar",
    "To-dos" : "To-dos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} created calendar {calendar}",
    "You created calendar {calendar}" : "You created calendar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} deleted calendar {calendar}",
    "You deleted calendar {calendar}" : "You deleted calendar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} updated calendar {calendar}",
    "You updated calendar {calendar}" : "You updated calendar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restored calendar {calendar}",
    "You restored calendar {calendar}" : "You restored calendar {calendar}",
    "You shared calendar {calendar} as public link" : "You shared calendar {calendar} as public link",
    "You removed public link for calendar {calendar}" : "You removed public link for calendar {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} shared calendar {calendar} with you",
    "You shared calendar {calendar} with {user}" : "You shared calendar {calendar} with {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} shared calendar {calendar} with {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} unshared calendar {calendar} from you",
    "You unshared calendar {calendar} from {user}" : "You unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} unshared calendar {calendar} from themselves",
    "You shared calendar {calendar} with group {group}" : "You shared calendar {calendar} with group {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} shared calendar {calendar} with group {group}",
    "You unshared calendar {calendar} from group {group}" : "You unshared calendar {calendar} from group {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} unshared calendar {calendar} from group {group}",
    "Untitled event" : "Untitled event",
    "{actor} created event {event} in calendar {calendar}" : "{actor} created event {event} in calendar {calendar}",
    "You created event {event} in calendar {calendar}" : "You created event {event} in calendar {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} deleted event {event} from calendar {calendar}",
    "You deleted event {event} from calendar {calendar}" : "You deleted event {event} from calendar {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} updated event {event} in calendar {calendar}",
    "You updated event {event} in calendar {calendar}" : "You updated event {event} in calendar {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restored event {event} of calendar {calendar}",
    "You restored event {event} of calendar {calendar}" : "You restored event {event} of calendar {calendar}",
    "Busy" : "Busy",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} created to-do {todo} in list {calendar}",
    "You created to-do {todo} in list {calendar}" : "You created to-do {todo} in list {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} deleted to-do {todo} from list {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "You deleted to-do {todo} from list {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} updated to-do {todo} in list {calendar}",
    "You updated to-do {todo} in list {calendar}" : "You updated to-do {todo} in list {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} solved to-do {todo} in list {calendar}",
    "You solved to-do {todo} in list {calendar}" : "You solved to-do {todo} in list {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reopened to-do {todo} in list {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "You reopened to-do {todo} in list {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendar, contacts and tasks",
    "A <strong>calendar</strong> was modified" : "A <strong>calendar</strong> was modified",
    "A calendar <strong>event</strong> was modified" : "A calendar <strong>event</strong> was modified",
    "A calendar <strong>to-do</strong> was modified" : "A calendar <strong>to-do</strong> was modified",
    "Contact birthdays" : "Contact birthdays",
    "Death of %s" : "Death of %s",
    "Calendar:" : "Calendar:",
    "Date:" : "Date:",
    "Where:" : "Where:",
    "Description:" : "Description:",
    "_%n year_::_%n years_" : ["%n year","%n years"],
    "_%n month_::_%n months_" : ["%n month","%n months"],
    "_%n day_::_%n days_" : ["%n day","%n days"],
    "_%n hour_::_%n hours_" : ["%n hour","%n hours"],
    "_%n minute_::_%n minutes_" : ["%n minute","%n minutes"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s ago)",
    "Calendar: %s" : "Calendar: %s",
    "Date: %s" : "Date: %s",
    "Description: %s" : "Description: %s",
    "Where: %s" : "Where: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Cancelled: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" has been cancelled",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has responded to your invitation" : "%1$s has responded to your invitation",
    "Invitation updated: %1$s" : "Invitation updated: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s updated the event \"%2$s\"",
    "Invitation: %1$s" : "Invitation: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s would like to invite you to \"%2$s\"",
    "Organizer:" : "Organiser:",
    "Attendees:" : "Attendees:",
    "Title:" : "Title:",
    "Time:" : "Time:",
    "Location:" : "Location:",
    "Link:" : "Link:",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "More options …" : "More options …",
    "More options at %s" : "More options at %s",
    "Contacts" : "Contacts",
    "{actor} created address book {addressbook}" : "{actor} created address book {addressbook}",
    "You created address book {addressbook}" : "You created address book {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} deleted address book {addressbook}",
    "You deleted address book {addressbook}" : "You deleted address book {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} updated address book {addressbook}",
    "You updated address book {addressbook}" : "You updated address book {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} shared address book {addressbook} with you",
    "You shared address book {addressbook} with {user}" : "You shared address book {addressbook} with {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} shared address book {addressbook} with {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} unshared address book {addressbook} from you",
    "You unshared address book {addressbook} from {user}" : "You unshared address book {addressbook} from {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} unshared address book {addressbook} from {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} unshared address book {addressbook} from themselves",
    "You shared address book {addressbook} with group {group}" : "You shared address book {addressbook} with group {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} shared address book {addressbook} with group {group}",
    "You unshared address book {addressbook} from group {group}" : "You unshared address book {addressbook} from group {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} unshared address book {addressbook} from group {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} created contact {card} in address book {addressbook}",
    "You created contact {card} in address book {addressbook}" : "You created contact {card} in address book {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} deleted contact {card} from address book {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "You deleted contact {card} from address book {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} updated contact {card} in address book {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "You updated contact {card} in address book {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "A <strong>contact</strong> or <strong>address book</strong> was modified",
    "File is not updatable: %1$s" : "File is not updatable: %1$s",
    "Could not write to final file, canceled by hook" : "Could not write to final file, cancelled by hook",
    "Could not write file contents" : "Could not write file contents",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side.",
    "Could not rename part file to final file, canceled by hook" : "Could not rename part file to final file, cancelled by hook",
    "Could not rename part file to final file" : "Could not rename part file to final file",
    "Failed to check file size: %1$s" : "Failed to check file size: %1$s",
    "Could not open file" : "Could not open file",
    "Encryption not ready: %1$s" : "Encryption not ready: %1$s",
    "Failed to open file: %1$s" : "Failed to open file: %1$s",
    "Failed to unlink: %1$s" : "Failed to unlink: %1$s",
    "Invalid chunk name" : "Invalid chunk name",
    "Could not rename part file assembled from chunks" : "Could not rename part file assembled from chunks",
    "Failed to write file contents: %1$s" : "Failed to write file contents: %1$s",
    "File not found: %1$s" : "File not found: %1$s",
    "System is in maintenance mode." : "System is in maintenance mode.",
    "Upgrade needed" : "Upgrade needed",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS.",
    "Configures a CalDAV account" : "Configures a CalDAV account",
    "Configures a CardDAV account" : "Configures a CardDAV account",
    "Events" : "Events",
    "Tasks" : "Tasks",
    "Untitled task" : "Untitled task",
    "Completed on %s" : "Completed on %s",
    "Due on %s by %s" : "Due on %s by %s",
    "Due on %s" : "Due on %s",
    "Migrated calendar (%1$s)" : "Migrated calendar (%1$s)",
    "Calendars including events, details and attendees" : "Calendars including events, details and attendees",
    "Contacts and groups" : "Contacts and groups",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Availability" : "Availability",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "If you configure your working hours, other users will see when you are out of office when they book a meeting.",
    "Time zone:" : "Time zone:",
    "to" : "to",
    "Delete slot" : "Delete slot",
    "No working hours set" : "No working hours set",
    "Add slot" : "Add slot",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sunday" : "Sunday",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications.",
    "Save" : "Save",
    "Failed to load availability" : "Failed to load availability",
    "Saved availability" : "Saved availability",
    "Failed to save availability" : "Failed to save availability",
    "Calendar server" : "Calendar server",
    "Send invitations to attendees" : "Send invitations to attendees",
    "Automatically generate a birthday calendar" : "Automatically generate a birthday calendar",
    "Birthday calendars will be generated by a background job." : "Birthday calendars will be generated by a background job.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hence they will not be available immediately after enabling but will show up after some time.",
    "Send notifications for events" : "Send notifications for events",
    "Notifications are sent via background jobs, so these must occur often enough." : "Notifications are sent via background jobs, so these must occur often enough.",
    "Send reminder notifications to calendar sharees as well" : "Send reminder notifications to calendar sharees as well",
    "Reminders are always sent to organizers and attendees." : "Reminders are always sent to organisers and attendees.",
    "Enable notifications for events via push" : "Enable notifications for events via push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Please make sure to properly set up {emailopen}the email server{linkclose}.",
    "There was an error updating your attendance status." : "There was an error updating your attendance status.",
    "Please contact the organizer directly." : "Please contact the organiser directly.",
    "Are you accepting the invitation?" : "Are you accepting the invitation?",
    "Tentative" : "Tentative",
    "Your attendance was updated successfully." : "Your attendance was updated successfully.",
    "Todos" : "Todos",
    "{actor} created todo {todo} in list {calendar}" : "{actor} created todo {todo} in list {calendar}",
    "You created todo {todo} in list {calendar}" : "You created todo {todo} in list {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} deleted todo {todo} from list {calendar}",
    "You deleted todo {todo} from list {calendar}" : "You deleted todo {todo} from list {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} updated todo {todo} in list {calendar}",
    "You updated todo {todo} in list {calendar}" : "You updated todo {todo} in list {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} solved todo {todo} in list {calendar}",
    "You solved todo {todo} in list {calendar}" : "You solved todo {todo} in list {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reopened todo {todo} in list {calendar}",
    "You reopened todo {todo} in list {calendar}" : "You reopened todo {todo} in list {calendar}",
    "A calendar <strong>todo</strong> was modified" : "A calendar <strong>todo</strong> was modified",
    "Invitation canceled" : "Invitation cancelled",
    "Invitation updated" : "Invitation updated",
    "Invitation" : "Invitation"
},
"nplurals=2; plural=(n != 1);");
