OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Ρυθμίσεις Βίαιη-δύναμη ",
    "Whitelist IPs" : "Επιτρεπόμενη λίστα IPs",
    "Brute Force Protection is meant to protect Nextcloud servers from attempts to\nguess user passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute force protection makes requests coming from an IP on a\nbruteforce protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of users on one IP address." : "Η Brute Force Protection έχει σκοπό να προστατεύσει τους διακομιστές Nextcloud από προσπάθειες\nανάκτησης κωδικών πρόσβασης χρηστών με διάφορους τρόπους. Εκτός από τις προφανές \"* ας δοκιμάσουμε μια μεγάλη\nλίστα των κοινώς χρησιμοποιούμενων κωδικών πρόσβασης*\" επιθέσεις, καθιστά επίσης πιο δύσκολο να χρησιμοποιήσετε\nελαφρώς πιο εξελιγμένες επιθέσεις μέσω της επαναφοράς  κωδικού ή προσπαθώντας να\nβρείτε αναγνωριστικά εφαρμογής κωδικού.\n\nΑν ενεργοποιηθεί, η brute force protection καθιστά τα αιτήματα που προέρχονται από μια IP σε ένα\nbruteforce προστατευμένο ελεγκτή με το ίδιο API με 24ωρη περίοδο καθυστέρησης.\n\nΜε αυτήν την εφαρμογή, ο διαχειριστής μπορεί να εξαιρέσει μια διεύθυνση IP ή μια περιοχή από την\nπροστασία που μπορεί να είναι χρήσιμη για δοκιμές ή όταν υπάρχουν ψευδείς\nθετικές προσπάθειες λόγω πολλών χρηστών από μία διεύθυνση IP.",
    "Brute-force IP whitelist" : "Brute-force IP λευκή λίστα",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Για την εξαίρεση ΙΡ από το brute-force protection καθορίστε τις παρακάτω. Λάβετε υπόψη ότι οποιαδήποτε διεύθυνση IP μπορεί να πραγματοποιήσει απόπειρες εξακρίβωσης της ταυτότητας χωρίς περιορισμό. Για λόγους ασφαλείας, συνιστάται η προσθήκη στις εξαιρούμενες όσο το δυνατόν λιγότερων ΙΡ ή ιδανικά ακόμη και καθόλου.",
    "Add new whitelist" : "Προσθήκη νέας λίστας ",
    "Add" : "Προσθήκη",
    "Delete" : "Διαγραφή"
},
"nplurals=2; plural=(n != 1);");
