OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Nylig kontaktet",
    "Contacts Interaction" : "Kontakter Interaktion",
    "Manages interaction between users and contacts" : "Håndterer interaktion mellem brugere og kontakter",
    "Collect data about user and contacts interactions and provide an address book for the data" : "Indsaml data om bruger- og kontaktinteraktioner og angiv en adressebog til dataene"
},
"nplurals=2; plural=(n != 1);");
