OC.L10N.register(
    "text",
    {
    "Guest" : "Gost",
    "guest" : "gost",
    "Bold" : "Podebljano",
    "Italic" : "Kurziv",
    "Translate" : "Prevedi",
    "Replace" : "Zameni postojeću",
    "Undo" : "Opozovi",
    "Info" : "Info",
    "Warning" : "Upozorenje",
    "Edit" : "Uredi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
