OC.L10N.register(
    "files",
    {
    "File could not be found" : "File could not be found",
    "Move or copy" : "Move or copy",
    "Download" : "Download",
    "Delete" : "Delete",
    "Tags" : "Tags",
    "Show list view" : "Show list view",
    "Show grid view" : "Show grid view",
    "Home" : "Home",
    "Close" : "Close",
    "Favorites" : "Favourites",
    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
    "This will stop your current uploads." : "This will stop your current uploads.",
    "Upload cancelled." : "Upload cancelled.",
    "Processing files …" : "Processing files …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
    "Not enough free space" : "Not enough free space",
    "An unknown error has occurred" : "An unknown error has occurred",
    "File could not be uploaded" : "File could not be uploaded",
    "Uploading …" : "Uploading …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploading that item is not supported",
    "Target folder does not exist any more" : "Target folder does not exist any more",
    "Operation is blocked by access control" : "Operation is blocked by access control",
    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
    "Actions" : "Actions",
    "Rename" : "Rename",
    "Move" : "Move",
    "Copy" : "Copy",
    "Choose target folder" : "Choose target folder",
    "Edit locally" : "Edit locally",
    "Open" : "Open",
    "Delete file" : "Delete file",
    "Delete folder" : "Delete folder",
    "Disconnect storage" : "Disconnect storage",
    "Leave this share" : "Leave this share",
    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
    "Files" : "Files",
    "Details" : "Details",
    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
    "Apply tag(s) to selection" : "Apply tag(s) to selection",
    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "This operation is forbidden" : "This operation is forbidden",
    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
    "Could not move \"{file}\"" : "Could not move \"{file}\"",
    "copy" : "copy",
    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
    "Failed to redirect to client" : "Failed to redirect to client",
    "{newName} already exists" : "{newName} already exists",
    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New file/folder menu" : "New file/folder menu",
    "Select file range" : "Select file range",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} of {quota} used",
    "{used} used" : "{used} used",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
    "View in folder" : "View in folder",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
    "You can only favorite a single file or folder at a time" : "You can only favourite a single file or folder at a time",
    "New folder" : "New folder",
    "Upload file" : "Upload file",
    "Recent" : "Recent",
    "Not favorited" : "Not favourited",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "Added to favorites" : "Added to favourites",
    "Removed from favorites" : "Removed from favourites",
    "You added {file} to your favorites" : "You added {file} to your favourites",
    "You removed {file} from your favorites" : "You removed {file} from your favourites",
    "File changes" : "File changes",
    "Created by {user}" : "Created by {user}",
    "Changed by {user}" : "Changed by {user}",
    "Deleted by {user}" : "Deleted by {user}",
    "Restored by {user}" : "Restored by {user}",
    "Renamed by {user}" : "Renamed by {user}",
    "Moved by {user}" : "Moved by {user}",
    "\"remote user\"" : "\"remote user\"",
    "You created {file}" : "You created {file}",
    "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
    "{user} created {file}" : "{user} created {file}",
    "{user} created an encrypted file in {file}" : "{user} created an encrypted file in {file}",
    "{file} was created in a public folder" : "{file} was created in a public folder",
    "You changed {file}" : "You changed {file}",
    "You changed an encrypted file in {file}" : "You changed an encrypted file in {file}",
    "{user} changed {file}" : "{user} changed {file}",
    "{user} changed an encrypted file in {file}" : "{user} changed an encrypted file in {file}",
    "You deleted {file}" : "You deleted {file}",
    "You deleted an encrypted file in {file}" : "You deleted an encrypted file in {file}",
    "{user} deleted {file}" : "{user} deleted {file}",
    "{user} deleted an encrypted file in {file}" : "{user} deleted an encrypted file in {file}",
    "You restored {file}" : "You restored {file}",
    "{user} restored {file}" : "{user} restored {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "You renamed {oldfile} (hidden) to {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "You renamed {oldfile} (hidden) to {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "You renamed {oldfile} to {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renamed {oldfile} (hidden) to {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renamed {oldfile} (hidden) to {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renamed {oldfile} to {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "A favourite file or folder has been <strong>changed</strong>",
    "All files" : "All files",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accept",
    "Reject" : "Reject",
    "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour.",
    "Ownership transfer failed" : "Ownership transfer failed",
    "Your ownership transfer of {path} to {user} failed." : "Your ownership transfer of {path} to {user} failed.",
    "The ownership transfer of {path} from {user} failed." : "The ownership transfer of {path} from {user} failed.",
    "Ownership transfer done" : "Ownership transfer done",
    "Your ownership transfer of {path} to {user} has completed." : "Your ownership transfer of {path} to {user} has completed.",
    "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
    "in %s" : "in %s",
    "File Management" : "File Management",
    "Storage informations" : "Storage informations",
    "{usedQuotaByte} used" : "{usedQuotaByte} used",
    "{relative}% used" : "{relative}% used",
    "Could not refresh storage stats" : "Could not refresh storage stats",
    "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
    "Choose file or folder to transfer" : "Choose file or folder to transfer",
    "Change" : "Change",
    "New owner" : "New owner",
    "Search users" : "Search users",
    "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transfer {path} to {userid}",
    "Invalid path selected" : "Invalid path selected",
    "Unknown error" : "Unknown error",
    "Ownership transfer request sent" : "Ownership transfer request sent",
    "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Open the files app settings" : "Open the files app settings",
    "Files settings" : "Files settings",
    "File cannot be accessed" : "File cannot be accessed",
    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
    "Show hidden files" : "Show hidden files",
    "Crop image previews" : "Crop image previews",
    "Additional settings" : "Additional settings",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copy to clipboard",
    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
    "Clipboard is not available" : "Clipboard is not available",
    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
    "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
    "Error while loading the file data" : "Error while loading the file data",
    "Pick a template for {name}" : "Pick a template for {name}",
    "Cancel" : "Cancel",
    "Create" : "Create",
    "Create a new file with the selected template" : "Create a new file with the selected template",
    "Creating file" : "Creating file",
    "Blank" : "Blank",
    "Unable to create new file from template" : "Unable to create new file from template",
    "Set up templates folder" : "Set up templates folder",
    "Templates" : "Templates",
    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
    "Toggle %1$s sublist" : "Toggle %1$s sublist",
    "Toggle grid view" : "Toggle grid view",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "No favorites yet" : "No favourites yet",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
    "Deleted files" : "Deleted files",
    "Shares" : "Shares",
    "Shared with others" : "Shared with others",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Shared by link",
    "Deleted shares" : "Deleted shares",
    "Pending shares" : "Pending shares",
    "Text file" : "Text file",
    "New text file.txt" : "New text file.txt",
    "Storage invalid" : "Storage invalid",
    "Select" : "Select",
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "New" : "New",
    "Copied!" : "Copied!",
    "Unlimited" : "Unlimited",
    "Cannot transfer ownership of a file or folder you don't own" : "Cannot transfer ownership of a file or folder you don't own",
    "%s used" : "%s used",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "%1$s of %2$s used",
    "Settings" : "Settings"
},
"nplurals=2; plural=(n != 1);");
