OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds inte!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "First run wizard" : "Uppstartsguiden",
    "Add your profile information! For example your email is needed to receive notifications." : "Lägg till din profilinformation! Till exempel behövs din e-post för att ta emot notifikationer.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Lägg till din profilinformation! Till exempel behövs din e-post för att ta emot notifikationer eller återställa ditt lösenord.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lägg till din profilinformation! Ställ in en profilbild och fullständigt namn för enklare erkännande över alla funktioner.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lägg till din profilinformation! Ange ett fullständigt namn för enklare erkännande över alla funktioner.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lägg till din profilinformation! Ställ in en profilbild för enklare erkännande över alla funktioner.",
    "App recommendation: Nextcloud Calendar" : "Rekommenderad app: Nextcloud Kalender",
    "Schedule work & meetings, synced with all your devices." : "Planera arbete och möten, synkronisera med alla dina enheter.",
    "App recommendation: Nextcloud Contacts" : "Rekommenderad app: Nextcloud Kontakter",
    "Keep your colleagues and friends in one place without leaking their private info." : "Håll dina kollegor och vänner på ett ställe utan att läcka deras privata info.",
    "App recommendation: Nextcloud Mail" : "Rekommenderad app: Nextcloud Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app integrerad med filer, kontakter och kalender.",
    "App recommendation: Tasks" : "Rekommenderad app: Uppgifter (Tasks)",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synka uppgifter från olika enheter med ditt Nextcloud och redigera dem online.",
    "App recommendation: Deck" : "Rekommenderad app: Kortlek",
    "Kanban style organization for personal planning and team projects." : "Kanban-baserad planering för egna projekt eller i grupp.",
    "App recommendation: Forms" : "Apprekommendation: Formulär",
    "Simple surveys and questionnaires, self-hosted" : "Enkla undersökningar och enkäter, själv-hostad",
    "App recommendation: Recognize" : "Apprekommendation: Känn igen",
    "Smart media tagging for Nextcloud" : "Smart taggning för media i Nextcloud",
    "App recommendation: Group folders" : "Rekommenderad app: Gruppmappar (Group folders)",
    "Admin-configured folders shared by everyone in a group." : "Admin-konfigurerade mappar som delas av alla i en grupp.",
    "About" : "Om",
    "A welcome and introduction wizard for Nextcloud" : "En välkomst och introduktionsguide för Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Den här appen visar ett pop-upp-fönster första gången en ny användare loggar in i Nextcloud. Användaren välkomnas till Nextcloud. Länkar visas till en vanlig skrivbordsklient, Android- och iOS-apparna. En länk visas också för att använda Nextcloud via WebDAV. Första-användnings-appen kan öppnas igen via \"Om\" i inställningsmenyn.\nFörsta-användnings-appen kan anpassas för specifik design, eller  andra länkar och meddelanden. Att skapa ett tema och ändra utseende för appen är enkelt. Mer information hittar du i Första-användnings-appens dokumentation och i tema-dokumentationen.",
    "Start using {cloudName}" : "Börja använda {cloudName}",
    "Welcome to {cloudName}!" : "Välkommen till {cloudName}!",
    "Extend your cloud" : "Utöka ditt moln",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Hitta fler än 100 appar i Nextcloud-appbutiken för att anpassa ditt moln:",
    "Groupware apps like Calendar, Contacts, Mail" : "Gruppvaruappar som Kalender, Kontakter, E-post",
    "Communication with Nextcloud Talk" : "Kommunicera med Nextcloud Talk",
    "Collaboration apps for document editing" : "Samarbetsappar för dokumentredigering",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Säkerhets- och autentiseringsfunktioner som tvåfaktorsautentisering, SSO och ransomware-skydd",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Många andra såsom musikspelare, lösenordshanterare, kanban-app, nedladdningshanterare och Markdown-redigerare",
    "Browse the App Store" : "Bläddra i appbutiken",
    "Stay in sync" : "Förbli synkroniserad",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud ger dig åtkomst till dina filer var du än befinner dig.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad!",
    "Get the apps to sync your files" : "Skaffa apparna för att synkronisera dina filer",
    "Desktop client" : "Skrivbordsklient",
    "Android app on Google Play Store" : "Androidapp på Google Play Store",
    "Android app on F-Droid" : "Androidapp på F-Droid",
    "iOS app" : "iOS-app",
    "Connect your desktop apps to %s" : "Anslut dina skrivbordsappar till %s",
    "Connect your calendar" : "Anslut din kalender",
    "Connect your contacts" : "Anslut dina kontakter",
    "Access files via WebDAV" : "Åtkomst till filer via WebDAV",
    "Download macOS/iOS configuration profile" : "Hämta macOS/iOS-konfigurationsprofil",
    "Get help" : "Få hjälp",
    "Start contributing" : "Börja bidra",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Vill du få en viss förbättring i Nextcloud? Hittade du ett problem? Vill du hjälpa till att översätta, marknadsföra eller dokumentera Nextcloud?",
    "Become part of the Community" : "Bli en del av gemenskapen",
    "Enterprise support" : "Företagssupport",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Om du kör Nextcloud i en verksamhetskritisk miljö där säkerhet och efterlevnad är viktigt behöver du vissheten hos Nextcloud Enterprise.",
    "Learn more about Nextcloud Enterprise" : "Läs mer om Nextcloud Enterprise",
    "Get more information" : "Skaffa mer information",
    "The Nextcloud documentation for home users:" : "Nextcloud-dokumentation för hemanvändare:",
    "User manual" : "Manual för användare",
    "Admin manual" : "Manual för administratörer",
    "Developer manual" : "Manual för utvecklare",
    "You can also ask for help in our community support channels:" : "Du kan också begära hjälp i våra gemenskapssupportskanaler:",
    "the Nextcloud forums" : "Nextcloud-forum",
    "A safe home for all your data" : "Ett säkert hem för all din data",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud ger dig full kontroll över din data. Lagra dina dokument, kalender, kontakter och foton på en server i ditt företag, hemma, hos en av våra leverantörer eller i ett datacenter du känner.",
    "Host your data and files where you decide" : "Lagra din data och filer där du vill",
    "Open standards and interoperability" : "Öppna standarder och interoperabilitet",
    "100%% open source & community-focused" : "100%% öppen källkod och gemenskapsfokuserad",
    "Learn more about %s" : "Läs mer om %s",
    "This Nextcloud is on version %s" : "Denna Nextcloud är på version %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s ger dig åtkomst till dina filer var du än befinner dig. Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad.",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Konfigurera synkroniseringsklienter som använder ett <a href=\"%s\">app-lösenord</a>. På  det sättet kan du återkalla åtkomst om du förlorar enheten.",
    "Connect other apps to %s" : "Anslut andra appar till %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Förutom synkroniseringsklienterna kan du ansluta alla program som stöder WebDAV/CalDAV/CardDAV-protokollen till %s.",
    "Server address" : "Serveradress",
    "Use this link to connect your apps and desktop client to this server:" : "Använd den här länken för att ansluta dina appar och desktopklient till den här servern:",
    "Copy link" : "Kopiera länk",
    "Copy to clipboard" : "Kopierat till urklipp",
    "App recommendation: Notes" : "Rekommenderad app: Anteckningar (Notes)",
    "Distraction-free notes and writing." : "Störningsfria anteckningar helt enkelt.",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Om du kör Nextcloud i produktionsmiljö med många användare, mycket data och behöver trygghet med support från experterna bakom Nextcloud-tekniken, finns ett företagsabonnemang från Nextcloud med e-post- och telefonsupport.",
    "Get enterprise support" : "Skaffa företagssupport",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC-chattkanal på freenode.net"
},
"nplurals=2; plural=(n != 1);");
