OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "To-dos" : "Tarefas pendentes",
    "Personal" : "Persoal",
    "{actor} created calendar {calendar}" : "{actor} creou o calendario {calendar}",
    "You created calendar {calendar}" : "Vostede creou o calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminou o calendario {calendar}",
    "You deleted calendar {calendar}" : "Vostede eliminou o calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizou o calendario {calendar}",
    "You updated calendar {calendar}" : "Vostede actualizou o calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restaurou o calendario {calendar}",
    "You restored calendar {calendar}" : "Restauraches o calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Vostede compartiu o calendario {calendar} como ligazón pública",
    "You removed public link for calendar {calendar}" : "Vostede retirou a ligazón pública do calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartiu o calendario {calendar} con vostede",
    "You shared calendar {calendar} with {user}" : "Vostede compartiu o calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartiu o calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} deixou de compartir o calendario {calendar} de vostede",
    "You unshared calendar {calendar} from {user}" : "Vostede deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} deixou de compartir o seu propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Vostede compartiu o calendario {calendar} co grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartiu o calendario {calendar} co grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vostede deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} deixou de compartir o calendario {calendar} do grupo {group}",
    "Untitled event" : "Evento sen título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creou o evento {event} no calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Vostede creou o evento {event} no calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminou o evento {event} do calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vostede eliminou o evento {event} do calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizou o evento {event} no calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vostede actualizou o evento {event} no calendario {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendario {sourceCalendar} ao calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Moveches o evento {evento} do calendario {sourceCalendar} ao calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {evento} do calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Restauraches o evento {evento} do calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} creou as tarefas {todo} na lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Creaches a tarefa {todo} na lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} eliminou as tarefas pendentes {todo} da lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Eliminaches as tarefas pendentes {todo} da lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} actualizou a tarefa {todo} na lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Actualizaches a tarefa {todo} na lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} resolveu as tarefas {todo} na lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Resolveches a tarefa {todo} na lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu as tarefas {todo} na lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Reabriches as tarefas {todo} na lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu a tarefa {todo} da lista {sourceCalendar} á lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Moveches a tarefa {todo} da lista {sourceCalendar} á lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendario, contactos e tarefas",
    "A <strong>calendar</strong> was modified" : "Foi modificado un <strong>calendario</strong>",
    "A calendar <strong>event</strong> was modified" : "Foi modificado un <strong>evento</strong> do calendario",
    "A calendar <strong>to-do</strong> was modified" : "Modificouse unha <strong>tarefa</strong> do calendario",
    "Contact birthdays" : "Aniversario do contacto",
    "Death of %s" : "Falecemento de %s",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrición:",
    "_%n year_::_%n years_" : ["%n ano","%n anos"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hai %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrición: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" cancelouse",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has responded to your invitation" : "%1$s respondeu á túa invitación",
    "Invitation: %1$s" : "Invitación: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s quere invitarte a \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Title:" : "Título:",
    "Time:" : "Hora:",
    "Location:" : "Lugar:",
    "Link:" : "Ligazón:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options …" : "Máis opcións…",
    "More options at %s" : "Máis opcións en %s",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} creou a axenda de enderezos {addressbook}",
    "You created address book {addressbook}" : "Creaches a axenda de enderezos {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} eliminou a axenda de enderezos {addressbook}",
    "You deleted address book {addressbook}" : "Eliminaches a axenda de enderezos {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} actualizou a axenda de enderezos {addressbook}",
    "You updated address book {addressbook}" : "Actualizaches a axenda de enderezos {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} compartiu a axenda de enderezos {addressbook} contigo",
    "You shared address book {addressbook} with {user}" : "Compartiches a axenda de enderezos {addressbook} con {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} compartiu a axenda de enderezos {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} deixou de compartir a túa axenda de enderezos {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Deixaches de compartir a axenda de enderezos {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} deixou de compartir a axenda de enderezos {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} deixaron de compartir a súa axenda de enderezos {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Compartiches a axenda de enderezos {addressbook} co grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} compartiu a axenda de enderezos {addressbook} co grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Deixaches de compartir a axenda de enderezos {addressbook} do grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} deixou de compartir axenda de enderezos {addressbook} do grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creou o contacto {card} na axenda de enderezos {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Creaches o contacto {card} na axenda de enderezos {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} eliminou o contacto {card} da axenda de enderezos {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Eliminaches o contacto {card} da axenda de enderezos {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} actualizou o contacto {card} na axenda de enderezos {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Actualizaches o contacto {card} na axenda de enderezos {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Modificouse un <strong>contacto</strong> ou <strong>axenda de enderezos</strong>",
    "File is not updatable: %1$s" : "O ficheiro non se pode actualizar: %1$s",
    "Could not write to final file, canceled by hook" : "Non foi posíbel escribir no ficheiro final, cancelouse polo hook",
    "Could not write file contents" : "Non se puido escribir o contido do ficheiro",
    "_%n byte_::_%n bytes_" : ["%n  byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Produciuse un erro ao copiar o ficheiro na localización de destino (copiado: %1$s, tamaño esperado do ficheiro: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamaño esperado do ficheiro %1$s pero lido (do cliente de Nextcloud) e escrito (no almacenamento de Nextcloud) %2$s. Pode ser un problema de rede no lado do envío ou un problema ao escribir no almacenamento no lado do servidor.",
    "Could not rename part file to final file, canceled by hook" : "Non foi posíbel cambiar o nome do ficheiro de parte ao ficheiro final, cancelado polo hook",
    "Could not rename part file to final file" : "Non se puido cambiar o nome do ficheiro de parte ao ficheiro final",
    "Failed to check file size: %1$s" : "Produciuse un erro ao comprobar o tamaño do ficheiro: %1$s",
    "Could not open file" : "Non se puido abrir o ficheiro",
    "Encryption not ready: %1$s" : "O cifrado non está listo: %1$s",
    "Failed to open file: %1$s" : "Produciuse un erro ao abrir o ficheiro: %1$s",
    "Failed to unlink: %1$s" : "Produciuse un erro ao desvincular: %1$s",
    "Invalid chunk name" : "O nome do fragmento non é válido",
    "Could not rename part file assembled from chunks" : "Non se puido cambiar o nome do ficheiro de pezas ensamblados a partir de fragmentos",
    "Failed to write file contents: %1$s" : "Produciuse un erro ao escribir o contido do ficheiro: %1$s",
    "File not found: %1$s" : "Arquivo non atopado: %1$s",
    "System is in maintenance mode." : "O sistema está en modo de mantemento.",
    "Upgrade needed" : "É necesario anovar actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
    "Configures a CalDAV account" : "Configurar unha conta de CalDAV",
    "Configures a CardDAV account" : "Configurar unha conta de CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tarefas",
    "Untitled task" : "Tarefa sen título",
    "Completed on %s" : "Rematado o %s",
    "Due on %s by %s" : "Caduca o %s por %s",
    "Due on %s" : "Caduca o %s",
    "Migrated calendar (%1$s)" : "Calendario migrado (%1$s)",
    "Calendars including events, details and attendees" : "Calendarios incluíndo eventos, detalles e asistentes",
    "Contacts and groups" : "Contactos e grupos",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminación WebDAV",
    "Availability" : "Dispoñibilidade",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se configuras o teu horario de traballo, outros usuarios verán cando estás fóra da oficina cando reserven unha reunión.",
    "Time zone:" : "Franxa horaria:",
    "to" : "para",
    "Delete slot" : "Eliminar slot",
    "No working hours set" : "Sen horario de traballo establecido",
    "Add slot" : "Engadir slot",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sunday" : "domingo",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Establece automaticamente o estado do usuario en \"Non molestar\" fóra da dispoñibilidade para silenciar todas as notificacións.",
    "Save" : "Gardar",
    "Failed to load availability" : "Produciuse un erro ao cargar a dispoñibilidade",
    "Saved availability" : "Dispoñibilidade gardada",
    "Failed to save availability" : "Produciuse un erro ao gardar a dispoñibilidade",
    "Calendar server" : "Servidor do calendario",
    "Send invitations to attendees" : "Enviar convites aos asistentes",
    "Automatically generate a birthday calendar" : "Xerar automaticamente o calendario de aniversarios",
    "Birthday calendars will be generated by a background job." : "O calendario de aniversarios xerase cun traballo en segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por isto, non estarán dispoñíbeis inmediatamente tras activalos, senón que aparecerán após certo tempo",
    "Send notifications for events" : "Enviar notificacións para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificacións enviaranse mediante procesos en segundo plano, polo que estes teñen que suceder con frecuencia.",
    "Send reminder notifications to calendar sharees as well" : "Envía notificacións de recordatorio tamén aos que comparten calendario",
    "Reminders are always sent to organizers and attendees." : "Os recordatorios sempre se envían aos organizadores e aos asistentes.",
    "Enable notifications for events via push" : "Activar o envío de notificacións do automáticas para eventos",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén a {calendarappstoreopen}aplicación do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrese de ter configurado correctamente {emailopen}o servidor de correo-e{linkclose}.",
    "There was an error updating your attendance status." : "Produciuse un erro ao actualizar o seu estado de asistencia.",
    "Please contact the organizer directly." : "Contacte directamente co organizador.",
    "Are you accepting the invitation?" : "Acepta vostede o convite?",
    "Tentative" : "Tentativa",
    "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
    "Todos" : "Asuntos pendentes",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creou os asuntos pendentes {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Vostede creou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminou os asuntos pendentes {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vostede eliminou os asuntos pendentes {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizou os asuntos pendentes {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vostede actualizou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolveu os asuntos pendentes {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vostede resolveu os asuntos pendentes {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vostede volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Foi modificado un <strong>asunto pendente</strong> do calendario",
    "Invitation canceled" : "Convite cancelado",
    "Invitation updated" : "Convite actualizado",
    "Invitation" : "Convite"
},
"nplurals=2; plural=(n != 1);");
