OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "\"Brute-Force\" iestatījumi",
    "Whitelist IPs" : "Baltā saraksta IP adreses",
    "Brute Force Protection is meant to protect Nextcloud servers from attempts to\nguess user passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute force protection makes requests coming from an IP on a\nbruteforce protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of users on one IP address." : "\"Brute-Force\" aizsardzība ir paredzēta aizsargāt Nextcloud serveri no mēģinājumiem\ndažādos veidos uzminēt lietotāja paroli. Bez acīmredzamā \"*pamēģināsim izmantot lielu\nbiežākizmantoto paroļu sarakstu*\" uzbrukuma, tas arī padara grūtāk pielietojamus sarežģītākus\nuzbrukumus ar paroļu atjaunošanas formu vai arī mēģinājumiem atrast lietotnes paroļu marķierus.\n\nJa nostrādā aizsardzība, tā padara pieprasījumus lēnākus 24 stundu periodā,\nkas nāk no IP adresēm uz aizsargātu kontrolieri ar tādu pašu API.\n\nAr šīs lietotnes palīdzību administators var pievienot IP adrešu izņēmumus, kuras pakļautas aizsardzībai,\nkas var būt noderīgi testēšanas nolūkos\nvai arī nepareizas nostrādāšanas gadījumā ja aiz vienas IP adreses atrodās daudz lietotāju.",
    "Brute-force IP whitelist" : "\"Brute-Force\" IP adrešu baltais saraksts",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Lai baltajā sarakstā iekļautu IP diapazonu no aizsardzības pret \"Brute-Force\" uzbrukuma, norādiet tos zemāk. Ņemiet vērā, ka jebkura baltajā sarakstā iekļautā IP adrese var veikt autentifikācijas mēģinājumus bez jebkādiem ierobežojumiem. Drošības apsvērumu dēļ ieteicams iekļaut baltajā sarakstā pēc iespējas mazāk adreses vai ideālā gadījumā pat nevienu.",
    "Add new whitelist" : "Pievienot jaunu balto sarakstu",
    "Add" : "Pievienot",
    "Delete" : "Dzēst"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
