OC.L10N.register(
    "files_trashbin",
    {
    "Deleted files" : "Gelöschte Dateien",
    "restored" : "Wiederhergestellt",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Gelöschte Dateien und Ordner im Papierkorb (können während des Exports gelöscht werden, wenn der Speicherplatz knapp wird)",
    "This application enables users to restore files that were deleted from the system." : "Diese App ermöglicht es Benutzern Dateien die vom System gelöscht wurden wiederherzustellen.",
    "This application enables users to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the users file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent a user from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Diese Anwendung ermöglicht es Benutzern, gelöschte Dateien wieder herzustellen. In der Web-Oberfläche wird eine Liste mit allen gelöschten Dateien angezeigt. Es besteht die Möglichkeit die Datein im Dateiverzeichnisse des Benutzers wieder herzustelle, oder diese endgültig zu löschen. Bei der Wiederherstellung einer Datei werden, sofern die Versions Anwendung aktiviert ist, die dazugehörigen Dateiversionen ebenfalls wieder hergestellt. Falls eine geteilte Datei gelöscht wurde, kann diese ebenfals wieder hergestellt werden, jedoch ist diese danach nicht mehr geteilt. Normalerweise verbleiben gelöschte Dateien für 30 Tage im Papierkorb .\nUm zu verhindern, dass einem Benutzer der Speicherplatz ausgeht, nutzt die Anwendung maximal 50% des verfügbaren freien Kontingents für gelöschte Dateien. Sofern die gelöschten Dateien dieses Limit überschreiten, werden zunächst die ältesten Dateien gelöscht, bis das Limit unterschritten wird. Mehr Informationen sind in der Dokumentation verfügbar.",
    "Restore" : "Wiederherstellen",
    "Delete permanently" : "Endgültig löschen",
    "Error while restoring file from trash bin" : "Fehler beim Wiederherstellen der Datei aus dem Papierkorb",
    "Error while removing file from trash bin" : "Fehler beim Entfernen der Datei aus dem Papierkorb",
    "Error while restoring files from trash bin" : "Fehler beim Wiederherstellen der Dateien aus dem Papierkorb",
    "Error while emptying trash bin" : "Fehler beim Leeren des Papierkorbs",
    "Error while removing files from trash bin" : "Fehler beim Entfernen von Dateien aus dem Papierkorb",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfe die Logdateien oder kontaktiere den Administrator",
    "No deleted files" : "Keine gelöschten Dateien",
    "You will be able to recover deleted files from here" : "Hier können gelöschte Dateien wiederhergestellt werden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Name" : "Name",
    "Actions" : "Aktionen",
    "Deleted" : "gelöscht",
    "Delete" : "Löschen"
},
"nplurals=2; plural=(n != 1);");
