OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Koledar",
    "Deck" : "Deck",
    "Files" : "Datoteke",
    "Talk" : "Pogovor",
    "Talk conversation" : "Pogovor Talk"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
