OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Katselin",
    "Simple file viewer with slideshow for media" : "Yksinkertainen tiedostokatselin mahdollisuudella katsoa kuvia diaesityksenä",
    "Your browser does not support audio." : "Selaimesi ei tue äänentoistoa.",
    "Error loading {name}" : "Virhe ladatessa {name}",
    "Image saved" : "Kuva tallennettu",
    "Error saving image" : "Virhe kuvaa tallentaessa",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Drop changes" : "Hylkää muutokset",
    "Content of \"{fileName}\"" : "Tiedoston \"{fileName}\" sisältö",
    "Your browser does not support videos." : "Selaimesi ei tue videoita.",
    "Edit" : "Muokkaa",
    "Open sidebar" : "Avaa sivupalkki",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "This file no longer exists" : "Tätä tiedostoa ei ole olemassa",
    "There is no plugin available to display this file type" : "Tämän tiedostotyypin näyttämiseksi ei ole saatavilla liitännäistä",
    "View" : "Näytä",
    "Name" : "Nimi",
    "Save" : "Tallenna",
    "Save as" : "Tallenna nimellä",
    "Back" : "Takaisin",
    "Loading …" : "Ladataan…",
    "Reset" : "Palauta",
    "All changes will be lost." : "Kaikki muutokset menetetään.",
    "Are you sure you want to continue?" : "Haluatko varmasti jatkaa?",
    "Cancel" : "Peruuta",
    "Continue" : "Jatka",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Show original image" : "Näytä alkuperäinen kuva",
    "Zoom in" : "Lähennä",
    "Zoom out" : "Loitonna",
    "Adjust" : "Säädä",
    "Fine-tune" : "Hienosäädä",
    "Filters" : "Suodattimet",
    "Watermark" : "Vesileima",
    "Draw" : "Piirrä",
    "Resize" : "Muuta kokoa",
    "Invalid image." : "Virheellinen kuva.",
    "Error while uploading the image." : "Virhe kuvaa lähettäessä.",
    "are not images" : "eivät ole kuvia",
    "is not an image" : "ei ole kuva",
    "to be uploaded" : "ladattava",
    "Crop" : "Rajaa",
    "Original" : "Alkuperäinen",
    "Custom" : "Omavalintainen",
    "Square" : "Neliö",
    "Landscape" : "Maisema",
    "Portrait" : "Muotokuva",
    "Ellipse" : "Ellipsi",
    "Classic TV" : "Klassinen TV",
    "Arrow" : "Nuoli",
    "Blur" : "Sumennus",
    "Brightness" : "Kirkkaus",
    "Contrast" : "Kontrasti",
    "Flip X" : "Käännä X",
    "Flip Y" : "Käännä Y",
    "Hue" : "Väri",
    "Saturation" : "Värikylläisyys",
    "Value" : "Arvo",
    "Image" : "Kuva",
    "Importing …" : "Tuodaan…",
    "+ Add image" : "+ Lisää kuva",
    "Line" : "Viiva",
    "Pen" : "Kynä",
    "Polygon" : "Polygoni",
    "Rectangle" : "Suorakulmio",
    "Corner Radius" : "Kulmien säde",
    "Width in pixels" : "Leveys kuvapisteinä",
    "Height in pixels" : "Korkeus kuvapisteinä",
    "Toggle ratio lock" : "Suhdelukitus päälle/pois",
    "Reset to original image size" : "Palauta alkuperäiseen kuvakokoon",
    "Rotate" : "Kierrä",
    "Text" : "Teksti",
    "Text spacing" : "Tekstin välitys",
    "Text alignment" : "Tekstin tasaus",
    "Font family" : "Kirjasin",
    "Size" : "Koko",
    "Letter spacing" : "Kirjainväli",
    "Line height" : "Rivikorkeus",
    "Warmth" : "Lämpö",
    "+ Add watermark" : "+ Lisää vesileima",
    "Choose watermark type" : "Valitse vesileiman tyyppi",
    "Upload watermark" : "Lähetä vesileima",
    "Add as text" : "Lisää tekstinä",
    "Shadow" : "Varjo",
    "Horizontal" : "Vaakasuora",
    "Vertical" : "Pystysuora",
    "Opacity" : "Läpinäkyvyys",
    "Position" : "Sijainti",
    "Stroke" : "Viiva",
    "Save image as" : "Tallenna kuva...",
    "Extension" : "Tiedostopääte",
    "Name is required." : "Nimi vaaditaan.",
    "Quality" : "Laatu",
    "Saved image size (width x height)" : "Tallennetun kuvan koko (leveys x korkeus)",
    "Actual size (100%)" : "Todellinen koko (100 %)",
    "Fit size" : "Sovita koko"
},
"nplurals=2; plural=(n != 1);");
