OC.L10N.register(
    "support",
    {
    "Link:" : "Povezava:",
    "Password:" : "Geslo:",
    "Generating system report failed." : "Ustvarjanje sistemskega poročila je spodletelo.",
    "Could not create folder \"System information\" to store generated report." : "Ni mogoče ustvariti mape »Podrobnosti sistema« za shranjevanje ustvarjenega  poročila.",
    "Could not create file \"%s\" to store generated report." : "Ni mogoče ustvariti datoteke »%s« za shranjevanje ustvarjenega poročila.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Souporabe datoteke »%s« ni mogoče začeti. Najdete jo lahko v mapi »Podrobnosti sistema«.",
    "Subscription notifications" : "Obvestilo naročnine",
    "Nextcloud Subscription" : "Naročnina Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Strežnik je brez naročnine Nextcloud ali pa je ta potekla.",
    "Your Nextcloud server subscription does not cover your number of users." : "Naročnina na strežnik Nextcloud ne vključuje trenutnega števila uporabnikov.",
    "Your Nextcloud Subscription has expired!" : "Naročnina na Nextcloud je potekla!",
    "Your server has no Nextcloud Subscription" : "Strežnik ne podpira naročnine Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Trenutna namestitev strežnika Nextcloud nima omogočene podpore za Poslovne naročnine.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Poslovna naročnina Nextcloud zagotavlja razvojnike za samo-gostujočim strežnikom, ki se 100 % posvečajo vašemu uspehu: varnost, prilagodljivost sistema, zmogljivost delovanja in funkcionalnost storitve!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Če se strežnik sesuje in zaposleni izgubijo dostop do svojih računov, vam ni treba iskati rešitev po forumih in spletu. Dobite namreč neposreden dostop do naših izkušenih strokovnjakov!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Varuje vas pogodba s ponudnikom, ki zagotavlja zgodnje varnostne informacije, blaženje težav, programski popravki in posodobitve.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Če želite ostati dlje na trenutni različici brez motenj, vam ni treba uporabljati sistema brez varnostnih posodobitev.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Na voljo so vam največji strokovnjaki za zagotavljanje zmogljivosti in prilagodljivosti sistema.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Omogočen je tudi dostop do ekspertne dokumentacije za hitro razreševanje vprašanj skladnosti oziroma zagotavljanja zahtev GDPR, FIPAA in drugih.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Ponudba vključuje tudi podporo za Outlook, spletni pisarniški paket, prilagodljiv videokonferenčni sistem in druge vrste komunikacije ter druge zmožnosti, ki so v brezplačni različici na voljo v omejeni obliki. Mogoč je tudi razvoj dodatnih možnosti za prilagajanje posebnim zahtevam.",
    "A subscription helps you get the most out of Nextcloud!" : "Naročnina vam omogoči dobiti največ iz oblaka Nextcloud!",
    "Learn more now" : "Več o tem",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "To sporočilo je bilo poslano vsem skrbnikom prek podpornega programa Nextcloud na %1$s, ker število dejavnih uporabnikov presega %2$s vpisanih uporabnikov.",
    "Your Nextcloud server Subscription is over limit" : "Naročnina na strežnik Nextcloud je prek omejitve",
    "Dear admin," : "Spoštovani skrbnik sistema,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Trenutno izbrana naročnina Nextcloud ne ustreza številu uporabnikov, ki so trenutno dejavni na strežniku. Stopite v stik z upravljavcem vašega računa in posodobite naročnino!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "Upravljavec računa %1$s je dosegljiv na elektronskem naslovu %2$s in prek telefonske številke %3$s.",
    "Thank you," : "Hvala,",
    "Your Nextcloud team" : "Skupina Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "To sporočilo je bilo poslano vsem skrbnikom prek podpornega programa Nextcloud na%s, ker število dejavnih uporabnikov presega določeno omejitev.",
    "Your Nextcloud server Subscription is expired" : "Naročnina na strežnik Nextcloud je potekla!",
    "Your Nextcloud server Subscription is expired!" : "Naročnina na strežnik Nextcloud je potekla!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Naročnina Nextcloud je potekla. Stopite v stik z upravljavcem računa in jo posodobite.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "To sporočilo je bilo poslano vsem skrbnikom prek podpornega programa Nextcloud na%s, ker je vaša naročnina potekla.",
    "Support" : "Podpora",
    "Getting support and help for your Nextcloud" : "Pridobite podporo in pomoč za vaš oblak Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Program za podporo omogoča neposreden dostop do pomoči in svetovalne vire, posebne pogodbene možnosti za upravljavca računa in pregled poslovne naročnine.",
    "Basic subscription" : "Osnovna naročnina",
    "Standard subscription" : "Standardna naročnina",
    "Premium subscription" : "Premium naročnina",
    "Géant subscription" : "Naročnina Géant",
    "Silver partner subscription" : "Srebrna naročnina",
    "Gold partner subscription" : "Zlata naročnina",
    "Subscription" : "Naročnina",
    "Over subscription limit" : "Presežena je omejitev naročnine",
    "Valid subscription" : "Veljavna naročnina",
    "Expired subscription" : "Pretečena naročnina",
    "Subscription key:" : "Ključ za naročnino:",
    "Expires in: " : "Preteče čez:",
    "_%n year_::_%n years_" : ["%nleto","%nleti","%n leta","%n let"],
    "_%n month_::_%n months_" : ["%n mesec","%n meseca","%n mesece","%n mesecev"],
    "_%n week_::_%n weeks_" : ["%n teden","%n tedna","%n tedne","%n tednov"],
    "_%n day_::_%n days_" : ["%n dan","%n dneva","%n dni","%n dni"],
    "For an unlimited amount of users" : "Za neomejeno število uporabnikov",
    "_For %n active users_::_For %n active users_" : ["Za %n dejavnega uporabnika","Za %n dejavna uporabnika","Za %n dejavne uporabnike","Za %n dejavnih uporabnikov"],
    "_For %n users_::_For %n users_" : ["Za %n uporabnika","Za %n uporabnika","Za %n uporabnike","Za %n uporabnikov"],
    "_currently at %n user_::_currently at %n users_" : ["trenutno je vključen %n uporabnik","trenutno sta vključena %n uporabnika","trenutno so vključeni %n uporabniki","trenutno je vključenih %nuporabnikov"],
    "Includes support for %s" : "Vključuje podporo za %s",
    "Includes support for %1$s & %2$s" : "Vključuje podporo za %1$s in %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Vključuje podporo za %1$s, %2$s in %3$s",
    "Extended maintenance life cycle" : "Razširjen življenjski krog vzdrževanja",
    "Update subscription key" : "Posodobi ključ za naročnino",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je vaš upravljalec računa. Če imate vprašanje glede naročnine, ne odlašajte in stopite z nami v stik.",
    "You can find answers to common question in our portal and also file support requests there." : "Odgovore na splošna vprašanja najdete na našem spletišču, prav tako datotečno podporo na tem mestu.",
    "Access Nextcloud portal" : "Dostop do portala Nextcloud",
    "System information" : "Podrobnosti sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Zbiranje podrobnosti sistema za podporo. Spodnji gumb ustvari besedilno datoteko v mapi »Sistemske podrobnosti« in omogoča souporabo kot z geslom zaščiteno javno povezavo. Povezava je veljavna dva tedna.",
    "Generate system report" : "Ustvari sistemsko poročilo",
    "Enterprise subscription recommended" : "Priporočena je poslovna naročnina",
    "No active enterprise subscription" : "Ni dejavne poslovni naročnini",
    "Unsupported" : "Nepodprto",
    "This Nextcloud server has no Enterprise Subscription." : "Ta strežnik Nextcloud nima Poslovne naročnine",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Podjetniška naročnina Nextcloud vam omogoča največ v oblaku Nextcloud, od varovanih podatkov do stalno zanesljivega delovanja strežnikov.",
    "Advantages" : "Prednosti",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Dostop do vrhunskih znanj vzdrževalcev okolja Nextcloud prek dokumentacije in podpore.",
    "Access to additional capabilities like Outlook integration, online office and more" : "Dostop do dodatnih zmožnosti, kot je podpora za Outlook, spletni pisarniški paket in še več.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Dostop do strokovne podpore razširljivosti in zmožnostih razširljivosti za Nextcloud Datoteke in Talk",
    "Optional branding, consulting, architecture advice" : "Izbirna uporaba blagovne znamke podjetja, svetovanje in pomoč.",
    "Confidential security notification service, mitigations, patches and advice" : "Zaupne varnostne storitve, blažitve težav, popravki in nasveti.",
    "Compliance certification, advice and documentation" : "Potrjevanje skladnosti, nasveti in dokumentacija",
    "Get a quote" : "Pridobite ponudbo",
    "More information" : "Več podrobnosti",
    "Subscription benefits" : "Prednosti naročnine",
    "Pricing" : "Cenik",
    "Community support" : "Podpora skupnosti",
    "Forum" : "Spletni forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Oblak Nextcloud je prosta programska oprema, s podporo izredno dinamične skupnosti. Sodelovanje na forumu omogoča diskusijo z drugimi.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Oblak Nextcloud uporablja okolje GitHub za sodelovalno delo. Poročila o hroščih je mogoče objaviti neposredno na strani.",
    "Chat" : "Pogovor",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Z nami lahko klepetate na kanalu IRC #nextcloud na spletišču Freenode.",
    "Nextcloud forum" : "Forum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Odpri klepet",
    "Subscription key" : "Ključ za naročnino",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Če imate omogočeno Naročnino Nextcloud, vpišite ključ v spodnje polje.",
    "Learn more about an enterprise subscription." : "Pozanimajte se tudi o poslovni naročnini.",
    "Set subscription key" : "Nastavi ključ za naročnino",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Podrobnosti naročnine trenutno ni bilo mogoče pridobiti. Načrtovana je samodejna ponovitev poizvedbe. Poskusite kasneje.",
    "The subscription key was invalid." : "Ključ za naročnino ni veljaven.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Ključa naročnine ni mogoče preveriti, ker ni vzpostavljene povezave med omrežjem in strežnikom. Stopite v stik s podporno skupino za razrešitev težave.",
    "The subscription key had an invalid format." : "Ključ za naročnino je napačno oblikovan.",
    "While fetching the subscription information an error happened." : "Prišlo je do napake med pridobivanjem podrobnosti o naročnini.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Spodnji gumb ustvari besedilo datoteko v mapi »Sistemske podrobnosti« in omogoča souporabo kot z geslom zaščiteno javno povezavo. Povezava je veljavna dva tedna.",
    "News" : "Novice",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Za sveže novice in dogodke Nextcloud se naročite na Novice in nas sledite na družbenih omrežjih.",
    "Like our Facebook page" : "Spremljajte naš Facebook",
    "Follow us on Twitter" : "Sledite naš Twitter",
    "Check out our blog" : "Preverite naš blog",
    "Subscribe to our newsletter" : "Naročite se na novice"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
