OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Прегледувач",
    "Simple file viewer with slideshow for media" : "Едноставен прегледувач на датотеки со слајдшоу за медиуми",
    "Your browser does not support audio." : "Вашиот прелистувач не поддржува звук.",
    "Error loading {name}" : "Грешка при вчитување на  {name}",
    "Unsaved changes" : "Незачувани промени",
    "Your browser does not support videos." : "Вашиот прелистувач не поддржува видео.",
    "Edit" : "Уреди",
    "Open sidebar" : "Отвори странична лента",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "There is no plugin available to display this file type" : "Нема достапен додаток за приказ на овој вид на датотека",
    "View" : "Погледни",
    "Name" : "Име",
    "Save" : "Зачувај",
    "Save as" : "Зачувај како",
    "Back" : "Назад",
    "Loading …" : "Се вчитува…",
    "Reset" : "Ресетирање",
    "All changes will be lost." : "Сите промени ќе се изгубат.",
    "Are you sure you want to continue?" : "Дали си сигурен дека сакаш да продолжиш?",
    "Cancel" : "Откажи",
    "Continue" : "Продолжи",
    "Undo" : "Назад",
    "Redo" : "Напред",
    "Show original image" : "Прикажи ја оргиналната слика",
    "Zoom in" : "Зумирај",
    "Zoom out" : "Од зумирај",
    "Toggle zoom menu" : "Прикажи мени за зумирање",
    "Adjust" : "Прилагоди",
    "Fine-tune" : "Фимо прилагодување",
    "Filters" : "Филтри",
    "Watermark" : "Воден печат",
    "Draw" : "Нацрт",
    "Resize" : "Промени големина",
    "Invalid image." : "Невалидна слика.",
    "Error while uploading the image." : "Грешка при прикачување на сликата.",
    "are not images" : "не се слики",
    "is not an image" : "не е слика",
    "to be uploaded" : "за да се орикачат",
    "Crop" : "Пресечи",
    "Original" : "Оргинал",
    "Custom" : "Прилагодено",
    "Square" : "Квадрат",
    "Landscape" : "Пејсаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Елипса",
    "Classic TV" : "Класичен ТВ",
    "Arrow" : "Стрела",
    "Brightness" : "Светлина",
    "Contrast" : "Контраст",
    "Value" : "Вредност",
    "Image" : "Слика",
    "+ Add image" : "+ Додади слика",
    "Line" : "Линија",
    "Text" : "Текст",
    "Size" : "Големина",
    "Position" : "Позиција",
    "Save image as" : "Зачувај ја сликата како",
    "Extension" : "Екстензија",
    "Name is required." : "Потребно е име.",
    "Quality" : "Квалитет",
    "Actual size (100%)" : "Актуелна големина (100%)",
    "Fit size" : "Соодветна големина",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажете ги вашите најнови фотографии и видеа како во филмовите, прикажете го прегледот на вашиот последен роман директно од вашиот Nextcloud, изберете го најдобриот GIF од вашата колекција благодарение на директниот преглед на омилените датотеките и многу друго!"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
