(self.webpackChunk_nextcloud_text=self.webpackChunk_nextcloud_text||[]).push([["highlight/json"],{82026:n=>{n.exports=function(n){const e={literal:"true false null"},t=[n.C_LINE_COMMENT_MODE,n.C_BLOCK_COMMENT_MODE],l=[n.QUOTE_STRING_MODE,n.C_NUMBER_MODE],i={end:",",endsWithParent:!0,excludeEnd:!0,contains:l,keywords:e},a={begin:/\{/,end:/\}/,contains:[{className:"attr",begin:/"/,end:/"/,contains:[n.BACKSLASH_ESCAPE],illegal:"\\n"},n.inherit(i,{begin:/:/})].concat(t),illegal:"\\S"},s={begin:"\\[",end:"\\]",contains:[n.inherit(i)],illegal:"\\S"};return l.push(a,s),t.forEach((function(n){l.push(n)})),{name:"JSON",contains:l,keywords:e,illegal:"\\S"}}}}]);
//# sourceMappingURL=json.js.map?v=6f01d5e9b7f5427511d6