OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "To-dos" : "代办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 还原了日历 {calendar}",
    "You restored calendar {calendar}" : "你还原了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "你取消了 {actor} 共享的日历 {calendar}",
    "You unshared calendar {calendar} from {user}" : "{user} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{user} 取消了 {actor} 共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消了他们自己共享的日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "群组 {group} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "群组 {group} 取消了 {actor} 共享的日历 {calendar}",
    "Untitled event" : "未命名事件",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} 将事件 {event} 从日历 {sourceCalendar} 移动至日历 {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "您已将事件 {event} 从日历 {sourceCalendar} 移动至日历 {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 还原了事件 {event}，它位于日历 {calendar}",
    "You restored event {event} of calendar {calendar}" : "你还原了事件 {event}，它位于日历 {calendar}",
    "Busy" : "忙碌",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} 在清单 {calendar} 中创建了代办事项 {todo}",
    "You created to-do {todo} in list {calendar}" : "您已在清单 {calendar} 中创建了代办事项 {todo}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} 从列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted to-do {todo} from list {calendar}" : "你从列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} 更新了列表 {calendar} 中的待办事项 {todo}",
    "You updated to-do {todo} in list {calendar}" : "你更新了列表 {calendar} 中的待办事项 {todo}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} 解决了列表 {calendar} 中的待办事项 {todo}",
    "You solved to-do {todo} in list {calendar}" : "你解决了列表 {calendar} 中的待办事项 {todo}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} 重新开启了列表 {calendar} 中的待办事项 {todo}",
    "You reopened to-do {todo} in list {calendar}" : "你重新开启了列表 {calendar} 中的待办事项 {todo}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} 将待办事项 {todo} 从列表 {sourceCalendar} 移动到列表 {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "你将待办事项 {todo} 从列表 {sourceCalendar} 移动到列表 {targetCalendar}",
    "Calendar, contacts and tasks" : "日历、联系人和任务",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>to-do</strong> was modified" : "日历中的<strong>待办事项</strong>已修改",
    "Contact birthdays" : "联系人生日",
    "Death of %s" : "%s 的忌日",
    "Calendar:" : "日历：",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n minute_::_%n minutes_" : ["%n 分钟"],
    "%s (in %s)" : "%s （在 %s）",
    "%s (%s ago)" : "%s （%s 前）",
    "Calendar: %s" : "日历：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地点：%s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Cancelled: %1$s" : "已取消：%1$s",
    "Re: %1$s" : "回复：%1$s",
    "Invitation: %1$s" : "邀请：%1$s",
    "Organizer:" : "组织者：",
    "Attendees:" : "与会者：",
    "Title:" : "标题：",
    "Time:" : "时间：",
    "Location:" : "地区：",
    "Link:" : "链接：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "More options at %s" : "在%s的更多选项",
    "Contacts" : "联系人",
    "{actor} created address book {addressbook}" : "{actor} 创建了通讯录 {addressbook}",
    "You created address book {addressbook}" : "你创建了通讯录 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 删除了通讯录 {addressbook}",
    "You deleted address book {addressbook}" : "你删除了通讯录 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通讯录 {addressbook}",
    "You updated address book {addressbook}" : "你更新通讯录  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 与你分享了通讯录 {addressbook}",
    "You shared address book {addressbook} with {user}" : "你与 {user} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 与 {user} 分享了通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消和你分享通讯录 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "你取消了与 {user} 分享通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消了与 {user} 分享通讯录",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消了和自己分享通讯录 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "你和小组 {group} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 和小组 {group} 分享了通讯录 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "你取消和小组 {group} 分享通讯录 ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消和小组 {group} 分享通讯录 ",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通讯录 {addressbook} 中创建了联系人 {card} ",
    "You created contact {card} in address book {addressbook}" : "你在通讯录 {addressbook} 中创建了联系人 {card} ",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 从通讯录 {addressbook} 中删除了联系人 {card} ",
    "You deleted contact {card} from address book {addressbook}" : "你从通讯录 {addressbook} 中删除了联系人 {card} ",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通讯录 {addressbook} 中的联系人 {card} ",
    "You updated contact {card} in address book {addressbook}" : "你更新了通讯录 {addressbook} 中的联系人 {card} ",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "一名 <strong>联系人</strong>或一个<strong>通讯录</strong>被更改了",
    "File is not updatable: %1$s" : "无法更新文件：%1$s",
    "Could not write to final file, canceled by hook" : "无法写入最终文件，操作被插件取消",
    "Could not write file contents" : "无法写入文件内容",
    "_%n byte_::_%n bytes_" : ["%n字节"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "将文件复制到目标位置时发生错误（已复制：%1$s，预期大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "预期文件大小为 %1$s，实际从 Nextcloud 客户端读入并写入 Nextcloud 存储空间的大小为 %2$s。可能是发送端发生了网络问题，或者是服务器写入存储设备时发生错误。",
    "Could not rename part file to final file, canceled by hook" : "无法将部分文件重命名为最终文件，操作被插件取消",
    "Could not rename part file to final file" : "无法将部分文件重命名为最终文件",
    "Failed to check file size: %1$s" : "检查文件大小失败：%1$s",
    "Could not open file" : "无法打开文件",
    "Encryption not ready: %1$s" : "加密不可用：%1$s",
    "Failed to open file: %1$s" : "打开文件失败：%1$s",
    "Failed to unlink: %1$s" : "解除链接失败：%1$s",
    "Invalid chunk name" : "分片名称无效",
    "Could not rename part file assembled from chunks" : "无法重命名从分片组合的部分文件",
    "Failed to write file contents: %1$s" : "写入文件内容失败：%1$s",
    "File not found: %1$s" : "找不到文件：%1$s",
    "System is in maintenance mode." : "系统处于维护模式 ",
    "Upgrade needed" : "需要升级",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的%s 需要配置使用HTTPS以在iOS/macOS中使用CalDAV和CardDAV。",
    "Configures a CalDAV account" : "配置一个 CalDAV 账号",
    "Configures a CardDAV account" : "配置一个 CardDAV 账号",
    "Events" : "事件",
    "Tasks" : "任务",
    "Untitled task" : "无标题任务",
    "Completed on %s" : "已完成 %s",
    "Due on %s by %s" : "到期于%s ，在%s之前",
    "Due on %s" : "到期于%s",
    "Migrated calendar (%1$s)" : "迁移的日历（%1$s）",
    "Calendars including events, details and attendees" : "日历包含活动、参与人和事件详情",
    "Contacts and groups" : "联系人和群组",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV端点",
    "Availability" : "可用性",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "如果您配置了工作时间，其他用户在预订会议时就会了解您何时不在办公室。",
    "Time zone:" : "时区：",
    "to" : "到",
    "Delete slot" : "删除插槽",
    "No working hours set" : "尚未设置工作时间",
    "Add slot" : "添加插槽",
    "Monday" : "周一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "不在可用时间内时，自动将用户状态设置为“请勿打扰”并静音所有通知。",
    "Save" : "保存",
    "Failed to load availability" : "可用时间段加载失败",
    "Saved availability" : "可用时间已保存",
    "Failed to save availability" : "可用时间保存失败",
    "Calendar server" : "日历服务器",
    "Send invitations to attendees" : "向与会者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "Send notifications for events" : "发送事件通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
    "Send reminder notifications to calendar sharees as well" : "同时向日历共享者发送提醒通知",
    "Reminders are always sent to organizers and attendees." : "始终向组织者和与会者发出提醒。",
    "Enable notifications for events via push" : "启用推送事件通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装 {calendarappstoreopen}日历应用{linkclose}，或者 {calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置 {emailopen}邮件服务器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的出席状态时出错。",
    "Please contact the organizer directly." : "请直接联系组织者。",
    "Are you accepting the invitation?" : "您是否接受邀请？",
    "Tentative" : "暂定",
    "Your attendance was updated successfully." : "您的出席状态更新成功。",
    "Todos" : "待办事项",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Invitation canceled" : "邀请已取消",
    "Invitation updated" : "邀请已更新",
    "Invitation" : "邀请"
},
"nplurals=1; plural=0;");
