OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Condivisa con {email}",
    "Shared with {email} by {actor}" : "Condivisa con {email} da {actor}",
    "Unshared from {email}" : "Condivisione rimossa da {email}",
    "Unshared from {email} by {actor}" : "Condivisione rimossa da {email} da {actor}",
    "Password for mail share sent to {email}" : "Password per la condivisione tramite posta inviata a {email}",
    "Password for mail share sent to you" : "Password per la condivisione tramite posta inviata a te",
    "You shared {file} with {email} by mail" : "Hai condiviso {file} con {email} tramite posta",
    "{actor} shared {file} with {email} by mail" : "{actor} ha condiviso {file} con {email} tramite email",
    "You unshared {file} from {email} by mail" : "Hai rimosso la condivisione di {file} con {email} tramite posta",
    "{actor} unshared {file} from {email} by mail" : "{actor} ha rimosso la condivisione di {file} da {email} tramite posta",
    "Password to access {file} was sent to {email}" : "La password per accedere a {file} ti è stata inviata a {email}",
    "Password to access {file} was sent to you" : "La password per accedere a {file} ti è stata inviata",
    "Share by mail" : "Condividi tramite email",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Condivisione di %1$s non riuscita, poiché l'oggetto è già condiviso con l'utente %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Non possiamo inviarti la password generata automaticamente. Imposta un indirizzo di posta valido nelle impostazioni personali e prova ancora.",
    "Failed to send share by email. Got an invalid email address" : "Impossibile inviare la condivisione tramite e-mail. L'indirizzo email non è valido",
    "Failed to send share by email" : "Invio non riuscito della condivisione tramite email",
    "%1$s shared »%2$s« with you" : "%1$s ha condiviso «%2$s» con te",
    "%1$s shared »%2$s« with you." : "%1$s ha condiviso «%2$s» con te.",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "Open »%s«" : "Apri «%s»",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s ha condiviso «%2$s» con te.\nDovresti aver ricevuto un messaggio separato con un collegamento per accedervi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s ha condiviso «%2$s» con te. Dovresti aver ricevuto un messaggio separato con un collegamento per accedervi.",
    "Password to access »%1$s« shared to you by %2$s" : "Password per accedere a «%1$s» condivisa con te da %2$s",
    "Password to access »%s«" : "Password per accedere a «%s»",
    "It is protected with the following password:" : "È protetta con la password seguente:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere",
    "»%s« added a note to a file shared with you" : "«%s» ha aggiunto una nota a un file condiviso con te",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Hai appena condiviso «%1$s» con %2$s. La condivisione è già stata inviata al destinatario. A causa dei criteri di sicurezza definiti dall'amministratore di %3$s, ogni condivisione deve essere protetta con password e non è consentito inviare la password direttamente al destinatario. Per questo motivo, devi inoltrare la password manualmente al destinatario.",
    "Password to access »%1$s« shared by you with %2$s" : "Password per accedere a «%1$s» condivisa da te con %2$s",
    "This is the password:" : "Questa è la password:",
    "You can choose a different password at any time in the share dialog." : "Puoi scegliere una password diversa in qualsiasi momento nella finestra di condivisione.",
    "Could not find share" : "Non è stato possibile trovare la condivisione",
    "Share provider which allows you to share files by mail" : "Fornitore di condivisione che ti consente di condividere file tramite posta",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Consente agli utenti di condividere un collegamento personalizzato a un file o a una cartella inserendo un indirizzo di posta elettronica.",
    "Send password by mail" : "Invia password tramite posta",
    "Reply to initiator" : "Rispondi all'iniziatore",
    "Shared with %1$s" : "Condivisa con %1$s",
    "Shared with %1$s by %2$s" : "Condivisa con %1$s da %2$s",
    "Unshared from %1$s" : "Condivisione rimossa da %1$s",
    "Unshared from %1$s by %2$s" : "Condivisione rimossa da %1$s da %2$s",
    "Password for mail share sent to %1$s" : "Password per la condivisione tramite posta inviata a %1$s",
    "You shared %1$s with %2$s by mail" : "Hai condiviso %1$s con %2$s tramite posta",
    "%3$s shared %1$s with %2$s by mail" : "%3$s ha condiviso %1$s con %2$s tramite email",
    "You unshared %1$s from %2$s by mail" : "Hai rimosso la condivisione %1$s da %2$s tramite posta",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s ha rimosso la condivisione %1$s da %2$s tramite posta",
    "Password to access %1$s was sent to %2s" : "La password per accedere a %1$s è stata inviata a %2s",
    "Password to access %1$s was sent to you" : "La password per accedere a %1$s ti è stata inviata"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
