<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38730 => 'Županija Središnja Bosna',
  38731 => 'Županija Posavska',
  38732 => 'Zeničko-dobojska županija',
  38733 => 'Sarajevska županija',
  38734 => 'Hercegbosanska županija',
  38735 => 'Tuzlanska županija',
  38736 => 'Hercegovačko-neretvanska županija',
  38737 => 'Unsko-sanska županija',
  38738 => 'Bosansko-podrinjska županija Goražde',
  38739 => 'Županija Zapadnohercegovačka',
);
