OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarii",
    "You commented" : "Ai comentat",
    "{author} commented" : " {author} a comentat",
    "You commented on %1$s" : "Ai comentat la %1$s",
    "You commented on {file}" : "Ai comentat la {file}",
    "%1$s commented on %2$s" : "%1$s a comentat la %2$s",
    "{author} commented on {file}" : " {author} a comentat la {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarii</strong> la fișiere",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Ai fost menționat în fișierul \"{file}\", într-un comentariu facut de un utilizator ce întretimp a fost șters",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} te-a menționat într-un comentariu la fișierul \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin pentru aplicația de fișiere pentru adăugarea de comentarii",
    "Edit comment" : "Editează comentariul",
    "Delete comment" : "Șterge comentariul",
    "Cancel edit" : "Anulați editarea",
    "Post comment" : "Postează comentariu",
    "No comments yet, start the conversation!" : "Nici un comentariu încă, începe conversația!",
    "No more messages" : "Nu mai sunt mesaje",
    "Retry" : "Reîncearcă",
    "Unable to load the comments list" : "Lista de comentarii nu poate fi încărcată",
    "_%n unread comment_::_%n unread comments_" : ["%n comentariu necitit","%n comentarii necitite","%n comentarii necitite"],
    "_1 new comment_::_{unread} new comments_" : ["1 nou comentariu","{unread} noi comentarii","{unread} comentarii noi"],
    "Comment" : "Comentariu",
    "An error occurred while trying to edit the comment" : "A apărut o eroare la încercarea de a edita comentariul",
    "Comment deleted" : "Comentariul a fost șters",
    "An error occurred while trying to delete the comment" : "A apărut o eroare la încercarea de a șterge comentariul",
    "An error occurred while trying to create the comment" : "A apărut o eroare la încercarea de a crea comentariul",
    "%1$s commented" : "%1$s a comentat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
