OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Hai abilitato l'autenticazione TOTP a due fattori per il tuo account",
    "You disabled TOTP two-factor authentication for your account" : "Hai disabilitato l'autenticazione TOTP a due fattori per il tuo account",
    "TOTP two-factor authentication disabled by an admin" : "Autenticazione a due fattori TOTP disabilitata da un amministratore",
    "TOTP (Authenticator app)" : "TOTP (Applicazione autenticazione)",
    "Authenticate with a TOTP app" : "Autenticati con un'applicazione TOTP",
    "Two-Factor TOTP Provider" : "Fornitore TOTP a due fattori",
    "TOTP two-factor provider" : "Fornitore a due fattori per TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un provider di autenticazione a due fattori per TOTP (RFC 6238)",
    "Enable TOTP" : "Abilita TOTP",
    "Could not enable TOTP" : "Impossibile abilitare TOTP",
    "Could not verify your key. Please try again" : "Impossibile verificare la tua chiave. Prova ancora",
    "Your new TOTP secret is:" : "Il tuo nuovo segreto TOTP è:",
    "For quick setup, scan this QR code with your TOTP app:" : "Per una configurazione rapida, scansiona questo codice QR con la tua applicazione TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Una volta configurata la tua applicazione, digita di seguito un codice di prova per assicurarti che tutto funzioni correttamente:",
    "Authentication code" : "Codice di autenticazione",
    "Verify" : "Verifica",
    "Get the authentication code from the two-factor authentication app on your device." : "Ottieni il codice di autenticazione dall'applicazione di autenticazione con due fattori sul tuo dispositivo.",
    "Submit" : "Invia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
