OC.L10N.register(
    "viewer",
    {
    "Image saved" : "Imagen guardada",
    "Unsaved changes" : "Cambios no guardados",
    "Edit" : "Editar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Back" : "Atrás",
    "Reset" : "Restablecer",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Deshacer",
    "Custom" : "Personalizado",
    "Value" : "Valor",
    "Text" : "Texto",
    "Size" : "Tamaño",
    "Position" : "Posición"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
