OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unbekannte Adresse",
    "No result." : "Kein Ergebnis.",
    "Malformed JSON data." : "Fehlerhafte JSON-Daten.",
    "Error" : "Fehler",
    "Weather status" : "Wetterstatus",
    "Weather status in your dashboard" : "Wetterstatus für dein Dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden.",
    "Detect location" : "Standort ermitteln",
    "Set custom address" : "Benutzerdefinierte Adresse festlegen",
    "Favorites" : "Favoriten",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} klarer Himmel später am Tag",
    "{temperature} {unit} clear sky" : "{temperature} {unit} klarer Himmel",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} bewölkt später am Tag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} bewölkt",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} schönes Wetter später am Tag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} schönes Wetter",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} teilweise bewölkt später am Tag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} teilweise bewölkt",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} neblig später am Tag",
    "{temperature} {unit} foggy" : "{temperature} {unit} nebelig",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} leichter Regen später am Tag",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} leichter Regen",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} Regen später am Tag",
    "{temperature} {unit} rainfall" : "{temperature} {unit} Regen",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} starker Regen später am Tag",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} starker Regen",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} Regenschauer später am Tag",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} Regenschauer",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} leichte Regenschauer später am Tag",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} leichte Regenschauer",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} starke Regenschauer später am Tag",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} starke Regenschauer",
    "More weather for {adr}" : "Mehr Wetter für {adr}",
    "Loading weather" : "Lade Wetter",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add as favorite" : "Als Favorit hinzufügen",
    "You are not logged in." : "Du bist nicht angemeldet.",
    "There was an error getting the weather status information." : "Beim Abrufen der Wetterstatusinformationen ist ein Fehler aufgetreten.",
    "No weather information found" : "Keine Wetterinformationen gefunden",
    "Location not found" : "Standort nicht gefunden",
    "There was an error setting the location address." : "Es ist ein Fehler beim Festlegen der Standortadresse aufgetreten.",
    "There was an error setting the location." : "Es ist ein Fehler beim Festlegen des Standortes aufgetreten.",
    "There was an error saving the mode." : "Es ist ein Fehler beim Festlegen des Modus aufgetreten.",
    "There was an error using personal address." : "Es ist ein Fehler beim Verwenden der persönlichen Adresse aufgetreten.",
    "Set location for weather" : "Standort für Wetterinformationen einstellen"
},
"nplurals=2; plural=(n != 1);");
