OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ενεργοποιήσατε την ΤΟΤΡ πιστοποίηση δύο-παραγόντων για το λογαριασμό σας",
    "You disabled TOTP two-factor authentication for your account" : "Απενεργοποιήσατε την ΤΟΤΡ πιστοποίηση δύο-παραγόντων για το λογαριασμό σας",
    "TOTP two-factor authentication disabled by an admin" : "Η πιστοποίηση δύο-παραγόντων ΤΟΤΡ απενεργοποιήθηκε από τον διαχειριστή",
    "TOTP (Authenticator app)" : "TOTP (Εφαρμογή πιστοποίησης)",
    "Authenticate with a TOTP app" : "Πιστοποίηση με μια TOTP εφαρμογή",
    "Two-Factor TOTP Provider" : "Πάροχος ΤΟΤΡ δύο-Παραγόντων",
    "TOTP two-factor provider" : "TOTP δύο-παραγόντων πάροχος",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Πάροχος Αυθεντικοποίησης-Δύο-Παραγόντων για TOTP (RFC 6238)",
    "Enable TOTP" : "Ενεργοποίηση TOTP",
    "Could not enable TOTP" : "Αδυναμία ενεργοποίησης TOTP",
    "Could not verify your key. Please try again" : "Αδυναμία επαλήθευσης κλειδιού. Παρακαλούμε προσπαθήστε ξανά",
    "Your new TOTP secret is:" : "Ο νέος κωδικός σας ΤΟΤΡ είναι:",
    "For quick setup, scan this QR code with your TOTP app:" : "Για γρήγορη εγκατάσταση, σαρώστε αυτόν τον κωδικό QR με την εφαρμογή TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Αφού διαμορφώσετε την εφαρμογή σας, εισάγετε έναν κωδικό δοκιμής παρακάτω για να βεβαιωθείτε ότι όλα λειτουργούν σωστά:",
    "Authentication code" : "Κώδικας πιστοποίησης",
    "Verify" : "Επαλήθευση",
    "Get the authentication code from the two-factor authentication app on your device." : "Παραλάβετε τον κωδικό πιστοποίησης από την εφαρμογή δύο-παραγόντων στην συσκευή σας.",
    "Submit" : "Υποβολή"
},
"nplurals=2; plural=(n != 1);");
