OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalendář",
    "Calendar \"%s\"" : "Kalendář „%s“",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Tabule „%s“ v Deck",
    "Files" : "Soubory",
    "File \"%s\"" : "File „%s“",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "Konverzace „%s“ v Talk",
    "Related Resources" : "Související prostředky",
    "Displays resources related to current item in right panel" : "V panelu napravo zobrazuje prostředky související s právě označenou položkou",
    "Displays resources related to current item in right panel." : "V panelu napravo zobrazuje prostředky související s právě označenou položkou.",
    "Talk conversation" : "Konverzace v Talk",
    "Conversation with %s" : "Konverzace s %s"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
