OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Calendièr",
    "Files" : "Fichièrs",
    "Talk" : "Talk",
    "Talk conversation" : "Conversacion Talk"
},
"nplurals=2; plural=(n > 1);");
