OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Ismeretlen cím",
    "No result." : "Nincs találat.",
    "Malformed JSON data." : "Sérült JSON adatok.",
    "Error" : "Hiba",
    "Weather status" : "Időjárás állapota",
    "Weather status in your dashboard" : "Időjárás állapota az irányítópulton",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Irányítópultba integrált időjárási állapot. A felhasználó helyzete meghatározható automatikusan vagy egyénileg beállítható. Ezután egy 6 órás előrejelzés lesz megjelenítve. Ez az információ máshol is megjeleníthető, például a Naptár alkalmazásban.",
    "Detect location" : "Helymeghatározás",
    "Set custom address" : "Egyéni cím beállítása",
    "Favorites" : "Kedvencek",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} tiszta égbolt a nap további részében",
    "{temperature} {unit} clear sky" : "{temperature} {unit} tiszta égbolt",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} felhős a nap további részében",
    "{temperature} {unit} cloudy" : "{temperature} {unit} felhős",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} kellemes idő a nap további részében",
    "{temperature} {unit} fair weather" : "{temperature} {unit} kellemes idő",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} részben felhős a nap további részében",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} részben felhős",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ködös a nap további részében",
    "{temperature} {unit} foggy" : "{temperature} {unit} ködös",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} enyhe esőzés a nap további részében",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} enyhe esőzés",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} esőzés a nap további részében",
    "{temperature} {unit} rainfall" : "{temperature} {unit} esőzés",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} kiadós esőzés a nap további részében",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} kiadós esőzés",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} záporok a nap további részében",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} záporok",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} enyhe záporok a nap további részében",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} enyhe záporok",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} kiadós záporok a nap további részében",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} kiadós záporok",
    "More weather for {adr}" : "További időjárás a következőhöz: {adr}",
    "Loading weather" : "Időjárás betöltése",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add as favorite" : "Hozzáadás kedvencként",
    "You are not logged in." : "Nincs bejelentkezve.",
    "There was an error getting the weather status information." : "Hiba lépett fel az időjárási információk lekérése során.",
    "No weather information found" : "Nem találhatók időjárási információk",
    "Location not found" : "A hely nem található",
    "There was an error setting the location address." : "Hiba történt a tartózkodási cím beállítása során.",
    "There was an error setting the location." : "Hiba történt a tartózkodási hely beállítása során.",
    "There was an error saving the mode." : "Hiba történt a mód mentése során.",
    "There was an error using personal address." : "Hiba történt a személyes cím használata során.",
    "Set location for weather" : "Tartózkodási hely beállítása az időjáráshoz"
},
"nplurals=2; plural=(n != 1);");
